@@ -21,5 +21,5 @@
 	$query = "INSERT INTO " . BWB_TABLE_PREFIX . "head SET head_name = '" . $head_name . "', revised='$today'";
 	$cnt = $bwb_dbh->exec($query);
 	
-	header("Location: manage_head.php?head_added=1");
+	echo $cnt . "@@@@@" . $head_name;
 ?>
\ No newline at end of file
