@@ -8,6 +8,13 @@
 // Added storing of plugin ID's into page data to facilitate content sensitive help for relevant plugins in page editor.
 // Revised: 1/12/2015	ELL
 // Fixed bug with single quotes in plugin HTML doubling up in border areas and content.
+// Revised: 5/1/2015	ELL
+// Converted from inline RunSQL function to included library RunSQL function.
+// Revised: 8/19/2015	ELL
+// Added handling of new plugin feature body_onload field.
+// Revised: 10/2/2015	ELL
+// Modified to get template from field in page data record instead of parsing page file.
+// Modified to get border area names and head name from fields in page data record instead of parsing page file.
 // 
 
 include ("check_session.php");
@@ -15,6 +22,8 @@ include ("check_session.php");
 $page_name = $_POST['page_name'];
 $plugin = $_POST['plugin'];
 
+include("lib/run_sql.php");
+
 ////////////////////////////////////////////////////////////////////////////////////////////////
 function copy_table_structure($table, $table_prefix, $dbh, $database)
 {
@@ -29,143 +38,19 @@ function copy_table_structure($table, $table_prefix, $dbh, $database)
 			$source_table = $table_prefix . "site_classes";
 		else
 			$source_table = $table_prefix . "site_css";
-		$query = "CREATE TABLE IF NOT EXISTS " . $table_prefix . $table . " SELECT * FROM " . $source_table;
-		$cnt = $dbh->exec($query);
-		
-		$query = " ALTER TABLE `" . $table_prefix . $table . "` ADD PRIMARY KEY (`class`)";
-		$cnt = $dbh->exec($query);
-	}
-	
-	$query = "TRUNCATE TABLE `" . $table_prefix . $table . "`";
-	$cnt = $dbh->exec($query);
-		
-	return "";
-}
-	
-///////////////////////////////////////////////////////////////////////////////
-function RunSQL($sql_string, $table_prefix, $dbh)
-{
-	$sql_string = stripslashes($sql_string);
-	$sql_string_arr = array();
-	$line_arr = array();
-	// Split SQL input into lines.
-	$line_arr = preg_split("[\n|\r]", $sql_string);
-	$sql_string_arr[0] = "";
-	$j = 0;
-	$find_start = true;
-	$got_script = false;
-	$got_php = false;
-	$got_style = false;
-	// Search for commands and assemble into SQL command array.
-	for ($i = 0; $i < count($line_arr); $i++)
-	{
-		// Test for comment line.
-		$curr_line = trim($line_arr[$i]);
-		if ($find_start)
-		{
-			$first_chars = substr($curr_line, 0, 2);
-			if (($first_chars == "--") || ($first_chars == "//"))
-				continue;
-		}
-		$find_start = false;
-		
-		// It is possible for a line to end with a semicolon (;) if records contain JavaScript or PHP.  Need to turn off looking end of SQL command
-		// if script or PHP is found until end of script or PHP is also found.  Otherwise we run the risk of trying to run only part of a record insert
-		// which usually results in an SQL syntax error.
-		if (!$got_script)
-		{
-			if (stripos($curr_line, "<script") !== false)
-				$got_script = true;
-		}
-		if ($got_script)
-		{
-			if (stripos($curr_line, "</script>") !== false)
-				$got_script = false;
-		}
-		
-		if (!$got_php)
-		{
-			if (stripos($curr_line, "<?php") !== false)
-				$got_php = true;
-		}
-		if ($got_php)
-		{
-			if (stripos($curr_line, "?>") !== false)
-				$got_php = false;
-		}
-		
-		if (!$got_style)
-		{
-			if (stripos($curr_line, "<style") !== false)
-				$got_style = true;
-		}
-		if ($got_style)
-		{
-			if (stripos($curr_line, "</style>") !== false)
-				$got_style = false;
-		}
-		
-		// Build SQL command.
-		$sql_string_arr[$j] = $sql_string_arr[$j] . $line_arr[$i];
-		
-		// Look for end of command.
-		if ((!$got_script) && (!$got_php) && (!$got_style))
-		{
-			$last_char = substr($curr_line, (strlen($curr_line) - 1), 1);
-			if ($last_char == ";")	// Got end of SQL command.
-			{
-				// Check for other possible reasons that ; is at end of line.
-				$last_6_chars = substr($curr_line, (strlen($curr_line) - 7), 6);
-				if (stripos($curr_line, "&") === false) // Looks like ; is not do to & code, good to go.
-				{
-					$j++;
-					$sql_string_arr[$j] = "";
-					$find_start = true;
-				}
-			}
-		}
-	}
-	// Run SQL commands one at a time.
-	for ($i = 0; $i < count($sql_string_arr); $i++)
-	{
-		if (strlen($sql_string_arr[$i]) > 2)
-		{
-			if ($table_prefix != "bwb_")
-			{
-				$sql_string_arr[$i] = str_replace("bwb_link", "@@@link_retention@@@", $sql_string_arr[$i]);
-				$sql_string_arr[$i] = str_replace("bwb_", $table_prefix, $sql_string_arr[$i]);
-				$sql_string_arr[$i] = str_replace("@@@link_retention@@@", "bwb_link", $sql_string_arr[$i]);
-			}
-//			echo $sql_string_arr[$i] . "<br><br>\n";
 
-			try	{
-				$cnt = $dbh->exec($sql_string_arr[$i]);
-			} catch (Exception $e) {
-				echo $e->getMessage() . "<br>\n";
-			}
-			
-//			if (is_array($cnt))
-//			{
-//				echo "<pre>\n";
-//				print_r($cnt);
-//				echo "</pre>\n";
-//			}
-//			elseif ($cnt > 0)
-//				echo $cnt . " row(s) affected.<br>\n";
-//			else
-//				echo $bwb_dbh->errorInfo() . "<br>\n";
-				
-//			if ($i < (count($sql_string_arr) - 1))
-//				echo "<br>-------------------------------------------------------------------------------<br>\n";
-		}
+		$query = "CREATE TABLE " . $table_prefix . $table . " LIKE " . $source_table;
+		$cnt = $dbh->exec($query);
 	}
+		
+	return 1;
 }
 
 ///////////////////////////////////////////////////////////////////////////////
 
 	if (($page_name == "-not selected-") || ($plugin == "-not selected-") || ($page_name == "") || ($plugin == ""))
 	{
-		echo "Oops! You forgot to select a page and/or a plugin.  Click <a href=\"add_plugin_to_page_select.php\" title=\"here\">here</a> and select a page and a plugin.";
+		echo ADD_PLUGIN_TO_PAGE_PAGE_OR_PLUGIN_NOT_SELECTED_1_MSG . " " . CLICK_WORD . " <a href=\"add_plugin_to_page_select.php\" title=\"" . HERE_WORD . "\">" . HERE_WORD . "</a> " .  ADD_PLUGIN_TO_PAGE_PAGE_OR_PLUGIN_NOT_SELECTED_2_MSG;
 		exit;
 	}
 	
@@ -196,15 +81,25 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 	$css_sql = $row["css_sql"];
 	$plugin_sql = $row["plugin_sql"];
 	$deployed = $row["deployed"];
+	$body_onload = $row["body_onload"];
+	$body_onload_function = (isset($row["body_onload_function"]) ? $row["body_onload_function"] : $page_name . "_load");
 	
 	//Get page content from database.
 	$today = date("Y-m-d H:i:s");
-	$query = "SELECT `page_content`, `plugins` FROM " . BWB_TABLE_PREFIX . "page_data WHERE page_name='$page_name'";
+	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "page_data WHERE page_name='$page_name'";
 	$result = $bwb_dbh->query($query);
 	$row = $result->fetch(PDO::FETCH_ASSOC);
 	$page_content = addslashes(stripslashes($row["page_content"]));
 	$existing_plugins = $row["plugins"];
 	$page_content .= "\n\n" . addslashes(stripslashes($content_html));
+	$template = $row["template"];
+	$head_name = $row["head_name"];
+	$header_name = $row["header_name"];
+	$top_name = $row["top_name"];
+	$left_name = $row["left_name"];
+	$right_name = $row["right_name"];
+	$bottom_name = $row["bottom_name"];
+	$footer_name = $row["footer_name"];
 	
 	if ((isset($existing_plugins)) && ($existing_plugins != ""))
 		$plugin_ids = $existing_plugins . "," . $plugin_id;
@@ -213,7 +108,10 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 	
 	//Update page content in database.
 	$today = date("Y-m-d H:i:s");
-	$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET page_content='$page_content', revised='$today', plugins='$plugin_ids' WHERE page_name='$page_name'";
+	if ($body_onload == 1)
+		$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET page_content='$page_content', revised='$today', plugins='$plugin_ids', body_onload=1, body_onload_function='$body_onload_function' WHERE page_name='$page_name'";
+	else
+		$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET page_content='$page_content', revised='$today', plugins='$plugin_ids' WHERE page_name='$page_name'";
 //	echo $query;
 	$cnt = $bwb_dbh->exec($query);
 
@@ -239,14 +137,14 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 	if (file_exists($file_name))
 	{
 		if (!($fh = fopen($file_name, 'r'))) {
-			echo "Error opening page file.  Please contact your system administrator.  Click <a href=\"add_plugin_to_page_select.php\" title=\"here\">here</a> to return to the insert-plugin-into-page console.\n$php_errormsg";
+			echo ADD_PLUGIN_TO_PAGE_ERROR_OPENING_PAGE_FILE_ERR . " " . CLICK_WORD . " <a href=\"add_plugin_to_page_select.php\" title=\"" . HERE_WORD . "\">" . HERE_WORD . "</a> " . ADD_PLUGIN_TO_PAGE_RETURN_TO_INSERT_PLUGIN_INTO_PAGE_CONSOLE_MSG . "\n$php_errormsg";
 			exit;
 		}
 		
 		$contents = (fread($fh, filesize($file_name)));
 		
 		if (!fclose($fh)) {
-			echo "Error closing page file.  Please contact your system administrator.  Click <a href=\"add_plugin_to_page_select.php\" title=\"here\">here</a> to return to the insert-plugin-into-page console.\n$php_errormsg";
+			echo ADD_PLUGIN_TO_PAGE_ERROR_CLOSING_PAGE_FILE_ERR . " " . CLICK_WORD . " <a href=\"add_plugin_to_page_select.php\" title=\"" . HERE_WORD . "\">" . HERE_WORD . "</a> " . ADD_PLUGIN_TO_PAGE_RETURN_TO_INSERT_PLUGIN_INTO_PAGE_CONSOLE_MSG . "\n$php_errormsg";
 			exit;
 		}
 	}
@@ -262,8 +160,14 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 	//If plugin is selected, then insert content code snippet after <!--content_code--> comment.
 	if (($plugin != "-not selected-") && ($content_code != ""))
 	{
-		$page_temp_arr = explode("<!--content_code-->", $contents, 2);
+		$page_temp_arr = explode("<!--content_code-->", $contents, 5);
 		$contents = $page_temp_arr[0] . $content_code . "\n\n<!--content_code-->\n" . $page_temp_arr[1];
+		if (isset($page_temp_arr[2]))
+			$contents .= $content_code . "\n\n<!--content_code-->\n" . $page_temp_arr[2];
+		if (isset($page_temp_arr[3]))
+			$contents .= $content_code . "\n\n<!--content_code-->\n" . $page_temp_arr[3];
+		if (isset($page_temp_arr[4]))
+			$contents .= $content_code . "\n\n<!--content_code-->\n" . $page_temp_arr[4];
 		unset($page_temp_arr);
 	}
 		
@@ -288,8 +192,12 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 	{
 		if (strpos($page_template, "<!--top_code-->") > 0)
 		{
-			$page_temp_arr = explode("<!--top_code-->", $contents, 2);
+			$page_temp_arr = explode("<!--top_code-->", $contents, 4);
 			$contents = $page_temp_arr[0] . $top_code . "\n\n<!--top_code-->\n" . $page_temp_arr[1];
+			if (isset($page_temp_arr[2]))
+				$contents .= $top_code . "\n\n<!--top_code-->\n" . $page_temp_arr[2];
+			if (isset($page_temp_arr[3]))
+				$contents .= $top_code . "\n\n<!--top_code-->\n" . $page_temp_arr[3];
 			unset($page_temp_arr);
 		}
 	}
@@ -299,8 +207,12 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 	{
 		if (strpos($page_template, "<!--left_code-->") > 0)
 		{
-			$page_temp_arr = explode("<!--left_code-->", $contents, 2);
+			$page_temp_arr = explode("<!--left_code-->", $contents, 4);
 			$contents = $page_temp_arr[0] . $left_code . "\n\n<!--left_code-->\n" . $page_temp_arr[1];
+			if (isset($page_temp_arr[2]))
+				$contents .= $left_code . "\n\n<!--left_code-->\n" . $page_temp_arr[2];
+			if (isset($page_temp_arr[3]))
+				$contents .= $left_code . "\n\n<!--left_code-->\n" . $page_temp_arr[3];
 			unset($page_temp_arr);
 		}
 	}
@@ -310,8 +222,12 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 	{
 		if (strpos($page_template, "<!--right_code-->") > 0)
 		{
-			$page_temp_arr = explode("<!--right_code-->", $contents, 2);
+			$page_temp_arr = explode("<!--right_code-->", $contents, 4);
 			$contents = $page_temp_arr[0] . $right_code . "\n\n<!--right_code-->\n" . $page_temp_arr[1];
+			if (isset($page_temp_arr[2]))
+				$contents .= $right_code . "\n\n<!--right_code-->\n" . $page_temp_arr[2];
+			if (isset($page_temp_arr[3]))
+				$contents .= $right_code . "\n\n<!--right_code-->\n" . $page_temp_arr[3];
 			unset($page_temp_arr);
 		}
 	}
@@ -321,226 +237,273 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 	{
 		if (strpos($page_template, "<!--bottom_code-->") > 0)
 		{
-			$page_temp_arr = explode("<!--bottom_code-->", $contents, 2);
+			$page_temp_arr = explode("<!--bottom_code-->", $contents, 4);
 			$contents = $page_temp_arr[0] . $bottom_code . "\n\n<!--bottom_code-->\n" . $page_temp_arr[1];
+			if (isset($page_temp_arr[2]))
+				$contents .= $bottom_code . "\n\n<!--bottom_code-->\n" . $page_temp_arr[2];
+			if (isset($page_temp_arr[3]))
+				$contents .= $bottom_code . "\n\n<!--bottom_code-->\n" . $page_temp_arr[3];
 			unset($page_temp_arr);
 		}
 	}
 	
 	if (!($fh = fopen($file_name, 'w'))) {
-		echo "Error opening page file.  Please contact your system administrator.  Click <a href=\"add_plugin_to_page_select.php\" title=\"here\">here</a> to return to the insert-plugin-into-page console.\n$php_errormsg";
+		echo ADD_PLUGIN_TO_PAGE_ERROR_OPENING_PAGE_FILE_ERR . " " . CLICK_WORD . " <a href=\"add_plugin_to_page_select.php\" title=\"" . HERE_WORD . "\">" . HERE_WORD . "</a> " . ADD_PLUGIN_TO_PAGE_RETURN_TO_INSERT_PLUGIN_INTO_PAGE_CONSOLE_MSG . "\n$php_errormsg";
 		exit;
 	}
 	if (!fwrite($fh, $contents)) {
-		echo "Error updating page file.  Please contact your system administrator.  Click <a href=\"add_plugin_to_page_select.php\" title=\"here\">here</a> to return to the insert-plugin-into-page console.\n$php_errormsg";
+		echo ADD_PLUGIN_TO_PAGE_ERROR_UPDATING_PAGE_FILE_ERR . " " . CLICK_WORD . " <a href=\"add_plugin_to_page_select.php\" title=\"" . HERE_WORD . "\">" . HERE_WORD . "</a> " . ADD_PLUGIN_TO_PAGE_RETURN_TO_INSERT_PLUGIN_INTO_PAGE_CONSOLE_MSG . "\n$php_errormsg";
 		exit;
 	}
 	if (!fclose($fh)) {
-		echo "Error closing page file.  Please contact your system administrator.  Click <a href=\"add_plugin_to_page_select.php\" title=\"here\">here</a> to return to the insert-plugin-into-page console.\n$php_errormsg";
+		echo ADD_PLUGIN_TO_PAGE_ERROR_CLOSING_PAGE_FILE_ERR . " " . CLICK_WORD . " <a href=\"add_plugin_to_page_select.php\" title=\"" . HERE_WORD . "\">" . HERE_WORD . "</a> " . ADD_PLUGIN_TO_PAGE_RETURN_TO_INSERT_PLUGIN_INTO_PAGE_CONSOLE_MSG . "\n$php_errormsg";
 		exit;
 	}
 	@chmod($file_name, 0644);
-	
-	
-	/////////////////////////////////////////////////////////////////////////////////////////
-	$search_str_head = "head_name='head";
-	$search_str_right = "page_name='right";
-	$search_str_left = "page_name='left";
-	$search_str_top = "page_name='top";
-	$search_str_bottom = "page_name='bottom";
-	$search_str_header = "page_name='header";
-	$search_str_footer = "page_name='footer";
-		
-	$start_pos = strpos($contents, $search_str_head, 1);
-	$end_pos = strpos($contents, "\"", $start_pos) - 1;
-	$start_pos = $start_pos + strlen("head_name='");
-	$head_str = substr($contents, $start_pos, $end_pos - $start_pos);
-
-	$start_pos = strpos($contents, $search_str_right, 1);
-	if ($start_pos !== false)
-	{
-		$end_pos = strpos($contents, "\"", $start_pos) - 1;
-		$start_pos = $start_pos + strlen("page_name='");
-		$right_str = substr($contents, $start_pos, $end_pos - $start_pos);
-	}
-	else
-		$right_str = "-na-";
-	
-	$start_pos = strpos($contents, $search_str_left, 1);
-	if ($start_pos !== false)
-	{
-		$end_pos = strpos($contents, "\"", $start_pos) - 1;
-		$start_pos = $start_pos + strlen("page_name='");
-		$left_str = substr($contents, $start_pos, $end_pos - $start_pos);
-	}
-	else
-		$left_str = "-na-";
-	
-	$start_pos = strpos($contents, $search_str_top, 1);
-	if ($start_pos !== false)
-	{
-		$end_pos = strpos($contents, "\"", $start_pos) - 1;
-		$start_pos = $start_pos + strlen("page_name='");
-		$top_str = substr($contents, $start_pos, $end_pos - $start_pos);
-	}
-	else
-		$top_str = "-na-";
-	
-	$start_pos = strpos($contents, $search_str_bottom, 1);
-	if ($start_pos !== false)
-	{
-		$end_pos = strpos($contents, "\"", $start_pos) - 1;
-		$start_pos = $start_pos + strlen("page_name='");
-		$bottom_str = substr($contents, $start_pos, $end_pos - $start_pos);
-	}
-	else
-		$bottom_str = "-na-";
-		
-	$start_pos = strpos($contents, $search_str_header, 1);
-	if ($start_pos !== false)
-	{
-		$end_pos = strpos($contents, "\"", $start_pos) - 1;
-		$start_pos = $start_pos + strlen("page_name='");
-		$header_str = substr($contents, $start_pos, $end_pos - $start_pos);
-	}
-	else
-		$header_str = "-na-";
-		
-	$start_pos = strpos($contents, $search_str_footer, 1);
-	if ($start_pos !== false)
-	{
-		$end_pos = strpos($contents, "\"", $start_pos) - 1;
-		$start_pos = $start_pos + strlen("page_name='");
-		$footer_str = substr($contents, $start_pos, $end_pos - $start_pos);
-	}
-	else
-		$footer_str = "-na-";
-
 
 	/////////////////////////////////////////////////////////////////////////////////////////
 	// If plugin is selected, then replace HTML head holder with head code snippet.
 	if (($plugin != "-not selected-") && (isset($head_html)) && ($head_html != ""))
 	{
 		// Get head content from main head.  Most likely that we want this as default.  Can edit later.
-		$query = "SELECT head_content FROM " . BWB_TABLE_PREFIX . "head WHERE head_name = '" . $head_str . "'";
+		$query = "SELECT head_content FROM " . BWB_TABLE_PREFIX . "head WHERE head_name = '" . $head_name . "'";
 		$result = $bwb_dbh->query($query);
 		$row = $result->fetch(PDO::FETCH_ASSOC);
 		$head_content = $row["head_content"];
 		
+		// If head is default head, then create a new head based on page name.
+		$new = false;
+		if ($head_name == "head")
+		{
+			$head_name .= "_" . $page_name;
+			$query = "SELECT head_name FROM " . BWB_TABLE_PREFIX . "head WHERE head_name = '" . $head_name . "'";
+			$result = $bwb_dbh->query($query);
+			if ($result->rowCount() > 0)
+				$head_name .= time();
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET head_name='" . $head_name. "' WHERE page_name='" . $page_name . "'";
+			$cnt = $bwb_dbh->exec($query);
+			$new = true;
+		}
+		
 		// Combine HTML (Javascript) code with default head content.
 		$head_content = $head_content . "\n\n\n" . $head_html;
 		$head_content = addslashes(stripslashes($head_content));
 		
 		// Insert new head into table.
-		$query = "UPDATE " . BWB_TABLE_PREFIX . "head SET head_content = '" . $head_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "' WHERE head_name = '" . $head_str . "'";
+		if ($new === true)
+			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "head SET head_content = '" . $head_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "', head_name = '" . $head_name . "'";
+		else
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "head SET head_content = '" . $head_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "' WHERE head_name = '" . $head_name . "'";
 		$cnt = $bwb_dbh->exec($query);
 	}
 	
 	//If plugin is selected, then replace HTML header holder with header HTML code snippet.
-	if (($plugin != "-not selected-") && (isset($header_html)) && ($header_html != "") && ($header_str != "-na-"))
+	if (($plugin != "-not selected-") && (isset($header_html)) && ($header_html != ""))
 	{	
 		// Get header content from main header.  Most likely that we want this as default.  Can edit later.
-		$query = "SELECT page_content FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '" . $header_str . "'";
+		$query = "SELECT page_content FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '" . $header_name . "'";
 		$result = $bwb_dbh->query($query);
 		$row = $result->fetch(PDO::FETCH_ASSOC);
 		$header_content = $row["page_content"];
 		
+		// If header is default header, then create a new header based on page name.
+		$new = false;
+		if ($header_name == "header")
+		{
+			$header_name .= "_" . $page_name;
+			$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '" . $header_name . "'";
+			$result = $bwb_dbh->query($query);
+			if ($result->rowCount() > 0)
+				$header_name .= time();
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET header_name='" . $header_name . "' WHERE page_name='" . $page_name. "'";
+			$cnt = $bwb_dbh->exec($query);
+			$new = true;
+		}
+		
 		// Combine HTML (Javascript) code with default header content.
 		$header_content = $header_content . "\n\n\n" . $header_html;
 		$header_content = addslashes(stripslashes($header_content));
 		
 		// Insert new header into table.
-		$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $header_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "' WHERE page_name = '" . $header_str . "'";
+		if ($new === true)
+			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $header_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "', page_name = '" . $header_name . "'";
+		else
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $header_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "' WHERE page_name = '" . $header_name . "'";
 		$cnt = $bwb_dbh->exec($query);
 	}
 	
 	//If plugin is selected, then replace HTML footer holder with footer HTML code snippet.
-	if (($plugin != "-not selected-") && (isset($footer_html)) && ($footer_html != "") && ($footer_str != "-na-"))
+	if (($plugin != "-not selected-") && (isset($footer_html)) && ($footer_html != ""))
 	{
 		// Get footer content from main footer.  Most likely that we want this as default.  Can edit later.
-		$query = "SELECT page_content FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '" . $footer_str . "'";
+		$query = "SELECT page_content FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '" . $footer_name . "'";
 		$result = $bwb_dbh->query($query);
 		$row = $result->fetch(PDO::FETCH_ASSOC);
 		$footer_content = $row["page_content"];
 		
+		// If footer is default footer, then create a new footer based on page name.
+		$new = false;
+		if ($footer_name == "footer")
+		{
+			$footer_name .= "_" . $page_name;
+			$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '" . $footer_name . "'";
+			$result = $bwb_dbh->query($query);
+			if ($result->rowCount() > 0)
+				$footer_name .= time();
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET footer_name='" . $footer_name . "' WHERE page_name='" . $page_name. "'";
+			$cnt = $bwb_dbh->exec($query);
+			$new = true;
+		}
+		
 		// Combine HTML (Javascript) code with default footer content.
 		$footer_content = $footer_content . "\n\n\n" . $footer_html;
 		$footer_content = addslashes(stripslashes($footer_content));
 		
 		// Insert new footer into table.
-		$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $footer_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "' WHERE page_name = '" . $footer_str . "'";
+		if ($new === true)
+			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $footer_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "', page_name = '" . $footer_name . "'";
+		else
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $footer_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "' WHERE page_name = '" . $footer_name . "'";
 		$cnt = $bwb_dbh->exec($query);
 	}
 	
 	//If plugin is selected, then append HTML code snippet to top.
-	if (($plugin != "-not selected-") && (isset($top_html)) && ($top_html != "") && ($top_str != "-na-"))
+	if (($plugin != "-not selected-") && (isset($top_html)) && ($top_html != ""))
 	{
 		// Get footer content from main footer.  Most likely that we want this as default.  Can edit later.
-		$query = "SELECT page_content FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '" . $top_str . "'";
+		$query = "SELECT page_content FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '" . $top_name . "'";
 		$result = $bwb_dbh->query($query);
 		$row = $result->fetch(PDO::FETCH_ASSOC);
 		$top_content = $row["page_content"];
 		
+		// If top is default top, then create a new top based on page name.
+		$new = false;
+		if ($top_name == "top")
+		{
+			$top_name .= "_" . $page_name;
+			$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '" . $top_name . "'";
+			$result = $bwb_dbh->query($query);
+			if ($result->rowCount() > 0)
+				$top_name .= time();
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET top_name='" . $top_name . "' WHERE page_name='" . $page_name. "'";
+			$cnt = $bwb_dbh->exec($query);
+			$new = true;
+		}
+		
 		// Combine HTML (Javascript) code with default top content.
 		$top_content = $top_content . "\n\n\n" . $top_html;
 		$top_content = addslashes(stripslashes($top_content));
 		
 		// Insert new top into table.
-		$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $top_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "' WHERE page_name = '" . $top_str . "'";
+		if ($new === true)
+			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $top_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "', page_name = '" . $top_name . "'";
+		else
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $top_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "' WHERE page_name = '" . $top_name . "'";
 		$cnt = $bwb_dbh->exec($query);
 	}
 	
 	//If plugin is selected, then append HTML code snippet to left.
-	if (($plugin != "-not selected-") && (isset($left_html)) && ($left_html != "") && ($left_str = "-na-"))
+	if (($plugin != "-not selected-") && (isset($left_html)) && ($left_html != ""))
 	{
 		// Get footer content from main footer.  Most likely that we want this as default.  Can edit later.
-		$query = "SELECT page_content FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '" . $left_str . "'";
+		$query = "SELECT page_content FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '" . $left_name . "'";
 		$result = $bwb_dbh->query($query);
 		$row = $result->fetch(PDO::FETCH_ASSOC);
 		$left_content = $row["page_content"];
 		
+		// If left is default left, then create a new left based on page name.
+		$new = false;
+		if ($left_name == "left")
+		{
+			$left_name .= "_" . $page_name;
+			$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '" . $left_name . "'";
+			$result = $bwb_dbh->query($query);
+			if ($result->rowCount() > 0)
+				$left_name .= time();
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET left_name='" . $left_name . "' WHERE page_name='" . $page_name. "'";
+			$cnt = $bwb_dbh->exec($query);
+			$new = true;
+		}
+		
 		// Combine HTML (Javascript) code with default left content.
 		$left_content = $left_content . "\n\n\n" . $left_html;
 		$left_content = addslashes(stripslashes($left_content));
 		
 		// Insert new top into table.
-		$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $left_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "' WHERE page_name = '" . $left_str . "'";
+		if ($new === true)
+			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $left_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "', page_name = '" . $left_name . "'";
+		else
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $left_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "' WHERE page_name = '" . $left_name . "'";
 		$cnt = $bwb_dbh->exec($query);
 	}
 	
 	//If plugin is selected, then append HTML code snippet to right.
-	if (($plugin != "-not selected-") && (isset($right_html)) && ($right_html != "") && ($right_str != "-na-"))
+	if (($plugin != "-not selected-") && (isset($right_html)) && ($right_html != ""))
 	{
 		// Get footer content from main footer.  Most likely that we want this as default.  Can edit later.
-		$query = "SELECT page_content FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '" . $right_str . "'";
+		$query = "SELECT page_content FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '" . $right_name . "'";
 		$result = $bwb_dbh->query($query);
 		$row = $result->fetch(PDO::FETCH_ASSOC);
 		$right_content = $row["page_content"];
 		
+		// If right is default right, then create a new right based on page name.
+		$new = false;
+		if ($right_name == "right")
+		{
+			$right_name .= "_" . $page_name;
+			$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '" . $right_name . "'";
+			$result = $bwb_dbh->query($query);
+			if ($result->rowCount() > 0)
+				$right_name .= time();
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET right_name='" . $right_name . "' WHERE page_name='" . $page_name. "'";
+			$cnt = $bwb_dbh->exec($query);
+			$new = true;
+		}
+		
 		// Combine HTML (Javascript) code with default right content.
 		$right_content = $right_content . "\n\n\n" . $right_html;
 		$right_content = addslashes(stripslashes($right_content));
 		
 		// Insert new top into table.
-		$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $right_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "' WHERE page_name = '" . $right_str . "'";
+		if ($new === true)
+			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $right_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "', page_name = '" . $right_name . "'";
+		else
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $right_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "' WHERE page_name = '" . $right_name . "'";
 		$cnt = $bwb_dbh->exec($query);
 	}
 	
 	//If plugin is selected, then append HTML code snippet to bottom.
-	if (($plugin != "-not selected-") && (isset($bottom_html)) && ($bottom_html != "") && ($bottom_str != "-na-"))
+	if (($plugin != "-not selected-") && (isset($bottom_html)) && ($bottom_html != ""))
 	{
 		// Get footer content from main footer.  Most likely that we want this as default.  Can edit later.
-		$query = "SELECT page_content FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '" . $bottom_str . "'";
+		$query = "SELECT page_content FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '" . $bottom_name . "'";
 		$result = $bwb_dbh->query($query);
 		$row = $result->fetch(PDO::FETCH_ASSOC);
 		$bottom_content = $row["page_content"];
 		
+		// If bottom is default bottom, then create a new bottom based on page name.
+		$new = false;
+		if ($bottom_name == "bottom")
+		{
+			$bottom_name .= "_" . $page_name;
+			$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '" . $bottom_name . "'";
+			$result = $bwb_dbh->query($query);
+			if ($result->rowCount() > 0)
+				$bottom_name .= time();
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET bottom_name='" . $bottom_name . "' WHERE page_name='" . $page_name. "'";
+			$cnt = $bwb_dbh->exec($query);
+			$new = true;
+		}
+		
 		// Combine HTML (Javascript) code with default bottom content.
 		$bottom_content = $bottom_content . "\n\n\n" . $bottom_html;
 		$bottom_content = addslashes(stripslashes($bottom_content));
 		
 		// Insert new top into table.
-		$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $bottom_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "' WHERE page_name = '" . $bottom_str . "'";
+		if ($new === true)
+			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $bottom_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "', page_name = '" . $bottom_name . "'";
+		else
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content = '" . $bottom_content . "', `revised` = '" . $today . "', plugins = '" . $plugin_ids . "' WHERE page_name = '" . $bottom_name . "'";
 		$cnt = $bwb_dbh->exec($query);
 	}
 	
@@ -569,16 +532,17 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 		{
 			$class_table = $style_sheet . "_classes";
 			copy_table_structure($class_table, BWB_TABLE_PREFIX, $bwb_dbh, $bwb_database);
-			$result = $bwb_dbh->query($class_sql);
+			$result = RunSQL($class_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
 		}
 		
 		if (isset($css_sql) && ($css_sql != ""))
 		{
 			$site_css_table = $style_sheet . "_css";
 			copy_table_structure($site_css_table, BWB_TABLE_PREFIX, $bwb_dbh, $bwb_database);
-			$result = $bwb_dbh->query($css_sql);
+			$result = RunSQL($css_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
 			
-			include ("build_css_string.php");
+			include ("lib/build_css_string.php");
+			$css_string = BuildCSSString(BWB_TABLE_PREFIX . $site_css_table, BWB_TABLE_PREFIX . $class_table, $bwb_dbh, BWB_BASE_DIR, BWB_IMAGE_DIR, BWB_TABLE_PREFIX . "fonts");
 			////////////////////////////////////////////////////////
 			/// Write menu items to menu.css file /////////////
 			//Test to see if file already exists.
@@ -594,7 +558,7 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 			{
 				$bkup_file_name = $file_name . time();
 				if (!rename($file_name, $bkup_file_name))
-					echo "Could not rename $file_name to $bkup_file_name.<br>";
+					echo ADD_PLUGIN_TO_PAGE_COULD_NOT_RENAME_MSG . " $file_name " . TO_WORD . " $bkup_file_name.<br>";
 				@chmod($bkup_file_name, 0644);
 			}
 			
@@ -607,8 +571,7 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 		
 		if (isset($plugin_sql) && ($plugin_sql != ""))
 		{
-//			$result = $bwb_dbh->query($plugin_sql);
-			RunSQL($plugin_sql, BWB_TABLE_PREFIX, $bwb_dbh);
+			$result = RunSQL($plugin_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
 		}
 		
 		$query = "UPDATE " . BWB_TABLE_PREFIX . "plugins SET `deployed`=1 WHERE `id`=$plugin";
@@ -617,7 +580,10 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 	
 	//Go to edit page.
 	$domain = $_SERVER['HTTP_HOST'];
-	$web_path = "http://" . $domain;
+	if (BWB_REQUIRE_SSL == 1)
+		$web_path = "https://" . $domain;
+	else
+		$web_path = "http://" . $domain;
 	$php_self = $_SERVER['PHP_SELF'];
 	$this_file = substr(strrchr($php_self, "/"), 1);
 	$app_dir = substr($php_self, 0, (strlen($php_self)- strlen($this_file)));
