@@ -1,13 +1,17 @@
 <?php
 ////////////////////////////////////////////////////////////////////////
 // Breeze Website Builder
-// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
+// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
 // For licensing, see license.txt.
 // Created: 9/25/2014	ELL
+// Modified: 2/12/2015	ELL
+// Added reCAPTCHA API v.2.
 ?>
 <script language='javascript' type='text/javascript'>
 	if (document.getElementById('captcha_type').value != 'recaptcha')
 		document.getElementById('recaptcha_row').style.display = 'none';
+	if (document.getElementById('captcha_type').value != 'recaptcha2')
+		document.getElementById('recaptcha2_row').style.display = 'none';
 	if (document.getElementById('captcha_type').value != 'wscaptcha')
 		document.getElementById('wscaptcha_row').style.display = 'none';
 	if (document.getElementById('captcha_type').value != 'mollom')
@@ -25,4 +29,9 @@
 		var captcha_challange_url = "http://www.google.com/recaptcha/api/challenge?k=" + recaptcha_public_key;
 		document.getElementById("recaptcha_script").src = captcha_challange_url;
 	}
+	
+	if ((document.getElementById("captcha_type").value == "recaptcha2") && (document.getElementById("use_captcha").value == 1))
+		document.getElementById("recaptcha2_div").setAttribute("data-sitekey", recaptcha_site_key);
+	else
+		document.getElementById("recaptcha2_td").innerHTML = "";
 </script>
\ No newline at end of file
