@@ -3,10 +3,17 @@
 // This file contains the public and private keys to operate Google's reCAPTCHA code used in the reset password-function for the public side of your site. 
 // You will need to go to http://www.google.com/recaptcha to obtain a pair of keys for your site.
 //
+// reCAPTCHA API V2
+define('RECAPTCHA_SITE_KEY', '');
+
+define('RECAPTCHA_SECRET', '');
+
+// reCAPTCHA API V1
 define('RECAPTCHA_PUBLIC_KEY', '6LeGudMSAAAAAOkRJtut9PVOFIxedHgutbY-i1XT');
 
 define('RECAPTCHA_PRIVATE_KEY', '6LeGudMSAAAAAPyGPjLnAay4i85v1qL5xFV6KdSM');
 
+// Mollom CAPTCHA
 define('MOLLOM_PUBLIC_KEY', '');
 
 define('MOLLOM_PRIVATE_KEY', '');
