@@ -11,12 +11,12 @@
 	
 	include ("check_session.php");
 ?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml">
+<!DOCTYPE html>
+<html>
 <head>
 <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
-<title>Copy/Rename Page Select</title>
-<link rel="stylesheet" href="manager.css" type="text/css">
+<title>Copy/Rename Page Select | Breeze Website Builder</title>
+<link rel="stylesheet" href="theme/<?php echo $theme; ?>/manager.css" type="text/css">
 
 <style type="text/css">
 #help_button	{	
@@ -36,20 +36,20 @@
 	background-attachment:scroll;
 	background-repeat:no-repeat;
 	background-position: 5px 1px;
-	background-image:url(images/icon_Copy_Pg.png);
+	background-image:url(theme/<?php echo $theme; ?>/images/icon_Copy_Pg.png);
 }
 #copy_radio_btn:hover	{	
-	background-image:url(images/icon_Copy_Pg_mo.png);
+	background-image:url(theme/<?php echo $theme; ?>/images/icon_Copy_Pg_mo.png);
 }
 #rename_radio_btn	{
 	width:130px;
 	background-attachment:scroll;
 	background-repeat:no-repeat;
 	background-position: 5px 1px;
-	background-image:url(images/icon_Edit-Content.png);
+	background-image:url(theme/<?php echo $theme; ?>/images/icon_Edit-Content.png);
 }
 #rename_radio_btn:hover	{
-	background-image:url(images/icon_Edit-Content_mo.png);
+	background-image:url(theme/<?php echo $theme; ?>/images/icon_Edit-Content_mo.png);
 }
 </style>
 
@@ -57,20 +57,20 @@
 </head>
 
 <body>
-<div class="button_heading_sub_level_1" id="copy_rename_pages_heading"><div class="button_heading_text_sub_level_1">Copy or Rename Pages</div><div class="help_button" id="help_button" onclick="OpenHelpWindow();">&nbsp;</div></div>
+<div class="button_heading_sub_level_1" id="copy_rename_pages_heading"><div class="button_heading_text_sub_level_1"><?php echo COPY_RENAME_PAGE_HEADING; ?></div><div class="help_button" id="help_button" onclick="OpenHelpWindow();">&nbsp;</div></div>
 
  <div style="text-align:center; margin-top:20px;">
 	<form name="frmRenamePage" id="frmRenamePage" method="post" action="copy_rename_page.php">
     	<div class="radio_button" id="copy_radio_btn" onclick="document.getElementById('copy_mode[0]').checked = true; EnableDisableCreateNewTemplateCheckbox(document.getElementById('copy_mode[0]').value);">
-        <span class='radio_button_text'>Copy</span>
+        <span class='radio_button_text'><?php echo COPY_WORD; ?></span>
         <input name="copy_mode" id="copy_mode[0]" type="radio" value="copy" checked="checked" />
         </div>
-        or 
+        <?php echo OR_WORD; ?> 
         <div class="radio_button" id="rename_radio_btn" onclick="document.getElementById('copy_mode[1]').checked = true; EnableDisableCreateNewTemplateCheckbox(document.getElementById('copy_mode[1]').value);">
-        <span class='radio_button_text'>Rename</span>
+        <span class='radio_button_text'><?php echo RENAME_WORD; ?></span>
         <input name="copy_mode" id="copy_mode[1]" type="radio" value="rename" />
         </div>
-	   page
+	   <?php echo PAGE_WORD; ?>
 	  <select name="page_name" id="page_name" class="page_dropdown">
 		<?php
 			$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data ORDER BY page_name";
@@ -84,26 +84,24 @@
 			}
 		?>
 	  </select>
-		to	
+		<?php echo TO_WORD; ?>	
 		<input type="text" name="new_name" id="new_name" onkeyup="CheckPageName(this.value);" onselect="CheckPageName(this.value);" />
 	      <br>
           <label id="create_new_template_label">
 	      <input type="checkbox" name="create_new_template_check" id="create_new_template_check" onchange="TransferPageNameOnCheck(this);" />
           <input type="hidden" name="create_new_template" id="create_new_template" value="0" />
-	      Discard old page template and create new
+	      <?php echo COPY_RENAME_PAGE_DISCARD_TEMPLATE_NOTE; ?>
           </label>
 		<center style="margin-top:20px;">
           <div class="button_console_edit_disabled" id="copy_rename_btn" onClick="document.getElementById('frmRenamePage').submit();">
-          	<span class='button_console_text_w_icon'>Copy/Rename</span>
+          	<span class='button_console_text_w_icon'><?php echo COPY_RENAME_PAGE_COPY_RENAME_BTN; ?></span>
           </div>
 		</center>
         <input type="hidden" name="overwrite" value="0" />
         <input type="hidden" name="overwrite_content_only" value="0" />
 	  </form>
       <br /><br /><br /><br /><br /><br /><br />
-	<span class="small_message">Note: Renaming page will NOT change any links that you have created.
-	Menu items will be updated automatically, but you will need to change any
-	links that exist on any pages to reference the new page name.</span>
+	<span class="small_message"><?php echo COPY_RENAME_PAGE_RENAME_PAGE_LINK_NOTE; ?></span>
 </div>
 
 </body>
