@@ -48,6 +48,15 @@
 // when page is viewed.
 // Revised: 1/10/2015	ELL
 // Fixed bug with single quotes in plugin HTML doubling up in border areas and content.
+// Revised: 5/1/2015	ELL
+// Converted from inline RunSQL function to included library RunSQL function.
+// Revised: 8/19/2015	ELL
+// Added handling of new plugin feature body_onload field.
+// Revised: 10/2/2015	ELL
+// Added missing language defines.
+// Modified to set template field in page data record instead of pulling specific template.
+// Modified to set border area and head fields in page data record instead of parsing template layout file to insert custom border area references.
+// Added setting of body_onload function name as attribute it the page data table.
 //
 
 include ("check_session.php");
@@ -57,6 +66,9 @@ $plugin = $_POST['plugin'];
 $template_name = $_POST['template_name'];
 $mode = $_REQUEST['mode'];
 
+include("lib/run_sql.php");
+include ("lib/build_css_string.php");
+
 ////////////////////////////////////////////////////////////////////////////////////////////////
 function copy_table_structure($table, $table_prefix, $dbh, $database)
 {
@@ -71,143 +83,17 @@ function copy_table_structure($table, $table_prefix, $dbh, $database)
 			$source_table = $table_prefix . "site_classes";
 		else
 			$source_table = $table_prefix . "site_css";
-		$query = "CREATE TABLE IF NOT EXISTS " . $table_prefix . $table . " SELECT * FROM " . $source_table;
-		$cnt = $dbh->exec($query);
-		
-		$query = " ALTER TABLE `" . $table_prefix . $table . "` ADD PRIMARY KEY (`class`)";
+
+		$query = "CREATE TABLE " . $table_prefix . $table . " LIKE " . $source_table;
 		$cnt = $dbh->exec($query);
 	}
-	
-	$query = "TRUNCATE TABLE `" . $table_prefix . $table . "`";
-	$cnt = $dbh->exec($query);
 		
-	return "";
+	return 1;
 }
-	
-///////////////////////////////////////////////////////////////////////////////
-function RunSQL($sql_string, $table_prefix, $dbh)
-{
-	$sql_string = stripslashes($sql_string);
-	$sql_string_arr = array();
-	$line_arr = array();
-	// Split SQL input into lines.
-	$line_arr = preg_split("[\n|\r]", $sql_string);
-	$sql_string_arr[0] = "";
-	$j = 0;
-	$find_start = true;
-	$got_script = false;
-	$got_php = false;
-	$got_style = false;
-	// Search for commands and assemble into SQL command array.
-	for ($i = 0; $i < count($line_arr); $i++)
-	{
-		// Test for comment line.
-		$curr_line = trim($line_arr[$i]);
-		if ($find_start)
-		{
-			$first_chars = substr($curr_line, 0, 2);
-			if (($first_chars == "--") || ($first_chars == "//"))
-				continue;
-		}
-		$find_start = false;
-		
-		// It is possible for a line to end with a semicolon (;) if records contain JavaScript or PHP.  Need to turn off looking end of SQL command
-		// if script or PHP is found until end of script or PHP is also found.  Otherwise we run the risk of trying to run only part of a record insert
-		// which usually results in an SQL syntax error.
-		if (!$got_script)
-		{
-			if (stripos($curr_line, "<script") !== false)
-				$got_script = true;
-		}
-		if ($got_script)
-		{
-			if (stripos($curr_line, "</script>") !== false)
-				$got_script = false;
-		}
-		
-		if (!$got_php)
-		{
-			if (stripos($curr_line, "<?php") !== false)
-				$got_php = true;
-		}
-		if ($got_php)
-		{
-			if (stripos($curr_line, "?>") !== false)
-				$got_php = false;
-		}
-		
-		if (!$got_style)
-		{
-			if (stripos($curr_line, "<style") !== false)
-				$got_style = true;
-		}
-		if ($got_style)
-		{
-			if (stripos($curr_line, "</style>") !== false)
-				$got_style = false;
-		}
-		
-		// Build SQL command.
-		$sql_string_arr[$j] = $sql_string_arr[$j] . $line_arr[$i];
-		
-		// Look for end of command.
-		if ((!$got_script) && (!$got_php) && (!$got_style))
-		{
-			$last_char = substr($curr_line, (strlen($curr_line) - 1), 1);
-			if ($last_char == ";")	// Got end of SQL command.
-			{
-				// Check for other possible reasons that ; is at end of line.
-				$last_6_chars = substr($curr_line, (strlen($curr_line) - 7), 6);
-				if (stripos($curr_line, "&") === false) // Looks like ; is not do to & code, good to go.
-				{
-					$j++;
-					$sql_string_arr[$j] = "";
-					$find_start = true;
-				}
-			}
-		}
-	}
-	// Run SQL commands one at a time.
-	for ($i = 0; $i < count($sql_string_arr); $i++)
-	{
-		if (strlen($sql_string_arr[$i]) > 2)
-		{
-			if ($table_prefix != "bwb_")
-			{
-				$sql_string_arr[$i] = str_replace("bwb_link", "@@@link_retention@@@", $sql_string_arr[$i]);
-				$sql_string_arr[$i] = str_replace("bwb_", $table_prefix, $sql_string_arr[$i]);
-				$sql_string_arr[$i] = str_replace("@@@link_retention@@@", "bwb_link", $sql_string_arr[$i]);
-			}
-//			echo $sql_string_arr[$i] . "<br><br>\n";
-
-			try	{
-				$cnt = $dbh->exec($sql_string_arr[$i]);
-			} catch (Exception $e) {
-				echo $e->getMessage() . "<br>\n";
-			}
-			
-//			if (is_array($cnt))
-//			{
-//				echo "<pre>\n";
-//				print_r($cnt);
-//				echo "</pre>\n";
-//			}
-//			elseif ($cnt > 0)
-//				echo $cnt . " row(s) affected.<br>\n";
-//			else
-//				echo $bwb_dbh->errorInfo() . "<br>\n";
-				
-//			if ($i < (count($sql_string_arr) - 1))
-//				echo "<br>-------------------------------------------------------------------------------<br>\n";
-		}
-	}
-}
-
-///////////////////////////////////////////////////////////////////////////////
 
 	if ($page_name == "")
 	{
-		echo "Oops! You forgot to enter a page name.  Click <a href=\"create_page_select.php\" title=\"here\">here</a> and enter a page name.";
+		echo CREATE_PAGE_PAGE_NAME_BLANK_1_ERR . " " . CLICK_WORD . " <a href=\"create_page_select.php\" title=\"" . HERE_WORD . "\">" . HERE_WORD . "</a> " . CREATE_PAGE_PAGE_NAME_BLANK_2_ERR;
 		exit;
 	}
 	
@@ -240,7 +126,7 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 	$page_name_retrieved = $row["page_name"];
 	if ($page_name_retrieved)
 	{
-		echo "$file_name already exists in database.  Click <a href=\"create_page_select.php\" title=\"here\">here</a> to enter a different page name.";
+		echo $file_name . " " . CLASSES_ADD_CLASS_ADD_ERR . " " . CLICK_WORD . " <a href=\"create_page_select.php\" title=\"" . HERE_WORD . "\">" . HERE_WORD . "</a> " . CREATE_PAGE_PAGE_ALREADY_EXISTS_ERR;
 		exit;
 	}
 	
@@ -257,7 +143,7 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 			unlink($file_name);
 		else
 		{
-			echo "$file_name already exists.  Click <a href=\"create_page_select.php\" title=\"here\">here</a> to enter a different page name.";
+			echo $file_name . " " . MANAGE_CUSTOM_FONTS_ADDING_FONT_2_ERR . " " . CLICK_WORD . " <a href=\"create_page_select.php\" title=\"" . HERE_WORD . "\">" . HERE_WORD . "</a> " . CREATE_PAGE_PAGE_ALREADY_EXISTS_ERR;
 			exit;
 		}
 	}
@@ -295,6 +181,9 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 		$plugin_sql = $row["plugin_sql"];
 		$deployed = $row["deployed"];
 		$disable_site_styles = $row["disable_site_styles"];
+		$body_onload = $row["body_onload"];
+		$body_onload_function = $row["body_onload_function"];
+		$body_onload_function = (isset($row["body_onload_function"]) ? $row["body_onload_function"] : $page_name . "_load");
 		// Check template compatibility with plugin.
 		if (strpos($template_name, "top_bottom_left_right") < 0)
 		{
@@ -307,7 +196,7 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 			if ((isset($bottom_code) && ($bottom_code != "")) || (isset($bottom_html) && ($bottom_html != "")))
 				$need_bottom = true;
 				
-			if ($need_top && $need_left && $need_right && $need_bottom)
+			if ($need_top && $need_left && $need_right && $need_bottom && ($template_name != "top_bottom_left_right") && ($template_name != "top_bottom_left_right_alt") && ($template_name != "top_bottom_left_right_alt2"))
 				$template_name = "top_bottom_left_right";
 			elseif ($need_top && $need_left && $need_right && !$need_bottom && ((strpos($template_name, "top") < 0) || (strpos($template_name, "left") < 0) || (strpos($template_name, "right") < 0)))
 				$template_name = "top_left_right";
@@ -373,14 +262,18 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 	}
 	else
 	{
-		$content_html = "\n<p>Enter your content here.</p>\n";
+		$content_html = "\n<p>" . CREATE_PAGE_DEFAULT_CONTENT . "</p>\n";
 		$plugin_id = "";
+		$body_onload = 0;
+		$body_onload_function = $page_name . "_load";
+		$disable_site_styles = 0;
 	}
 	
 	//Add page name to database.
 	$today = date("Y-m-d H:i:s");
 	$page_content = addslashes(stripslashes($content_html));
-	$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data SET page_name='$page_name', page_content='$page_content', revised='$today', plugins='$plugin_id', disable_site_styles='$disable_site_styles', use_table_structure='$UseTableStructure', use_table_structure_mobile='$UseTableStructureMobile'";
+		
+	$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data SET page_name='$page_name', page_content='$page_content', template='$template_name', revised='$today', plugins='$plugin_id', disable_site_styles='$disable_site_styles', body_onload='$body_onload', body_onload_function='$body_onload_function', use_table_structure='$UseTableStructure', use_table_structure_mobile='$UseTableStructureMobile'";
 //	echo $query;
 	$cnt = $bwb_dbh->exec($query);
 
@@ -390,12 +283,12 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 	$cnt = $bwb_dbh->exec($query);
 
 	//Get template from database.
-	$query = "SELECT `page_template` FROM `" . BWB_TABLE_PREFIX . "template` WHERE `template_name` = '$template_name'";
+	$query = "SELECT `page_template` FROM `" . BWB_TABLE_PREFIX . "template` WHERE `template_name` = 'all'";
 	$result = $bwb_dbh->query($query);
 	$row = $result->fetch(PDO::FETCH_ASSOC);
 	$page_template = $row["page_template"];
-	
-	//Insert page name into template.
+
+//Insert page name into template.
 	$zzz_found = false;
 	if ($page_name == "zzz")	{
 		$page_template = str_replace("xxx", "-ZZZ-", $page_template);
@@ -430,8 +323,14 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 	//If plugin is selected, then insert content code snippet after <!--content_code--> comment.
 	if (($plugin != "-not selected-") && ($content_code != ""))
 	{
-		$page_temp_arr = explode("<!--content_code-->", $page_template, 2);
+		$page_temp_arr = explode("<!--content_code-->", $page_template, 5);
 		$page_template = $page_temp_arr[0] . $content_code . "\n\n<!--content_code-->\n" . $page_temp_arr[1];
+		if (isset($page_temp_arr[2]))
+			$page_template .= $content_code . "\n\n<!--content_code-->\n" . $page_temp_arr[2];
+		if (isset($page_temp_arr[3]))
+			$page_template .= $content_code . "\n\n<!--content_code-->\n" . $page_temp_arr[3];
+		if (isset($page_temp_arr[4]))
+			$page_template .= $content_code . "\n\n<!--content_code-->\n" . $page_temp_arr[4];
 		unset($page_temp_arr);
 	}
 		
@@ -454,45 +353,49 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 	//If plugin is selected, then insert top code snippet after <!--top_code--> comment.
 	if (($plugin != "-not selected-") && ($top_code != ""))
 	{
-		if (strpos($page_template, "<!--top_code-->") > 0)
-		{
-			$page_temp_arr = explode("<!--top_code-->", $page_template, 2);
-			$page_template = $page_temp_arr[0] . $top_code . "\n\n<!--top_code-->\n" . $page_temp_arr[1];
-			unset($page_temp_arr);
-		}
+		$page_temp_arr = explode("<!--top_code-->", $page_template, 4);
+		$page_template = $page_temp_arr[0] . $top_code . "\n\n<!--top_code-->\n" . $page_temp_arr[1];
+		if (isset($page_temp_arr[2]))
+			$page_template .= $top_code . "\n\n<!--top_code-->\n" . $page_temp_arr[2];
+		if (isset($page_temp_arr[3]))
+			$page_template .= $top_code . "\n\n<!--top_code-->\n" . $page_temp_arr[3];
+		unset($page_temp_arr);
 	}
 	
 	//If plugin is selected, then insert left code snippet after <!--left_code--> comment.
 	if (($plugin != "-not selected-") && ($left_code != ""))
 	{
-		if (strpos($page_template, "<!--left_code-->") > 0)
-		{
-			$page_temp_arr = explode("<!--left_code-->", $page_template, 2);
-			$page_template = $page_temp_arr[0] . $left_code . "\n\n<!--left_code-->\n" . $page_temp_arr[1];
-			unset($page_temp_arr);
-		}
+		$page_temp_arr = explode("<!--left_code-->", $page_template, 4);
+		$page_template = $page_temp_arr[0] . $left_code . "\n\n<!--left_code-->\n" . $page_temp_arr[1];
+		if (isset($page_temp_arr[2]))
+			$page_template .= $left_code . "\n\n<!--left_code-->\n" . $page_temp_arr[2];
+		if (isset($page_temp_arr[3]))
+			$page_template .= $left_code . "\n\n<!--left_code-->\n" . $page_temp_arr[3];
+		unset($page_temp_arr);
 	}
 	
 	//If plugin is selected, then insert right code snippet after <!--right_code--> comment.
 	if (($plugin != "-not selected-") && ($right_code != ""))
 	{
-		if (strpos($page_template, "<!--right_code-->") > 0)
-		{
-			$page_temp_arr = explode("<!--right_code-->", $page_template, 2);
-			$page_template = $page_temp_arr[0] . $right_code . "\n\n<!--right_code-->\n" . $page_temp_arr[1];
-			unset($page_temp_arr);
-		}
+		$page_temp_arr = explode("<!--right_code-->", $page_template, 4);
+		$page_template = $page_temp_arr[0] . $right_code . "\n\n<!--right_code-->\n" . $page_temp_arr[1];
+		if (isset($page_temp_arr[2]))
+			$page_template .= $right_code . "\n\n<!--right_code-->\n" . $page_temp_arr[2];
+		if (isset($page_temp_arr[3]))
+			$page_template .= $right_code . "\n\n<!--right_code-->\n" . $page_temp_arr[3];
+		unset($page_temp_arr);
 	}
 	
 	//If plugin is selected, then insert bottom code snippet after <!--bottom_code--> comment.
 	if (($plugin != "-not selected-") && ($bottom_code != ""))
 	{
-		if (strpos($page_template, "<!--bottom_code-->") > 0)
-		{
-			$page_temp_arr = explode("<!--bottom_code-->", $page_template, 2);
-			$page_template = $page_temp_arr[0] . $bottom_code . "\n\n<!--bottom_code-->\n" . $page_temp_arr[1];
-			unset($page_temp_arr);
-		}
+		$page_temp_arr = explode("<!--bottom_code-->", $page_template, 4);
+		$page_template = $page_temp_arr[0] . $bottom_code . "\n\n<!--bottom_code-->\n" . $page_temp_arr[1];
+		if (isset($page_temp_arr[2]))
+			$page_template .= $bottom_code . "\n\n<!--bottom_code-->\n" . $page_temp_arr[2];
+		if (isset($page_temp_arr[3]))
+			$page_template .= $bottom_code . "\n\n<!--bottom_code-->\n" . $page_temp_arr[3];
+		unset($page_temp_arr);
 	}
 
 	//If plugin is selected, then replace HTML head holder with head code snippet.
@@ -520,9 +423,9 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "head (head_name, head_content, `revised`, plugins) VALUES ('" . $head_name . "', '" . $head_content . "', '" . $today . "', '" . $plugin_id . "')";
 		$cnt = $bwb_dbh->exec($query);
 		
-		// Replace reference to head content in template.
-		$head_str = "head_name='" . $head_name . "'";
-		$page_template = str_replace("head_name='head'", $head_str, $page_template);
+		// Update head name in page record.
+		$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET head_name='$head_name' WHERE page_name='$page_name'";
+		$cnt = $bwb_dbh->exec($query);
 	}
 	
 	//If plugin is selected, then replace HTML header holder with header HTML code snippet.
@@ -550,9 +453,9 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special (page_name, page_content, `revised`, plugins) VALUES ('" . $header_name . "', '" . $header_content . "', '" . $today . "', '" . $plugin_id . "')";
 		$cnt = $bwb_dbh->exec($query);
 		
-		// Replace reference to header content in template.
-		$header_str = "page_name='" . $header_name . "'";
-		$page_template = str_replace("page_name='header'", $header_str, $page_template);
+		// Update header name in page record.
+		$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET header_name='$header_name' WHERE page_name='$page_name'";
+		$cnt = $bwb_dbh->exec($query);
 	}
 
 	//If plugin is selected, then replace HTML footer holder with footer HTML code snippet.
@@ -580,9 +483,9 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special (page_name, page_content, `revised`, plugins) VALUES ('" . $footer_name . "', '" . $footer_content . "', '" . $today . "', '" . $plugin_id . "')";
 		$cnt = $bwb_dbh->exec($query);
 		
-		// Replace reference to footer content in template.
-		$footer_str = "page_name='" . $footer_name . "'";
-		$page_template = str_replace("page_name='footer'", $footer_str, $page_template);
+		// Update footer name in page record.
+		$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET footer_name='$footer_name' WHERE page_name='$page_name'";
+		$cnt = $bwb_dbh->exec($query);
 	}
 
 	//If plugin is selected, then append HTML code snippet to top.
@@ -610,9 +513,9 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special (page_name, page_content, `revised`, plugins) VALUES ('" . $top_name . "', '" . $top_content . "', '" . $today . "', '" . $plugin_id . "')";
 		$cnt = $bwb_dbh->exec($query);
 		
-		// Replace reference to top content in template.
-		$top_str = "page_name='" . $top_name . "'";
-		$page_template = str_replace("page_name='top'", $top_str, $page_template);
+		// Update top name in page record.
+		$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET top_name='$top_name' WHERE page_name='$page_name'";
+		$cnt = $bwb_dbh->exec($query);
 	}
 	
 	//If plugin is selected, then append HTML code snippet to left.
@@ -640,9 +543,9 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special (page_name, page_content, `revised`, plugins) VALUES ('" . $left_name . "', '" . $left_content . "', '" . $today . "', '" . $plugin_id . "')";
 		$cnt = $bwb_dbh->exec($query);
 		
-		// Replace reference to top content in template.
-		$left_str = "page_name='" . $left_name . "'";
-		$page_template = str_replace("page_name='left'", $left_str, $page_template);
+		// Update left name in page record.
+		$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET left_name='$left_name' WHERE page_name='$page_name'";
+		$cnt = $bwb_dbh->exec($query);
 	}
 	
 	//If plugin is selected, then append HTML code snippet to right.
@@ -670,9 +573,9 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special (page_name, page_content, `revised`, plugins) VALUES ('" . $right_name . "', '" . $right_content . "', '" . $today . "', '" . $plugin_id . "')";
 		$cnt = $bwb_dbh->exec($query);
 		
-		// Replace reference to top content in template.
-		$right_str = "page_name='" . $right_name . "'";
-		$page_template = str_replace("page_name='right'", $right_str, $page_template);
+		// Update right name in page record.
+		$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET right_name='$right_name' WHERE page_name='$page_name'";
+		$cnt = $bwb_dbh->exec($query);
 	}
 	
 	//If plugin is selected, then append HTML code snippet to bottom.
@@ -700,9 +603,9 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special (page_name, page_content, `revised`, plugins) VALUES ('" . $bottom_name . "', '" . $bottom_content . "', '" . $today . "', '" . $plugin_id . "')";
 		$cnt = $bwb_dbh->exec($query);
 		
-		// Replace reference to top content in template.
-		$bottom_str = "page_name='" . $bottom_name . "'";
-		$page_template = str_replace("page_name='bottom'", $bottom_str, $page_template);
+		// Update bottom name in page record.
+		$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET bottom_name='$bottom_name' WHERE page_name='$page_name'";
+		$cnt = $bwb_dbh->exec($query);
 	}
 			
 	// Create file.
@@ -736,17 +639,17 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 				if (isset($class_sql) && ($class_sql != ""))
 				{
 					$class_table = $style_sheet . "_classes";
-					copy_table_structure($class_table, BWB_TABLE_PREFIX, $bwb_dbh, $bwb_database);
-					$result = $bwb_dbh->query($class_sql);
+					$result = copy_table_structure($class_table, BWB_TABLE_PREFIX, $bwb_dbh, $bwb_database);
+					$result = RunSQL($class_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
 				}
 				
 				if (isset($css_sql) && ($css_sql != ""))
 				{
 					$site_css_table = $style_sheet . "_css";
-					copy_table_structure($site_css_table, BWB_TABLE_PREFIX, $bwb_dbh, $bwb_database);
-					$result = $bwb_dbh->query($css_sql);
+					$result = copy_table_structure($site_css_table, BWB_TABLE_PREFIX, $bwb_dbh, $bwb_database);
+					$result = RunSQL($css_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
 					
-					include ("build_css_string.php");
+					$css_string = BuildCSSString(BWB_TABLE_PREFIX . $site_css_table, BWB_TABLE_PREFIX . $class_table, $bwb_dbh, BWB_BASE_DIR, BWB_IMAGE_DIR, BWB_TABLE_PREFIX . "fonts");
 					////////////////////////////////////////////////////////
 					/// Write menu items to menu.css file /////////////
 					//Test to see if file already exists.
@@ -762,22 +665,21 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 					{
 						$bkup_file_name = $file_name . time();
 						if (!rename($file_name, $bkup_file_name))
-							echo "Could not rename $file_name to $bkup_file_name.<br>";
+							echo EDIT_CSS_COULD_NOT_RENAME_1_ERR . " $file_name " . EDIT_CSS_COULD_NOT_RENAME_2_ERR . " $bkup_file_name.<br>";
 						@chmod($bkup_file_name, 0644);
 					}
 					
 					// Create file.
-					$fh = fopen($file_name, 'x') or die("Can't create $file_name: $php_errormsg");
+					$fh = fopen($file_name, 'x') or die(EDIT_CSS_CANT_CREATE_ERR . " $file_name: $php_errormsg");
 					$result = (fputs($fh, $css_string));
 					fclose($fh) or die($php_errormsg);
 					@chmod($file_name, 0644);
 				}
 			}
 		}
-	
 		if (isset($plugin_sql) && ($plugin_sql != ""))
 		{
-			RunSQL($plugin_sql, BWB_TABLE_PREFIX, $bwb_dbh);
+			$result = RunSQL($plugin_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
 		}
 	
 		$query = "UPDATE " . BWB_TABLE_PREFIX . "plugins SET `deployed`=1 WHERE `id`=$plugin";
@@ -785,14 +687,13 @@ function RunSQL($sql_string, $table_prefix, $dbh)
 	}	
 	
 	//Go to edit page.
-	$domain = $_SERVER['HTTP_HOST'];
-	$web_path = "http://" . $domain;
-	$php_self = $_SERVER['PHP_SELF'];
-	$this_file = substr(strrchr($php_self, "/"), 1);
-	$app_dir = substr($php_self, 0, (strlen($php_self)- strlen($this_file)));
-	$edit_page = $web_path . $app_dir . "edit_page.php?page_name=$page_name&mode=$mode";
+	$edit_page = "edit_page.php?page_name=$page_name&mode=$mode";
 	if (($plugin != "-not selected-") && ($deployed != 1))
 		$edit_page .= "&refresh_buttons=1";
-	header("Location: $edit_page");
+	try	{
+		header("Location: $edit_page");
+	} catch (Exception $e) {
+		echo $e->getMessage();
+	}
 	
-?>
+?>
\ No newline at end of file
