@@ -6,18 +6,20 @@
 // Created: 11/28/2013	ELL
 // Modified: 10/14/2014	ELL
 // Added grouping of plugins by category and sub categories.
+// Modified: 2/22/2015	ELL
+// Added update template image on mouseover.
 // 
 	
 	include ("check_session.php");
 ?>
 
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml">
+<!DOCTYPE html>
+<html>
 <head>
 <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
-<title>Create Page Select</title>
+<title>Create Page Select | Breeze Website Builder</title>
 
-<link rel="stylesheet" href="manager.css" type="text/css">
+<link rel="stylesheet" href="theme/<?php echo $theme; ?>/manager.css" type="text/css">
 
 <style type="text/css">
 #help_button	{	
@@ -92,6 +94,12 @@
 	{
 		echo "plugins[" . $row['id'] . "] = '" . $row['name'] . "';\n";
 	}
+	
+	$query2 = "SELECT * FROM `" . BWB_TABLE_PREFIX . "options_selected` WHERE `option_name` = 'Template'";
+	$result2 = $bwb_dbh->query($query2);
+	$row2 = $result2->fetch(PDO::FETCH_ASSOC);
+	$option_value_selected = $row2["option_value"];
+	echo "\nvar option_value_selected = '$option_value_selected';\n";
 ?>
 </script>
 
@@ -100,26 +108,21 @@
 <body id="workspace_body">
 
 <div id="sub_level_1_buttons">
-	<div class="button_heading_sub_level_1" id="create_page_heading" onclick="ShowSelections();"><div class="button_heading_text_sub_level_1">Create Page</div><div class="help_button" id="help_button" onMouseOver="OpenHelpList();" onclick="OpenHelpWindow('create');">&nbsp;</div></div>
+	<div class="button_heading_sub_level_1" id="create_page_heading" onClick="ShowSelections();"><div class="button_heading_text_sub_level_1"><?php echo CREATE_PAGE_SELECT_HEADING; ?></div><div class="help_button" id="help_button" onMouseOver="OpenHelpList();" onClick="OpenHelpWindow('create');">&nbsp;</div></div>
 	
-    <div class='button_sub_level_1' style='width:258px;' onClick="ShowEnterPageName();" id="enter_page_name_btn"><span class='button_text_sub_level_1'>Enter Name of Page</span></div>
+    <div class='button_sub_level_1' style='width:258px;' onClick="ShowEnterPageName();" id="enter_page_name_btn"><span class='button_text_sub_level_1'><?php echo CREATE_PAGE_SELECT_ENTER_PAGE_NAME_BTN; ?></span></div>
     
-    <div class='button_sub_level_1' style='width:258px;' onClick="ShowPlugins();" id="add_plugin_btn"><span class='button_text_sub_level_1'>Add Plugin</span></div>
+    <div class='button_sub_level_1' style='width:258px;' onClick="ShowPlugins();" id="add_plugin_btn"><span class='button_text_sub_level_1'><?php echo CREATE_PAGE_SELECT_ADD_PLUGIN_BTN; ?></span></div>
     
-    <div class='button_sub_level_1' style='width:258px;' onClick="ShowSelectLayout();" id="select_layout_btn"><span class='button_text_sub_level_1'>Select Layout</span></div>
+    <div class='button_sub_level_1' style='width:258px;' onClick="ShowSelectLayout();" id="select_layout_btn"><span class='button_text_sub_level_1'><?php echo CREATE_PAGE_SELECT_SELECT_LAYOUT_BTN; ?></span></div>
 </div>
 		<form name="frmCreatePage" id="frmCreatePage" method="post" action="create_page.php">
         
-        <input name="createPage" type="text" id="createPage" style="width:300px; display:none;" onblur="SelectPageName();" onkeyup="CheckPageName(this.value);" />
+        <input name="createPage" type="text" id="createPage" style="width:300px; display:none;" onBlur="SelectPageName();" onKeyUp="CheckPageName(this.value);" />
         
         <div id="select_layout_div" style="display:none;">
-
+        
           <?php
-		  	$query2 = "SELECT * FROM `" . BWB_TABLE_PREFIX . "options_selected` WHERE `option_name` = 'Template'";
-			$result2 = $bwb_dbh->query($query2);
-			$row2 = $result2->fetch(PDO::FETCH_ASSOC);
-			$option_value_selected = $row2["option_value"];
-		
 		  	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "options` WHERE `option_name` = 'Template' ORDER BY `sort_order`";
 			$result = $bwb_dbh->query($query);
 			$i = 0;
@@ -129,9 +132,9 @@
 				$option_value = $row["option_value"];				
 			 	
 				if ($option_value_selected == $option_value)
-					echo "<div class='button_sub_level_1 down_sub' id='layout_select$i' style='width:200px;$top_border_style' onClick=\"UpdateTemplateImage($i);\"><span class='button_text_sub_level_1'>$option_value</span></div>\n";
+					echo "<div class='button_sub_level_1 down_sub' id='layout_select$i' style='width:200px;$top_border_style' onClick=\"UpdateTemplateImage($i, true);\" onmouseover=\"UpdateTemplateImage($i, false);\"><span class='button_text_sub_level_1'>$option_value</span></div>\n";
 				else
-					echo "<div class='button_sub_level_1' id='layout_select$i' style='width:200px;$top_border_style' onClick=\"UpdateTemplateImage($i);\"><span class='button_text_sub_level_1'>$option_value</span></div>\n";
+					echo "<div class='button_sub_level_1' id='layout_select$i' style='width:200px;$top_border_style' onClick=\"UpdateTemplateImage($i, true);\" onmouseover=\"UpdateTemplateImage($i, false);\" onmouseout=\"RevertTemplateImage(option_value_selected);\"><span class='button_text_sub_level_1'>$option_value</span></div>\n";
 				$top_border_style = "";
 				$i++;
 			}
@@ -235,21 +238,21 @@
             <div id="selections_div">
             <div id="selected_page_name" class="selection_div">&lsaquo;&mdash; <em>(required)</em></div>
             <div id="selected_plugin" class="selection_div">&lsaquo;&mdash; <em>(optional)</em></div>
-            <img id="template_pic" src="images/<?php echo $option_value_selected; ?>.jpg" border="0">
+            <img id="template_pic" src="images/<?php echo $option_value_selected; ?>.jpg" border="0" width="155" height="88" onMouseOver="this.width = '310'; this.height = '175'; this.style.cursor = 'zoom-in';" onMouseOut="this.width = '155'; this.height = '88';">
             </div>
            
-        <div class='button_console_add_disabled' onClick="document.getElementById('frmCreatePage').submit();" id="create_btn"><span class='button_console_text_w_icon'>Create</span></div>
+        <div class='button_console_add_disabled' onClick="document.getElementById('frmCreatePage').submit();" id="create_btn"><span class='button_console_text_w_icon'><?php echo CREATE_WORD; ?></span></div>
         
           <input type="hidden" name="mode" value="create" />
 	  </form>
 
 
 	<div id="help_list" style="display:none;" onMouseOut="fixOnMouseOut(this, event, 'CloseHelpList();');">
-    	<div id='help_list_close_btn'><img src='images/close-button.png' alt='Close' onClick="document.getElementById('help_list').style.display='none';" style='cursor:pointer;' /></div>
-    	<span onClick="window.open('http://breezewebsitebuilder.com/docs/cms/help.html#create', 'Help', 'scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800');" style='cursor:pointer'>Creating a Page</span><br />
-		<hr /><span onClick="window.open('http://breezewebsitebuilder.com/docs/cms/help.html#plugins', 'Help', 'scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800');" style='cursor:pointer'>Plugins</span><br />
-		<hr /><span onClick="window.open('http://breezewebsitebuilder.com/docs/cms/help.html#start', 'Help', 'scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800');" style='cursor:pointer'>Selecting Page Layout</span><br />
-        <hr /><span onClick="window.open('http://breezewebsitebuilder.com/docs/cms/help.html#create_page_tips', 'Help', 'scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800');" style='cursor:pointer'>Helpful Tips</span>
+    	<div id='help_list_close_btn'><img src='theme/<?php echo $theme; ?>/images/close-button.png' alt='Close' onClick="document.getElementById('help_list').style.display='none';" style='cursor:pointer;' /></div>
+    	<span onClick="window.open('http://breezewebsitebuilder.com/docs/cms/help.html#create', 'Help', 'scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800');" style='cursor:pointer'><?php echo CREATE_PAGE_SELECT_CREATING_A_PAGE; ?></span><br />
+		<hr /><span onClick="window.open('http://breezewebsitebuilder.com/docs/cms/help.html#plugins', 'Help', 'scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800');" style='cursor:pointer'><?php echo PLUGINS_WORD; ?></span><br />
+		<hr /><span onClick="window.open('http://breezewebsitebuilder.com/docs/cms/help.html#start', 'Help', 'scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800');" style='cursor:pointer'><?php echo CREATE_PAGE_SELECT_SELECTING_PAGE_LAYOUT; ?></span><br />
+        <hr /><span onClick="window.open('http://breezewebsitebuilder.com/docs/cms/help.html#create_page_tips', 'Help', 'scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800');" style='cursor:pointer'><?php echo CREATE_PAGE_SELECT_HELPFUL_TIPS; ?></span>
     </div>
 </body>
 </html>
\ No newline at end of file
