@@ -11,6 +11,8 @@
 // Added table prefix handling. Added reference to user files folder constant.
 // Revised: 11/20/2014	ELL
 // Added "redirect", "folder" and separated "page_name" from "file_name" such that this module can be used in more than one place.
+// Revised: 3/26/2016	ELL
+// Fixed bug where delete file, then re-create file and file cache is loaded instead of file.
 //
 	include ("check_session.php");
 
@@ -44,33 +46,47 @@
 	if ($folder == "pages")
 	{
 		if ((BWB_BASE_DIR == '') && (BWB_WEBPAGE_DIR == ''))
-			$path = $document_root . "/" . $file_name;
+			$path = $document_root . "/";
 		elseif (BWB_BASE_DIR == '')
-			$path = $document_root . "/" . BWB_WEBPAGE_DIR . "/" . $file_name;
+			$path = $document_root . "/" . BWB_WEBPAGE_DIR . "/";
 		else
-			$path = $document_root . "/" . BWB_BASE_DIR . "/" . BWB_WEBPAGE_DIR . "/" . $file_name;
+			$path = $document_root . "/" . BWB_BASE_DIR . "/" . BWB_WEBPAGE_DIR . "/";
 	}
 	elseif ($folder == "scripts")
 	{
 		if (BWB_BASE_DIR == '')
-			$path = $document_root . "/" . BWB_SCRIPTS_DIR . "/" . $file_name;
+			$path = $document_root . "/" . BWB_SCRIPTS_DIR . "/";
 		else
-			$path = $document_root . "/" . BWB_BASE_DIR . "/" . BWB_SCRIPTS_DIR . "/" . $file_name;
+			$path = $document_root . "/" . BWB_BASE_DIR . "/" . BWB_SCRIPTS_DIR . "/";
 	}
 	elseif ($folder == "php")
-		$path = $document_root . "/php/" . $file_name;
+		$path = $document_root . "/php/";
 	else
 	{
 		echo "Error: no folder specified";
 		exit;
 	}
 	
-	if (file_exists($path))
+	if (file_exists($path . $file_name))
 	{
+		// Backup file just in case.
+		$source = $path . $file_name;
+		$dest = $path . "." . $file_name . time();
+		copy($source, $dest);
+	
 		// Delete file.
-		$fh = fopen($path, 'w') or die("Can't open $path: $php_errormsg");
+		$fh = fopen($path . $file_name, 'w') or die("Can't open $path: $php_errormsg");
 		fclose($fh) or die($php_errormsg);
-		unlink($path);
+		unlink($path . $file_name);
+	}
+	
+	// Delete cache file.
+	$save_file_path = $path . "." . $file_name . "_save";
+	if (file_exists($save_file_path))
+	{
+		$fh = fopen($save_file_path, 'w') or die("Can't open $path: $php_errormsg");
+		fclose($fh) or die($php_errormsg);
+		unlink($save_file_path);
 	}
 	
 	header("Location: $redirect");
