@@ -46,14 +46,14 @@
 ?>
 <html>
 <head>
-<title>Breeze Website Builder</title>
+<title>Custom <?php echo $style_sheet; ?> CSS - Editing | Breeze Website Builder</title>
 <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
-<link rel="stylesheet" href="manager.css" type="text/css">
+<link rel="stylesheet" href="theme/<?php echo $theme; ?>/manager.css" type="text/css">
 <link rel="shortcut icon" href="images/favicon.ico" type="image/x-icon">
 
 <link rel="stylesheet" href="../ckeditor/plugins/codemirror/theme/<?php echo $CodeMirrorCSS; ?>.css">
 
-<script type="text/javascript" src="js/jquery-1.11.1.min.js"></script>
+<script type="text/javascript" src="js/jquery.min.js"></script>
 <script language="javascript" type="text/javascript" src="js/browser_detect.js"></script>
 <script language="javascript" type="text/javascript" src="js/mouse_position.js"></script>
 <script language="javascript" type="text/javascript" src="js/popup_msg.js"></script>
@@ -68,6 +68,20 @@
  
 	var browser = BrowserDetect.browser;
 	var browser_version = BrowserDetect.version;
+	
+<?php
+	echo "	var EDITOR_STARTING_UPDATE_MSG = \"" . EDITOR_STARTING_UPDATE_MSG . "\";\n";
+	echo "	var EDITOR_PREPARING_PREVIEW_MSG = \"" . EDITOR_PREPARING_PREVIEW_MSG . "\";\n";
+	echo "	var EDITOR_REVERT_CSS_CONFIRM_1_MSG = \"" . EDITOR_REVERT_CSS_CONFIRM_1_MSG . "\";\n";
+	echo "	var EDITOR_REVERT_CSS_CONFIRM_2_MSG = \"" . EDITOR_REVERT_CSS_CONFIRM_2_MSG . "\";\n";
+	echo "	var EDITOR_REVERTING_MSG = \"" . EDITOR_REVERTING_MSG . "\";\n";
+	echo "	var EDITOR_REVERT_COMPLETE_MSG = \"" . EDITOR_REVERT_COMPLETE_MSG . "\";\n";
+	echo "	var EDITOR_REVERT_ERR = \"" . EDITOR_REVERT_ERR . "\";\n";
+	echo "	var EDITOR_CSS_NOT_SAVED_MSG = \"" . EDITOR_FILE_NOT_SAVED_MSG . "\";\n";
+	echo "	var SAVE_AS_WORD = \"" . SAVE_AS_WORD . "\";\n";
+	echo "	var YES_WORD = \"" . YES_WORD . "\";\n";
+	echo "	var NO_WORD = \"" . NO_WORD . "\";\n";
+?>
 </script>
 
 </head>
@@ -85,6 +99,7 @@
 		
 		CKEDITOR.replace( 'editorContainer', { contentsCss : ['/ckeditor/contents.css'] });
 
+		CKEDITOR.config.language = '<?php echo BWB_LANG; ?>';
 		CKEDITOR.config.extraPlugins = 'codemirror';
 		CKEDITOR.config.skin = 'kama';
 		CKEDITOR.config.allowedContent = true;
@@ -226,22 +241,22 @@
    <table width="90%" border="0" cellspacing="0" cellpadding="0" id="btn_table">
 	 <tr>
 	 <td align="left" class="small_message" width="9%">
-	  <span id="page_name_label">Style Sheet:<br /><?php echo $custom_site_css_table; ?></span>
+	  <span id="page_name_label"><?php echo EDITOR_STYLE_SHEET; ?>:<br /><?php echo $custom_site_css_table; ?></span>
 	 </td>
 	 <td align="center">
-		<div class='button_console_preview' style="width:110px;" onClick="Save('Preview');"><span class='button_console_text_w_icon'>Preview</span></div>
+		<div class='button_console_preview' style="width:110px;" onClick="PreviewPageSelect();"><span class='button_console_text_w_icon'><?php echo EDITOR_PREVIEW; ?></span></div>
 	  </td>
 	   <td align="center">
-		<div class='button_console_save' style="width:110px;" onClick="Save('Save');"><span class='button_console_text_w_icon'>Save</span></div>
+		<div class='button_console_save' style="width:110px;" onClick="Save('Save');"><span class='button_console_text_w_icon'><?php echo EDITOR_SAVE; ?></span></div>
 	   </td>
 	   <td align="center">
-		<div class='button_console_save' style="width:110px;" onClick="Save('Publish');"><span class='button_console_text_w_icon'>Publish</span></div>
+		<div class='button_console_save' style="width:110px;" onClick="Save('Publish');"><span class='button_console_text_w_icon'><?php echo EDITOR_PUBLISH; ?></span></div>
 	   </td>
 	   <td align="center">
-		<div class='button_console_cancel' style="width:110px;" onClick="RevertConfirm();"><span class='button_console_text_w_icon'>Revert</span></div>
+		<div class='button_console_cancel' style="width:110px;" onClick="RevertConfirm();"><span class='button_console_text_w_icon'><?php echo EDITOR_REVERT; ?></span></div>
 	   </td>
 	   <td align="center">
-		<div class='button_console_preview' style="width:110px;" onClick="window.open('<?php echo $path; ?>', '_blank');"><span class='button_console_text_w_icon'>See Site</span></div>
+		<div class='button_console_preview' style="width:110px;" onClick="window.open('<?php echo $path; ?>', '_blank');"><span class='button_console_text_w_icon'><?php echo EDITOR_SEE_SITE; ?></span></div>
 	   </td>
 		<td align="right" width="10%"><div class="help_button" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div></td>
 	 </tr>
@@ -250,6 +265,22 @@
 
 </div>
 
+<div id="page_select_div" style="display:none;">
+<?php echo EDIT_CSS_SELECT_PAGE_FOR_PREVIEW; ?>:<br />
+<select id="page_select" onChange="Preview(this.value, 0);">
+<?php
+	$query = "SELECT page_name FROM `" . BWB_TABLE_PREFIX . "page_data`";
+	$result = $bwb_dbh->query($query);
+	while($row = $result->fetch(PDO::FETCH_ASSOC))
+	{
+		$page_name = $row['page_name'];
+		echo "		<option value='$page_name'>$page_name</option>\n";
+	}
+?>
+</select>
+<div id="preview_go" onClick="Preview(document.getElementById('page_select').value, 0);">&nbsp;</div>
+</div>
+
 <?php include("lib/popup_msg.html"); ?>
 
 <script language="javascript" type="text/javascript">
