@@ -55,14 +55,14 @@
 ?>
 <html>
 <head>
-<title>Breeze Website Builder</title>
+<title><?php echo $file_name; ?> - Editing | Breeze Website Builder</title>
 <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
-<link rel="stylesheet" href="manager.css" type="text/css">
+<link rel="stylesheet" href="theme/<?php echo $theme; ?>/manager.css" type="text/css">
 <link rel="shortcut icon" href="images/favicon.ico" type="image/x-icon">
 
 <link rel="stylesheet" href="../ckeditor/plugins/codemirror/theme/<?php echo $CodeMirrorCSS; ?>.css">
 
-<script type="text/javascript" src="js/jquery-1.11.1.min.js"></script>
+<script type="text/javascript" src="js/jquery.min.js"></script>
 <script language="javascript" type="text/javascript" src="js/browser_detect.js"></script>
 <script language="javascript" type="text/javascript" src="js/mouse_position.js"></script>
 <script language="javascript" type="text/javascript" src="js/popup_msg.js"></script>
@@ -77,6 +77,27 @@
  
 	var browser = BrowserDetect.browser;
 	var browser_version = BrowserDetect.version;
+	
+<?php
+	echo "	var EDITOR_STARTING_UPDATE_MSG = \"" . EDITOR_STARTING_UPDATE_MSG . "\";\n";
+	echo "	var EDITOR_PREPARING_PREVIEW_MSG = \"" . EDITOR_PREPARING_PREVIEW_MSG . "\";\n";
+	echo "	var EDITOR_REVERT_FILE_CONFIRM_1_MSG = \"" . EDITOR_REVERT_FILE_CONFIRM_1_MSG . "\";\n";
+	echo "	var EDITOR_REVERT_FILE_CONFIRM_2_MSG = \"" . EDITOR_REVERT_FILE_CONFIRM_2_MSG . "\";\n";
+	echo "	var EDITOR_REVERTING_MSG = \"" . EDITOR_REVERTING_MSG . "\";\n";
+	echo "	var EDITOR_REVERT_COMPLETE_MSG = \"" . EDITOR_REVERT_COMPLETE_MSG . "\";\n";
+	echo "	var EDITOR_REVERT_ERR = \"" . EDITOR_REVERT_ERR . "\";\n";
+	echo "	var EDITOR_FILE_NOT_SAVED_MSG = \"" . EDITOR_FILE_NOT_SAVED_MSG . "\";\n";
+	echo "	var EDITOR_FILE_BLANK_ERR = \"" . EDITOR_FILE_BLANK_ERR . "\";\n";
+	echo "	var EDITOR_FILE_ALREADY_EXISTS_1_ERR = \"" . EDITOR_FILE_ALREADY_EXISTS_1_ERR . "\";\n";
+	echo "	var EDITOR_FILE_ALREADY_EXISTS_2_ERR = \"" . EDITOR_FILE_ALREADY_EXISTS_2_ERR . "\";\n";
+	echo "	var EDITOR_DELETE_FILE_CONFIRM_1_MSG = \"" . EDITOR_DELETE_FILE_CONFIRM_1_MSG . "\";\n";
+	echo "	var EDITOR_DELETE_FILE_CONFIRM_2_MSG = \"" . EDITOR_DELETE_FILE_CONFIRM_2_MSG . "\";\n";
+	echo "	var SAVE_AS_WORD = \"" . SAVE_AS_WORD . "\";\n";
+	echo "	var YES_WORD = \"" . YES_WORD . "\";\n";
+	echo "	var NO_WORD = \"" . NO_WORD . "\";\n";
+	echo "	var OK_WORD = \"" . OK_WORD . "\";\n";
+	echo "	var CANCEL_WORD = \"" . CANCEL_WORD . "\";\n";
+?>
 </script>
 
 </head>
@@ -93,6 +114,7 @@
 		
 		CKEDITOR.replace( 'editorContainer', { contentsCss : ['/ckeditor/contents.css'] });
 
+		CKEDITOR.config.language = '<?php echo BWB_LANG; ?>';
 		CKEDITOR.config.extraPlugins = 'codemirror';
 		CKEDITOR.config.skin = 'kama';
 		CKEDITOR.config.allowedContent = true;
@@ -262,30 +284,30 @@
  
   <table width="90%" align="center" id="btn_table"><tr>
   <td align="left" class="medium_message" width="9%">
-  <span id="page_name_label">File Name:<br /><?php echo $file_name; ?></span>
+  <span id="page_name_label"><?php echo EDITOR_FILE_NAME; ?>:<br /><?php echo $file_name; ?></span>
   </td>
 <?php if ($folder == "pages")	{	?>
   <td align="center">
-  <div class='button_console_preview' style="width:110px;" onClick="Preview();"><span class='button_console_text_w_icon'>Preview</span></div>
+  <div class='button_console_preview' style="width:110px;" onClick="Preview();"><span class='button_console_text_w_icon'><?php echo EDITOR_PREVIEW; ?></span></div>
   </td>
 <?php }	?>
   <td align="center">
-  <div class='button_console_save' style="width:110px;" onClick="Save('save');"><span class='button_console_text_w_icon'>Save</span></div>
+  <div class='button_console_save' style="width:110px;" onClick="Save('save');"><span class='button_console_text_w_icon'><?php echo EDITOR_SAVE; ?></span></div>
   </td>
   <td align="center">
-  <div class='button_console_save' style="width:110px;" onClick="ShowSaveAsMsg();"><span class='button_console_text_w_icon'>Save As</span></div>
+  <div class='button_console_save' style="width:110px;" onClick="ShowSaveAsMsg();"><span class='button_console_text_w_icon'><?php echo EDITOR_SAVE_AS; ?></span></div>
   </td>
   <td align="center">
-  <div class='button_console_save' style="width:110px;" onClick="Save('publish');"><span class='button_console_text_w_icon'>Publish</span></div>
+  <div class='button_console_save' style="width:110px;" onClick="Save('publish');"><span class='button_console_text_w_icon'><?php echo EDITOR_PUBLISH; ?></span></div>
   </td>
    <td align="center">
-  <div class='button_console_cancel' style="width:110px;" onClick="RevertConfirm();"><span class='button_console_text_w_icon'>Revert</span></div>
+  <div class='button_console_cancel' style="width:110px;" onClick="RevertConfirm();"><span class='button_console_text_w_icon'><?php echo EDITOR_REVERT; ?></span></div>
   </td>
   <td align="center">
-  <div class='button_console_delete' style="width:110px;" onClick="DeleteConfirm();"><span class='button_console_text_w_icon'>Delete</span></div>
+  <div class='button_console_delete' style="width:110px;" onClick="DeleteConfirm();"><span class='button_console_text_w_icon'><?php echo EDITOR_DELETE; ?></span></div>
   </td>
   <td align="center">
-  <div class='button_console_preview' style="width:110px;" onClick="window.open('<?php echo $path; ?>', '_blank');"><span class='button_console_text_w_icon'>See File</span></div>
+  <div class='button_console_preview' style="width:110px;" onClick="window.open('<?php echo $path; ?>', '_blank');"><span class='button_console_text_w_icon'><?php echo EDITOR_SEE_FILE; ?></span></div>
   </td>
   <td align="right" width="10%"><div class="help_button" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div></td>
   </tr></table>
