@@ -67,11 +67,12 @@
 		$robots_revisit = 30;
 	}
 ?>
+<!DOCTYPE html>
 <html>
 <head>
-<title>EB Content Manager</title>
+<title>Editing <?php echo $selected_page_name; ?> Meta Tags | Breeze Website Builder</title>
 <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
-<link rel="stylesheet" href="manager.css" type="text/css">
+<link rel="stylesheet" href="theme/<?php echo $theme; ?>/manager.css" type="text/css">
 <link rel="shortcut icon" href="images/favicon.ico" type="image/x-icon">
 
 <style type="text/css">
@@ -96,7 +97,7 @@
 
 <body id="workspace_body">
 <table width="90%" align="center"><tr><td>
-<div class="button_heading_sub_level_1" id="edit_metatags_heading"><div class="button_heading_text_sub_level_1">Edit Meta Tags</div><div class="help_button" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div></div>
+<div class="button_heading_sub_level_1" id="edit_metatags_heading"><div class="button_heading_text_sub_level_1"><?php echo EDIT_META_TAGS_HEADING; ?></div><div class="help_button" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div></div>
 </td></tr></table>
 
 <form name="formEditMetatags" id="formEditMetatags" method="post" action="save_meta_tags.php">
@@ -106,7 +107,7 @@
     <table width="100%" class="layout_box_table"><tr>
       <td width="90%">
       
-	  <p style="padding-left:5px;">Select a page:
+	  <?php echo EDIT_META_TAGS_SELECT_PAGE; ?>:
 	        <select name="page_name" id="page_name" OnChange="GetPageMetatags(this.options[this.selectedIndex].value);">
 		      <?php
 			$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data ORDER BY page_name";
@@ -135,60 +136,60 @@
 			
 		?>
             </select>
-	        </p>
+	        
        </td>
        </tr></table>
        </td>
     </tr>
   <tr>
-    <td style="padding-left:5px;">Owner:</td>
+    <td style="padding-left:5px;"><?php echo OWNER_WORD; ?>:</td>
 	<td>
       <input name="owner" type="text" id="owner" value="<?php echo $owner; ?>"></td>
-    <td style="padding-left:5px;">Author:</td> 
+    <td style="padding-left:5px;"><?php echo AUTHOR_WORD; ?>:</td> 
 	<td>
       <input name="author" type="text" id="author" value="<?php echo $author; ?>"></td>
     </tr>
   <tr>
-    <td style="padding-left:5px;">Lanquage:</td> 
+    <td style="padding-left:5px;"><?php echo LANGUAGE_WORD; ?>:</td> 
 	<td>
       <input name="lanquage" type="text" id="lanquage" value="<?php echo $lanquage; ?>"></td>
-    <td style="padding-left:5px;">Copyright:</td>
+    <td style="padding-left:5px;"><?php echo COPYRIGHT_WORD; ?>:</td>
 	<td> 
       <input name="copyright" type="text" id="copyright" value="<?php echo $copyright; ?>"></td>
     </tr>
   <tr>
-    <td style="padding-left:5px;">Description:</td>
+    <td style="padding-left:5px;"><?php echo DESCRIPTION_WORD; ?>:</td>
     <td colspan="3"><textarea name="description" cols="100" id="description"><?php echo $description; ?></textarea></td>
     </tr>
   <tr>
-    <td style="padding-left:5px;">Abstract:</td>
+    <td style="padding-left:5px;"><?php echo ABSTRACT_WORD; ?>:</td>
     <td colspan="3"><textarea name="abstract" cols="100" id="abstract"><?php echo $abstract; ?></textarea></td>
     </tr>
   <tr>
-    <td style="padding-left:5px;">Keywords:</td>
+    <td style="padding-left:5px;"><?php echo KEYWORDS_WORD; ?>:</td>
     <td colspan="3"><textarea name="keywords" cols="100" id="keywords"><?php echo $keywords; ?></textarea>
 	<br>
-    <span class="small_message">Note: Use comma &quot; , &quot; to separate key words and key phrases.</span></td>
+    <span class="small_message"><?php echo EDIT_META_TAGS_KEYWORDS_NOTE; ?></span></td>
     </tr>
   <tr>
-    <td style="padding-left:5px;">Subject:</td>
+    <td style="padding-left:5px;"><?php echo SUBJECT_WORD; ?>:</td>
     <td colspan="3"><textarea name="subject" cols="100" id="subject"><?php echo $subject; ?></textarea></td>
     </tr>
   <tr>
-    <td style="padding-left:5px;">Robots:</td>
+    <td style="padding-left:5px;"><?php echo ROBOTS_WORD; ?>:</td>
     <td style="padding-left:5px;"><input name="robots_index" type="checkbox" id="robots_index" value="checkbox" <?php if ($robots_index == 1) echo "checked"; ?>>
-      Index</td>
+      <?php echo INDEX_WORD; ?></td>
     <td style="padding-left:5px;"><input name="robots_follow" type="checkbox" id="robots_follow" value="checkbox" <?php if ($robots_follow == 1) echo "checked"; ?>> 
-      Follow</td>
-    <td style="padding-left:5px;">Revisit: 
+      <?php echo FOLLOW_WORD; ?></td>
+    <td style="padding-left:5px;"><?php echo REVISIT_WORD; ?>: 
       <input name="robots_revisit" type="text" id="robots_revisit" value="<?php echo $robots_revisit; ?>"> 
-      days</td>
+      <?php echo DAYS_WORD; ?></td>
   </tr>
   <tr>
     <td colspan="4" align="center">
-	  <br>
-        <div class='button_console_save' id="save_metatags_btn" onClick="document.getElementById('formEditMetatags').submit();"><span class='button_console_text_w_icon'>Submit</span></div>
-      <br>
+	  
+        <div class='button_console_save' id="save_metatags_btn" onClick="document.getElementById('formEditMetatags').submit();"><span class='button_console_text_w_icon'><?php echo SUBMIT_WORD; ?></span></div>
+      
 	  </td>
     </tr>
 </table>
@@ -203,7 +204,7 @@
 	popup_msg.left_offset = 320;
 	popup_msg.popup_msg_type = 1;
 	popup_msg.popup_timeout = 3000;
-	popup_msg.status_msg = "Meta tags have been saved.";
+	popup_msg.status_msg = "<?php echo EDIT_META_TAGS_META_TAGS_SAVED_MSG; ?>";
 	popup_msg.ShowPopupMsg();
 <?php	}	?>
 </script>
