@@ -118,15 +118,15 @@
 ?>
 <html>
 <head>
-<title>Breeze Website Builder - Editing <?php echo $page_name; ?></title>
+<title><?php if ($mode == "blog") echo "Blog ID " . $blog_id; else echo $page_name; ?> - Editing | Breeze Website Builder</title>
 <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
-<link rel="stylesheet" href="manager.css" type="text/css">
+<link rel="stylesheet" href="theme/<?php echo $theme; ?>/manager.css" type="text/css">
 <link rel="shortcut icon" href="images/favicon.ico" type="image/x-icon">
 
 <link rel="stylesheet" href="../ckeditor/plugins/codemirror/theme/<?php echo $CodeMirrorCSS; ?>.css">
 
 <script language="javascript" type="text/javascript" src="../ckeditor/ckeditor.js"></script>
-<script type="text/javascript" src="js/jquery-1.11.1.min.js"></script>
+<script type="text/javascript" src="js/jquery.min.js"></script>
 <script language="javascript" type="text/javascript" src="js/browser_detect.js"></script>
 <script language="javascript" type="text/javascript" src="js/mouse_position.js"></script>
 <script language="javascript" type="text/javascript" src="js/popup_msg.js"></script>
@@ -149,7 +149,7 @@
  var browser = BrowserDetect.browser;
  var browser_version = BrowserDetect.version;
 // alert(browser + " " + browser_version);
- var help_list_html = "<div id='help_list_close_btn'><img src='images/close-button.png' alt='Close' onClick=\"document.getElementById('help_list').style.display='none';\" style='cursor:pointer;' /></div>\n";
+ var help_list_html = "<div id='help_list_close_btn'><img src='theme/<?php echo $theme; ?>/images/close-button.png' alt='Close' onClick=\"document.getElementById('help_list').style.display='none';\" style='cursor:pointer;' /></div>\n";
 <?php
 	foreach ($plugin_help as $name => $url)
 	{
@@ -160,6 +160,35 @@
 	
 	help_list_html = help_list_html + "<hr /><span onClick=\"window.open('http://breezewebsitebuilder.com/docs/cms/help.html#edit_page', 'Help', 'scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800');\" style='cursor:pointer'>Using Page Editor</span>";
 	
+<?php
+	echo "	var EDITOR_STARTING_UPDATE_MSG = \"" . EDITOR_STARTING_UPDATE_MSG . "\";\n";
+	echo "	var EDITOR_PREPARING_PREVIEW_MSG = \"" . EDITOR_PREPARING_PREVIEW_MSG . "\";\n";
+	echo "	var EDITOR_REVERT_BLOG_CONFIRM_1_MSG = \"" . EDITOR_REVERT_BLOG_CONFIRM_1_MSG . "\";\n";
+	echo "	var EDITOR_REVERT_BLOG_CONFIRM_2_MSG = \"" . EDITOR_REVERT_BLOG_CONFIRM_2_MSG . "\";\n";
+	echo "	var EDITOR_REVERT_AREA_CONFIRM_1_MSG = \"" . EDITOR_REVERT_AREA_CONFIRM_1_MSG . "\";\n";
+	echo "	var EDITOR_REVERT_AREA_CONFIRM_2_MSG = \"" . EDITOR_REVERT_AREA_CONFIRM_2_MSG . "\";\n";
+	echo "	var EDITOR_REVERT_PAGE_CONFIRM_1_MSG = \"" . EDITOR_REVERT_PAGE_CONFIRM_1_MSG . "\";\n";
+	echo "	var EDITOR_REVERT_PAGE_CONFIRM_2_MSG = \"" . EDITOR_REVERT_PAGE_CONFIRM_2_MSG . "\";\n";
+	echo "	var EDITOR_REVERTING_MSG = \"" . EDITOR_REVERTING_MSG . "\";\n";
+	echo "	var EDITOR_REVERT_ERR = \"" . EDITOR_REVERT_ERR . "\";\n";
+	echo "	var EDITOR_PAGE_NOT_SAVED_MSG = \"" . EDITOR_PAGE_NOT_SAVED_MSG . "\";\n";
+	echo "	var EDITOR_PAGE_BLANK_ERR = \"" . EDITOR_PAGE_BLANK_ERR . "\";\n";
+	echo "	var EDITOR_PAGE_ALREADY_EXISTS_1_ERR = \"" . EDITOR_PAGE_ALREADY_EXISTS_1_ERR . "\";\n";
+	echo "	var EDITOR_PAGE_ALREADY_EXISTS_2_ERR = \"" . EDITOR_PAGE_ALREADY_EXISTS_2_ERR . "\";\n";
+	echo "	var EDITOR_AREA_ALREADY_EXISTS_1_ERR = \"" . EDITOR_AREA_ALREADY_EXISTS_1_ERR . "\";\n";
+	echo "	var EDITOR_AREA_ALREADY_EXISTS_2_ERR = \"" . EDITOR_AREA_ALREADY_EXISTS_2_ERR . "\";\n";
+	echo "	var EDITOR_DELETE_BLOG_CONFIRM_1_MSG = \"" . EDITOR_DELETE_BLOG_CONFIRM_1_MSG . "\";\n";
+	echo "	var EDITOR_DELETE_BLOG_CONFIRM_2_MSG = \"" . EDITOR_DELETE_BLOG_CONFIRM_2_MSG . "\";\n";
+	echo "	var EDITOR_DELETE_AREA_CONFIRM_1_MSG = \"" . EDITOR_DELETE_AREA_CONFIRM_1_MSG . "\";\n";
+	echo "	var EDITOR_DELETE_AREA_CONFIRM_2_MSG = \"" . EDITOR_DELETE_AREA_CONFIRM_2_MSG . "\";\n";
+	echo "	var EDITOR_DELETE_PAGE_CONFIRM_1_MSG = \"" . EDITOR_DELETE_PAGE_CONFIRM_1_MSG . "\";\n";
+	echo "	var EDITOR_DELETE_PAGE_CONFIRM_2_MSG = \"" . EDITOR_DELETE_PAGE_CONFIRM_2_MSG . "\";\n";
+	echo "	var SAVE_AS_WORD = \"" . SAVE_AS_WORD . "\";\n";
+	echo "	var YES_WORD = \"" . YES_WORD . "\";\n";
+	echo "	var NO_WORD = \"" . NO_WORD . "\";\n";
+	echo "	var OK_WORD = \"" . OK_WORD . "\";\n";
+	echo "	var CANCEL_WORD = \"" . CANCEL_WORD . "\";\n";
+?>
 </script>
 
 </head>
@@ -174,9 +203,9 @@
 		CKEDITOR_BASEPATH = '../ckeditor/';
 		
 		CKEDITOR.replace( 'editorContainer', {
-			filebrowserBrowseUrl: '/kfm/index.php?startup_folder=<?php echo BWB_WEBPAGE_DIR; ?>',
-			filebrowserImageBrowseUrl: '/kfm/index.php?startup_folder=<?php echo BWB_IMAGE_DIR; ?>&type=Images',
-			filebrowserFlashBrowseUrl: '/kfm/index.php?startup_folder=<?php echo BWB_FLASH_DIR; ?>&type=Flash',
+			filebrowserBrowseUrl: '/kfm/index.php?startup_folder=<?php echo BWB_WEBPAGE_DIR; ?>&langCode=<?php echo BWB_LANG; ?>',
+			filebrowserImageBrowseUrl: '/kfm/index.php?startup_folder=<?php echo BWB_IMAGE_DIR; ?>&type=Images&langCode=<?php echo BWB_LANG; ?>',
+			filebrowserFlashBrowseUrl: '/kfm/index.php?startup_folder=<?php echo BWB_FLASH_DIR; ?>&type=Flash&langCode=<?php echo BWB_LANG; ?>',
 <?php 
 	if ($disable_site_styles != 1)
 	{
@@ -197,6 +226,7 @@
 ?>
 		});
 
+		CKEDITOR.config.language = '<?php echo BWB_LANG; ?>';
 		CKEDITOR.config.extraPlugins = 'zoom,letterspacing,codemirror';
 		CKEDITOR.config.skin = 'kama';
 		CKEDITOR.config.allowedContent = true;
@@ -325,28 +355,28 @@
       
 	  <table width="100%" align="center" id="btn_table"><tr>
 	  <td align="left" class="medium_message" width="9%">
-      Page Name:<br/><span id="page_name_label"><?php echo $page_name; ?></span>
+      <?php echo EDITOR_PAGE_NAME; ?>:<br/><span id="page_name_label"><?php echo $page_name; ?></span>
 	  </td>
       <td align="center" style="min-width:90px;">
-      <div class='button_console_preview_sm' style="min-width:90px;" onClick="Preview();"><span class='button_console_text_w_sm_icon'>Preview</span></div>
+      <div class='button_console_preview_sm' style="min-width:90px;" onClick="Preview('<?php echo $page_name; ?>', 0);"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_PREVIEW; ?></span></div>
 	  </td>
       <td align="center" style="min-width:80px;">
-      <div class='button_console_save_sm' style="min-width:80px;" onClick="Save('save_draft');"><span class='button_console_text_w_sm_icon'>Save</span></div>
+      <div class='button_console_save_sm' style="min-width:80px;" onClick="Save('save_draft');"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_SAVE; ?></span></div>
 	  </td>
 <?php if ($mode != "blog") { ?>
       <td align="center" style="min-width:90px;">
-      <div class='button_console_save_sm' style="min-width:90px;" onClick="ShowSaveAsMsg();"><span class='button_console_text_w_sm_icon'>Save As</span></div>
+      <div class='button_console_save_sm' style="min-width:90px;" onClick="ShowSaveAsMsg();"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_SAVE_AS; ?></span></div>
 	  </td>
 <?php } ?>
 	  <td align="center" style="min-width:90px;">
-      <div class='button_console_save_sm' style="min-width:90px;" onClick="Save('publish');"><span class='button_console_text_w_sm_icon'>Publish</span></div>
+      <div class='button_console_save_sm' style="min-width:90px;" onClick="Save('publish');"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_PUBLISH; ?></span></div>
 	  </td>
       <td align="center" style="min-width:80px;">
-      <div class='button_console_cancel_sm' style="min-width:80px;" onClick="RevertConfirm('<?php echo $mode; ?>');"><span class='button_console_text_w_sm_icon'>Revert</span></div>
+      <div class='button_console_cancel_sm' style="min-width:80px;" onClick="RevertConfirm('<?php echo $mode; ?>');"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_REVERT; ?></span></div>
 	  </td>
 <?php if (($access_level == "admin") || ($access_level == "power_user")) { ?>
 	  <td align="center" style="min-width:80px;">
-      <div class='button_console_delete_sm' style="min-width:80px;" onClick="DeleteConfirm('<?php echo $mode; ?>');"><span class='button_console_text_w_sm_icon'>Delete</span></div>
+      <div class='button_console_delete_sm' style="min-width:80px;" onClick="DeleteConfirm('<?php echo $mode; ?>');"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_DELETE; ?></span></div>
 	  </td>
 <?php } ?>
       <td align="center">
@@ -360,23 +390,23 @@
 			echo $page_name;
 		echo ".php', '_blank');\"";
 ?>
-      ><span class='button_console_text_w_sm_icon' style="min-width:90px;">See Site</span></div>
+      ><span class='button_console_text_w_sm_icon' style="min-width:90px;"><?php echo EDITOR_SEE_SITE; ?></span></div>
 	  </td>
       <td align="center" style="min-width:75px;">
-      <div class='button_console_delete_sm' style="min-width:75px;" onClick="ClearContent();"><span class='button_console_text_w_sm_icon'>Clear</span></div>
+      <div class='button_console_delete_sm' style="min-width:75px;" onClick="ClearContent();"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_CLEAR; ?></span></div>
       </td>
 	  <td width="2%">&nbsp;
       
 	  </td>
       <td align="center" style="min-width:145px;">
-      <div class='button_console_image_sm' style="min-width:145px;" onClick="OptimizeResetImages('optimize');"><span class='button_console_text_w_sm_icon'>Optimize Images</span></div>
+      <div class='button_console_image_sm' style="min-width:145px;" onClick="OptimizeResetImages('optimize');"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_OPTIMIZE_IMAGES; ?></span></div>
       </td>
       <td align="center" style="min-width:125px;">
-      <div class='button_console_image_sm' style="min-width:125px;" onClick="OptimizeResetImages('reset');"><span class='button_console_text_w_sm_icon'>Reset Images</span></div>
+      <div class='button_console_image_sm' style="min-width:125px;" onClick="OptimizeResetImages('reset');"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_RESET_IMAGES; ?></span></div>
       </td>
       <td style="min-width:115px;">
 <?php if ($access_level != "restricted") { ?>
-      <div class='button_console_edit_sm' style="min-width:115px;" onClick="window.open('edit_css.php?style_sheet=site','_blank');"><span class='button_console_text_w_sm_icon'>Edit Styles</span></div>
+      <div class='button_console_edit_sm' style="min-width:115px;" onClick="window.open('edit_css.php?style_sheet=site','_blank');"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_EDIT_STYLES; ?></span></div>
 <?php } else echo "&nbsp;"; ?>
       </td>
       <td width="1%">&nbsp;</td>
