@@ -14,12 +14,12 @@
 	$page_title_saved = $_REQUEST['page_title_saved'];
 ?>
 
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml">
+<!DOCTYPE html>
+<html>
 <head>
 <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
-<title>Edit Title Select</title>
-<link rel="stylesheet" href="manager.css" type="text/css">
+<title>Editing <?php echo $selected_page_name; ?> Title | Breeze Website Builder</title>
+<link rel="stylesheet" href="theme/<?php echo $theme; ?>/manager.css" type="text/css">
 
 <style type="text/css">
 #manage_users_site_options_heading	{	width:300px;	}
@@ -45,14 +45,14 @@
 
 <body>
 <div id="sub_level_1_buttons">
-<div class="button_heading_sub_level_1" id="edit_page_titles_heading"><div class="button_heading_text_sub_level_1">Edit Page Titles</div><div class="help_button" id="help_button" onclick="OpenHelpWindow();">&nbsp;</div></div>
+<div class="button_heading_sub_level_1" id="edit_page_titles_heading"><div class="button_heading_text_sub_level_1"><?php echo EDIT_PAGE_TITLES_HEADING; ?></div><div class="help_button" id="help_button" onclick="OpenHelpWindow();">&nbsp;</div></div>
 
   <table border="0" width="100%">
 		<tr>
 			<td>
 			  <form name="frmChangeDefaultTitle" id="frmChangeDefaultTitle" method="post" action="save_page_title.php">
 			  <p align="center">
-			  Revise Default Page Title:<br>
+			  <?php echo EDIT_PAGE_TITLES_REVISE_DEFAULT_PAGE_TITLE; ?>:<br>
 			  <?php
 				$query = "SELECT title FROM " . BWB_TABLE_PREFIX . "page_titles WHERE page_name = '_default_'";
 			
@@ -65,14 +65,14 @@
 				</p>
 				<center>
 				<input type="hidden" name="page_name" id="page_name" value="_default_" />
-                <div class='button_console_save' id="update_default_page_title_btn" onClick="document.getElementById('frmChangeDefaultTitle').submit();"><span class='button_console_text_w_icon'>Update</span></div>
+                <div class='button_console_save' id="update_default_page_title_btn" onClick="document.getElementById('frmChangeDefaultTitle').submit();"><span class='button_console_text_w_icon'><?php echo UPDATE_WORD; ?></span></div>
 				</center>
 			  </form>
 	  		</td>
 	  		<td>
 			  <form name="frmChangePageTitles" id="frmChangePageTitles" method="post" action="save_page_title.php">
 			  <p align="center">
-			  Select a page to change the title of:<br>
+			  <?php echo EDIT_PAGE_TITLES_SELECT_PAGE; ?>:<br>
 			  <select name='page_name' id='page_name' OnChange="FillInPageTitle(this.options[this.selectedIndex].value);" class="page_dropdown">
 			  <?php
 				$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data ORDER BY page_name";
@@ -99,7 +99,7 @@
 				<input type='text' name='title' id='title' value='<?php echo $title; ?>' size='40' />
 				</p>
 				<center>
-                <div class='button_console_save' id="update_page_title_btn" onClick="document.getElementById('frmChangePageTitles').submit();"><span class='button_console_text_w_icon'>Update</span></div>
+                <div class='button_console_save' id="update_page_title_btn" onClick="document.getElementById('frmChangePageTitles').submit();"><span class='button_console_text_w_icon'><?php echo UPDATE_WORD; ?></span></div>
 				</center>
 			  </form>
 			</td>
@@ -109,7 +109,7 @@
         	<td>
 			  <form name="frmChangeTitle" id="frmChangeTitle" method="post" action="save_page_title.php">
 			  <p align="center">
-			  Revise Site Title <span class="small_message">(appended to page title if exists)</span>:<br>
+			  <?php echo EDIT_PAGE_TITLES_REVISE_SITE_TITLE; ?> <span class="small_message">(<?php echo EDIT_PAGE_TITLES_SITE_TITLE_NOTE; ?>)</span>:<br>
 			  <?php
 				$query = "SELECT title FROM " . BWB_TABLE_PREFIX . "page_titles WHERE page_name = '_append_'";
 			
@@ -122,7 +122,7 @@
 				</p>
 				<center>
 				<input type="hidden" name="page_name" id="page_name" value="_append_" />
-                <div class='button_console_save' id="update_default_page_title_btn" onClick="document.getElementById('frmChangeTitle').submit();"><span class='button_console_text_w_icon'>Update</span></div>
+                <div class='button_console_save' id="update_default_page_title_btn" onClick="document.getElementById('frmChangeTitle').submit();"><span class='button_console_text_w_icon'><?php echo UPDATE_WORD; ?></span></div>
 				</center>
 			  </form>
 	  		</td>
@@ -141,7 +141,7 @@
 	popup_msg.left_offset = 320;
 	popup_msg.popup_msg_type = 1;
 	popup_msg.popup_timeout = 2000;
-	popup_msg.status_msg = "Page title has been saved.";
+	popup_msg.status_msg = "<?php echo EDIT_PAGE_TITLES_PAGE_TILE_SAVED_MSG; ?>";
 	popup_msg.ShowPopupMsg();
 <?php	}	?>
 </script>
