@@ -15,7 +15,6 @@ $server_name = $_SERVER['SERVER_NAME'];
 $server_name_www = "www." . $server_name;
 $referers = array($server_name_www, $server_name);
 
-
 // Module for performaing actual email operation.
 include("mime_mail.inc");
 // DB connection for retrieving HTML message format for message back to inquirer, etc.
@@ -32,7 +31,7 @@ if ($_POST['alt_go_back'])
 	$delim = "?";
 	foreach($_POST as $key => $val)
 	{
-		if (!in_array($key, $ignore_fields))
+		if (!in_array($key, $ignore_fields) || ($key == "redirect") || ($key == "redirect2") || ($key == "redirect3"))
 		{
 			if ((strpos($key, "password") === false) && (isset($val) && ($val != "")))
 			{
@@ -98,11 +97,11 @@ if ($_POST['html'])
 	$html = 1;	// html
 else
 	$html = 0;	// text
-if ($_POST['no_mime'])
+if (($_POST['no_mime']) || ((isset($_FILES)) && (count($_FILES) > 0) && ($_FILES["upload_file"]["name"] != "")))
 	$no_mime = 1;	// Certain servers can't handle mime messages such as GoDaddy hosting.
 else
 	$no_mime = 0;
-if ($_POST['octet_stream'])
+if (($_POST['octet_stream']) || ((isset($_FILES)) && (count($_FILES) > 0) && ($_FILES["upload_file"]["name"] != "")))
 	$octet_stream = 1;	// If adding attachments, then it might be necessary to set the content type to application/octet-stream.
 else
 	$octet_stream = 0;
@@ -191,7 +190,7 @@ if (isset($password) && isset($password_strength))
 	if ($password_strength == "high")
 	{
 		$symbols = array('~','!','@','#','\$','%','^','&','*','(',')','[',']','{','}','?','+','=','-','_','/','|','\\','.',',','<','>',',',"'",'"',':',';');
-		if (!preg_match('/[A-Za-z]/', $password) || !preg_match('/[0-9]/', $password) || (strpos_a($password, $symbols) < 0))
+		if (!preg_match('/[A-Za-z]/', $password) || !preg_match('/[0-9]/', $password) || (strpos_a($password, $symbols) === false))
 		{
 			$pass_strength_err = true;
 			$err_msg = "Your password is too weak.  Please fill in a password contaning letters, numbers and symbols.";
@@ -364,6 +363,46 @@ if ($http_cnt > 1)
 }
 /////////// Check for robots by counting URLs. ////////////////////
 
+// If attachements, then get files onto server.
+if (isset($_FILES))	{;
+	$bad_file_ext = array("php", "PHP", "htm", "html", "js", "asp", "exe", "cf", "jsp", "sh");
+	foreach($_FILES as $file_key => $file)	{
+		if (basename($file["name"] == ""))	{
+			// If not file was selected, can't upload it. Unset files and get out of here.
+			unset($_FILES);
+			break;
+		}
+		$_POST[$file_key] = $file["name"];
+		$target_dir = "uploads";
+		if (!file_exists($target_dir))
+			mkdir($target_dir);
+		$target_file = $target_dir . "/" . basename($file["name"]);
+		// Check if file already exists
+		if (file_exists($target_file))
+			unlink($target_file);
+		// Check file size
+		if ($file["size"] > 50000000) {
+			$err_code = "file_size";
+			$err_msg = "The file you are trying to send is too large for email.  Please select a different file.";
+			DisplayError($redirect_err_to_src, $err_msg, $err_code, $go_back);
+		}
+		// Allow certain file formats
+		$file_parts = explode(".", $target_file);
+		$ext = $file_parts[count($file_parts) - 1];
+		if (in_array($ext, $bad_file_ext))	{
+			$err_code = "file_type";
+			$err_msg = "The file you are trying to send is of a type that is not allowed to be be emailed.  Please select a different file.";
+			DisplayError($redirect_err_to_src, $err_msg, $err_code, $go_back);
+		}
+		// if everything is ok, try to upload file
+		if (!move_uploaded_file($file["tmp_name"], $target_file)) {
+			$err_code = "upload";
+			$err_msg = "There was an error uploading your file.  Please try again.";
+			DisplayError($redirect_err_to_src, $err_msg, $err_code, $go_back);
+		}
+	}
+}
+
 $mail->from = $from_email;
 $mail->to = $to_email;
 $mail->cc = $cc_email;
@@ -373,18 +412,29 @@ $mail->body = $msg;
 $mail->html = $html;
 $mail->no_mime = $no_mime;
 $mail->octet_stream = $octet_stream;
+if (isset($_FILES))	{
+	$i = 0;
+	foreach($_FILES as $file)	{
+		$mail->attachment[$i] = "uploads/" . $file["name"];
+		$i++;
+	}
+}
 
 $mail->send();
 
-//$email_ext = substr($to_email, strlen($to_email) - 8);
-//if ($email_ext == "@aol.com")	// AOL emails
-//	mail($to_email, $subject, $msg);
-
 /////////////////////////////////////////////////////////////////////////
 // Pipe data to table.  Create table if it does not exist.
 // But first clean entire POST var array:
-foreach ($_POST as $key => $value)
-	$_POST[$key] = CleanVar($value);
+foreach ($_POST as $key => $value)	{
+	if ((!is_array($value)) && (!is_object($value)))
+		$_POST[$key] = CleanVar($value);
+	else	{
+		foreach ($value as $k => $val)	{
+			$value[$k]= CleanVar($val);
+		}
+		$_POST[$key] = $value;
+	}
+}
 	
 $table_name = $_POST['table_name'];
 
@@ -411,11 +461,24 @@ if (isset($table_name) && ($table_name != ""))
 		// Add column for each key.
 		foreach ($_POST as $key => $value)
 		{
-			$key = CleanVar($key);
-			if (in_array($key, $longtext_fields))
-				$query .= "`$key` longtext default NULL, ";
-			elseif (!in_array($key, $ignore_fields))
-				$query .= "`$key` varchar(255) default NULL, ";
+			if ((!is_array($value)) && (!is_object($value)))	{
+				if ((!is_array($key)) && (!is_object($key)))
+					$key = CleanVar($key);
+				if (in_array($key, $longtext_fields))
+					$query .= "`$key` longtext default NULL, ";
+				elseif (!in_array($key, $ignore_fields))
+					$query .= "`$key` varchar(255) default NULL, ";
+			}
+			else	{
+				foreach ($value as $k => $val)	{
+					$k= CleanVar($k);
+					if (in_array($key . "[" . $k . "]", $longtext_fields))
+						$query .= "`" . $key . "[" . $k . "]` longtext default NULL, ";
+					elseif (!in_array($key, $ignore_fields))
+						$query .= "`" . $key . "[" . $k . "]` varchar(255) default NULL, ";
+				}
+			}
+			
 		}
 		// Add created field.
 		$query .= "`created` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP, ";
@@ -427,24 +490,50 @@ if (isset($table_name) && ($table_name != ""))
 	// Add any missing columns due to new fields in form.
 	foreach ($_POST as $key => $value)
 	{
-		$key = CleanVar($key);
-		$field_found = false;
-		$query ="SHOW COLUMNS FROM $bwb_database.$table_name";
-		$result = $bwb_dbh->query($query);
-		while ($row = $result->fetch(PDO::FETCH_ASSOC))
-		{
-			if (($row['Field'] == $key) || ($row['field'] == $key))
-				$field_found = true;
+		if ((!is_array($value)) && (!is_object($value)))	{
+			if ((!is_array($key)) && (!is_object($key)))
+				$key = CleanVar($key);
+			$field_found = false;
+			$query ="SHOW COLUMNS FROM $bwb_database.$table_name";
+			$result = $bwb_dbh->query($query);
+			while ($row = $result->fetch(PDO::FETCH_ASSOC))
+			{
+				if (($row['Field'] == $key) || ($row['field'] == $key))
+					$field_found = true;
+			}
+			if (!$field_found && in_array($key, $longtext_fields))
+			{
+				$query2 = "ALTER TABLE `$table_name` ADD `$key` longtext NULL ";
+				$cnt = $bwb_dbh->exec($query2);
+			}
+			elseif (!$field_found && !in_array($key, $ignore_fields))
+			{
+				$query2 = "ALTER TABLE `$table_name` ADD `$key` VARCHAR( 255 ) NULL ";
+				$cnt = $bwb_dbh->exec($query2);
+			}
 		}
-		if (!$field_found && in_array($key, $longtext_fields))
-		{
-			$query2 = "ALTER TABLE `$table_name` ADD `$key` longtext NULL ";
-			$cnt = $bwb_dbh->exec($query2);
-		}
-		elseif (!$field_found && !in_array($key, $ignore_fields))
-		{
-			$query2 = "ALTER TABLE `$table_name` ADD `$key` VARCHAR( 255 ) NULL ";
-			$cnt = $bwb_dbh->exec($query2);
+		else	{
+			foreach ($value as $k => $val)	{
+				$k= CleanVar($k);
+				$field_found = false;
+				$query ="SHOW COLUMNS FROM $bwb_database.$table_name";
+				$result = $bwb_dbh->query($query);
+				while ($row = $result->fetch(PDO::FETCH_ASSOC))
+				{
+					if (($row['Field'] == $key . "[" . $k . "]") || ($row['field'] == $key . "[" . $k . "]"))
+						$field_found = true;
+				}
+				if (!$field_found && in_array($key . "[" . $k . "]", $longtext_fields))
+				{
+					$query2 = "ALTER TABLE `$table_name` ADD `" . $key . "[" . $k . "]` longtext NULL ";
+					$cnt = $bwb_dbh->exec($query2);
+				}
+				elseif (!$field_found && !in_array($key . "[" . $k . "]", $ignore_fields))
+				{
+					$query2 = "ALTER TABLE `$table_name` ADD `" . $key . "[" . $k . "]` VARCHAR( 255 ) NULL ";
+					$cnt = $bwb_dbh->exec($query2);
+				}
+			}
 		}
 	}
 
@@ -494,7 +583,13 @@ if (isset($table_name) && ($table_name != ""))
 
 	foreach ($_POST as $key => $value)
 	{
-		$key = CleanVar($key);
+		if ((!is_array($key)) && (!is_object($key)))	
+			$key = CleanVar($key);
+		else	{
+			foreach ($key as $k => $val)	{
+				$key[$k]= CleanVar($val);
+			}
+		}
 		if (!in_array($key, $ignore_fields))
 		{
 			if (($value == "") && ($verb == "UPDATE"))
@@ -519,10 +614,19 @@ if (isset($table_name) && ($table_name != ""))
 					$value = doEncrypt($salted_pass, $_POST['email']);
 			}
 	
-			if (!$first) $query .= ", "; else $first = false;
-			if (strpos($value, "'") !== false)
-				$value = addslashes($value);
-			$query .= "`$key` = '$value'";
+			if ((!is_array($value)) && (!is_object($value)))	{
+				if (!$first) $query .= ", "; else $first = false;
+				if (strpos($value, "'") !== false)
+					$value = addslashes($value);
+				$query .= "`$key` = '$value'";
+			}
+			else	{
+				foreach ($value as $k => $val)	{
+					$val = CleanVar($val);
+					if (!$first) $query .= ", "; else $first = false;
+					$query .= "`" . $key . "[" . $k . "]` = '" . $val . "'";
+				}
+			}
 		}
 	}
 	if ($verb == "UPDATE")
@@ -536,13 +640,16 @@ if (isset($table_name) && ($table_name != ""))
 		$query = "SELECT * FROM " . $table_name . " WHERE `" . $where_key . "`='" . $_POST[$where_key] . "'";
 		$result = $bwb_dbh->query($query);
 		$row = $result->fetch(PDO::FETCH_ASSOC);
-		$last_id = $row["id"];
+		if (isset($row["id"]))
+			$last_id = $row["id"];
+		else
+			$last_id = $row[0];
 	}
 	
 
 	/////////////////////////////////////////////
 	// If table is user table for page access, then see if need to activate right now.
-	if ($verb != "UPDATE")
+	if ($verb != "UPDATE" || (isset($_POST['update_and_login']) && ($_POST['update_and_login'] == 1)))
 	{
 		$query = "SELECT option_value FROM `" . BWB_TABLE_PREFIX . "options_selected` WHERE option_name='ActivateNewUsersAutomatically'";
 		$result = $bwb_dbh->query($query);
@@ -560,6 +667,14 @@ if (isset($table_name) && ($table_name != ""))
 			$result = $bwb_dbh->query($query);
 			while ($row = $result->fetch(PDO::FETCH_ASSOC))
 			{
+				if (($row['Key'] == "PRI") || ($row['key'] == "PRI"))	{
+					if (isset($row['Field']))
+						$key_field = $row['Field'];
+					elseif (isset($row['field']))
+						$key_field = $row['field'];
+					else
+						$key_field = "id";
+				}
 				if (($row['field'] == "Active") || ($row['Field'] == "Active"))
 					$got_active = true;
 				if (($row['field'] == "Session") || ($row['Field'] == "Session"))
@@ -573,7 +688,9 @@ if (isset($table_name) && ($table_name != ""))
 			}
 			if ($got_active && $got_session && $got_ip && $got_userid && $got_password)
 			{
-				$query = "UPDATE `$table_name` SET `Active`=1 WHERE id=$last_id";
+				$query = "UPDATE `$table_name` SET `Active`=1 WHERE `UserID`='$userid'";
+				$cnt = $bwb_dbh->exec($query);
+				$query = "UPDATE `$table_name` SET `Active`=1 WHERE `$key_field`=$last_id";
 				$cnt = $bwb_dbh->exec($query);
 				
 				// Account activated, now go ahead and log in.
@@ -585,7 +702,9 @@ if (isset($table_name) && ($table_name != ""))
 				$_SESSION['pub_userid'] = $userid;
 				$session = md5(session_id());
 				$ip = $_SERVER['REMOTE_ADDR'];
-				$query = "UPDATE `" . $table_name . "` SET `Session`='$session', `IP`='$ip' WHERE `UserID` = '$userid'";
+				$query = "UPDATE `" . $table_name . "` SET `Session`='$session', `IP`='$ip' WHERE `UserID`='$userid'";
+				$cnt = $bwb_dbh->exec($query);
+				$query = "UPDATE `" . $table_name . "` SET `Session`='$session', `IP`='$ip' WHERE `$key_field`=$last_id";
 				$cnt = $bwb_dbh->exec($query);
 			}
 		}
@@ -661,6 +780,16 @@ if (isset($html_message_page) && ($html_message_page != ""))
 	}
 }
 
+// If attachements sent, then delete them off of server.
+if (isset($_FILES))	{
+	foreach($_FILES as $file)	{
+		$target_file = $target_dir . "/" . basename($file["name"]);
+		if (file_exists($target_file)) {
+			unlink($target_file);
+		}
+	}
+}
+
 /////////////////////////////////////////////////////////////////////////
 // If data stored in table, then pass along last id to next page.
 if (isset($table_name) && ($table_name != ""))
@@ -679,31 +808,10 @@ exit;
 /////////////////////////////////////////////////////////////////////////
 // Check for valid emails. //////////////////////////////////////////////
 function check_email_address($email) {
-// First, we check that there's one @ symbol, and that the lengths are right
-	if (!ereg("^[^@]{1,64}@[^@]{1,255}$", $email)) {
-		// Email invalid because wrong number of characters in one section, or wrong number of @ symbols.
-		return false;
-	}
-	// Split it into sections to make life easier
-	$email_array = explode("@", $email);
-	$local_array = explode(".", $email_array[0]);
-	for ($i = 0; $i < sizeof($local_array); $i++) {
-		if (!ereg("^(([A-Za-z0-9!#$%&'*+/=?^_`{|}~-][A-Za-z0-9!#$%&'*+/=?^_`{|}~\.-]{0,63})|(\"[^(\\|\")]{0,62}\"))$", $local_array[$i])) {
-		return false;
-		}
-	}
-	if (!ereg("^\[?[0-9\.]+\]?$", $email_array[1])) { // Check if domain is IP. If not, it should be valid domain name
-		$domain_array = explode(".", $email_array[1]);
-		if (sizeof($domain_array) < 2) {
-			return false; // Not enough parts to domain
-		 }
-		for ($i = 0; $i < sizeof($domain_array); $i++) {
-			 if (!ereg("^(([A-Za-z0-9][A-Za-z0-9-]{0,61}[A-Za-z0-9])|([A-Za-z0-9]+))$", $domain_array[$i])) {
-				return false;
-			 }
-		}
-	 }
-	 return true;
+	if (!filter_var($email, FILTER_VALIDATE_EMAIL))
+	 	return false;
+	else
+		return true;
 }
 
 /****************************************************************
