@@ -13,6 +13,8 @@
 var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
 var popup_msg = new PopupMsg(param_array);
 
+window.parent.document.title = document.title;
+
 function OpenHelpWindow()
 {
 	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#install_plugin_into_page", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
@@ -32,7 +34,7 @@ function SelectPage(page_name, i)
 	page_name_select_ctl = "page_name_select" + i;
 	document.getElementById(page_name_select_ctl).className = "button_sub_level_1 down_sub";
 	
-	document.getElementById('selected_page').innerHTML = "<b><em>" + page_name + "</em></b> page selected";
+	document.getElementById('selected_page').innerHTML = "<b><em>" + page_name + "</em></b> " + ADD_PLUGIN_TO_PAGE_PAGE_SELECTED;
 	CheckForm();
 }
 
@@ -52,7 +54,7 @@ function SelectPlugin(plugin, i)
 	plugin_name_select_ctl = "plugin_select" + i;
 	document.getElementById(plugin_name_select_ctl).className = "button_sub_level_1 down_sub";
 	
-	document.getElementById('selected_plugin').innerHTML = "<b><em>" + plugins[plugin] + "</em></b> plugin selected";
+	document.getElementById('selected_plugin').innerHTML = "<b><em>" + plugins[plugin] + "</em></b> " + ADD_PLUGIN_TO_PAGE_PLUGIN_SELECTED;
 	CheckForm();
 }
 
