@@ -14,21 +14,23 @@ var browser_version = BrowserDetect.version;
 var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
 var popup_msg = new PopupMsg(param_array);
 
+window.parent.document.title = document.title;
+
 function DeleteConfirm(delete_mode)
 {
 	popup_msg.top_offset = 0;
 	popup_msg.left_offset = 300;
 	popup_msg.popup_msg_type = 3;
 	popup_msg.popup_btn_cnt = 2;
-	popup_msg.popup_button_2_span = "Yes";
-	popup_msg.popup_button_1_span = "No";
+	popup_msg.popup_button_2_span = YES_WORD;
+	popup_msg.popup_button_1_span = NO_WORD;
 	popup_msg.popup_timeout = -1;
 	
 	if (delete_mode == "blog")
 	{
 		var list = document.getElementById('selectBlogToDelete');
 		var blog = list.options[list.selectedIndex].innerHTML;
-		popup_msg.popup_msg_cell = "Are your sure you want to delete <b>" + blog + "</b>?";
+		popup_msg.popup_msg_cell = DELETE_PAGE_OR_BLOG_DELETE_BLOG_CONFIRM_1_MSG + " <b>" + blog + "</b>" + DELETE_PAGE_OR_BLOG_DELETE_BLOG_CONFIRM_2_MSG;
 		document.getElementById("popup_button_2_span").onclick = function() { DeleteBlog(); };
 	}
 	else if (delete_mode == "recall_plugin")
@@ -37,12 +39,12 @@ function DeleteConfirm(delete_mode)
 		var plugin_name = list.options[list.selectedIndex].innerHTML;
 		var plugin_name_arr = plugin_name.split("-");
 		plugin_name = plugin_name_arr[0];
-		popup_msg.popup_msg_cell = "Are your sure you want to recall the <b>" + plugin_name + "</b> plugin?";
+		popup_msg.popup_msg_cell = DELETE_PAGE_OR_BLOG_RECALL_PLUGIN_CONFIRM_1_MSG + " <b>" + plugin_name + "</b> " + DELETE_PAGE_OR_BLOG_RECALL_PLUGIN_CONFIRM_2_MSG;
 		document.getElementById("popup_button_2_span").onclick = function() { RecallPlugin(); };
 	}
 	else	// page
 	{
-		popup_msg.popup_msg_cell = "Are your sure you want to delete the <b>" + document.getElementById("selectPageToDelete").value + "</b> page?";
+		popup_msg.popup_msg_cell = DELETE_PAGE_OR_BLOG_DELETE_PAGE_CONFIRM_1_MSG + " <b>" + document.getElementById("selectPageToDelete").value + "</b> " + DELETE_PAGE_OR_BLOG_DELETE_PAGE_CONFIRM_2_MSG;
 		document.getElementById("popup_button_2_span").onclick = function() { DeletePage(); };
 	}
 	document.getElementById("popup_button_1_span").onclick = function () { HidePopupMsg(); };
