@@ -31,11 +31,30 @@
 // Added browser CSS reset button.
 // Revised: 1/12/2015	ELL
 // Replaced deprecated font-stretch with letter-spacing.
-
+// Revised: 2/14/2015	ELL
+// Added visibility.
+// Added full compliment of font-size units.
+// Added full compliment of length units to border.
+// Added full compliment of length units to all paddings.
+// Added full compliment of length units to existing unit fields.
+// Revised: 5/15/2015	ELL
+// Added background transparancy.
+// Added overflow-x and overflow-y.
+// Revised: 6/10/2015	ELL
+// Added margin set to 0 on body upen clicking "Load Browser Reset CSS".
+// Revised: 9/21/2015	ELL
+// Added text-indent attribute.
+// Revised: 1/19/2016	ELL
+// Overhauled preview to use popup page.
+// Revised: 3/25/2016	ELL
+// Replace numeric placeholders of -1 and -1000000 for not set with "-not set".  Added code to clear "-not set-" when user wants to type
+// and code to re-apply "-not set-" when user clears the field.
 
 var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
 var popup_msg = new PopupMsg(param_array);
 
+window.parent.document.title = document.title;
+
 function popupcolorpicker(form_name, field_name)
 {
 	var start_color = document.getElementById(field_name).value;
@@ -56,13 +75,12 @@ function enable_disable_controls(ShowMessage)
 		document.getElementById("font").disabled = false;
 		document.getElementById("font2").disabled = false;
 		document.getElementById("font3").disabled = false;
-		document.getElementById("font_size").disabled = false;
+		document.getElementById("font_size_units").disabled = false;
 		document.getElementById("text_color").disabled = false;
 		document.getElementById("align").disabled = false;
 		document.getElementById("vertical_align").disabled = false;
 		document.getElementById("display").disabled = false;
 		document.getElementById("weight").disabled = false;
-		//document.getElementById("font_stretch").disabled = false;
 		document.getElementById("letter_spacing_units").disabled = false;
 		document.getElementById("italic").disabled = false;
 		document.getElementById("underline").disabled = false;
@@ -73,12 +91,15 @@ function enable_disable_controls(ShowMessage)
 		document.getElementById("small_caps").disabled = false;
 		document.getElementById("no_text_decoration").disabled = false;
 		document.getElementById("shadow").disabled = false;
-		//document.getElementById("line_height").disabled = false;
 		document.getElementById("line_height_units").disabled = false;
+		document.getElementById("text_indent").disabled = false;
+		document.getElementById("text_indent_units").disabled = false;
 		
 		document.getElementById("bkgd_color").disabled = false;
+		document.getElementById("bkgd_transparent").disabled = false;
 		document.getElementById("bkgd_opacity").disabled = false;
 		document.getElementById("border").disabled = false;
+		document.getElementById("border_units").disabled = false;
 		document.getElementById("border_color").disabled = false;
 		document.getElementById("border_style").disabled = false;
 		document.getElementById("outline_style").disabled = false;
@@ -91,6 +112,10 @@ function enable_disable_controls(ShowMessage)
 		document.getElementById("padding_right").disabled = false;
 		document.getElementById("padding_bottom").disabled = false;
 		document.getElementById("padding_left").disabled = false;
+		document.getElementById("padding_top_units").disabled = false;
+		document.getElementById("padding_right_units").disabled = false;
+		document.getElementById("padding_bottom_units").disabled = false;
+		document.getElementById("padding_left_units").disabled = false;
 
 		document.getElementById("width").disabled = false;
 		document.getElementById("width_units").disabled = false;
@@ -120,6 +145,8 @@ function enable_disable_controls(ShowMessage)
 		document.getElementById("position_bottom_units").disabled = false;
 		document.getElementById("z_index").disabled = false;
 		document.getElementById("overflow").disabled = false;
+		document.getElementById("overflow_x").disabled = false;
+		document.getElementById("overflow_y").disabled = false;
 		document.getElementById("clip_top").disabled = false;
 		document.getElementById("clip_top_units").disabled = false;
 		document.getElementById("clip_right").disabled = false;
@@ -159,15 +186,50 @@ function enable_disable_controls(ShowMessage)
 		
 		document.getElementById("background_size").disabled = false;
 		
+		document.getElementById("visibility").disabled = false;
+		
 		enable_disable_shadow();
 		margin_auto_clicked("top");
 		margin_auto_clicked("bottom");
 		margin_auto_clicked("left");
 		margin_auto_clicked("right");
+		enable_disable_background_color();
 		enable_disable_background_positions();
 		enable_disable_background_sizes();
 		enable_disable_letter_spacing();
 		enable_disable_line_height();
+		enable_disable_font_size();
+		
+		
+		CheckFormatOnUnitSelect("border_units", "border", 0);
+		CheckFormatOnUnitSelect("padding_top_units", "padding_top", 0);
+		CheckFormatOnUnitSelect("padding_right_units", "padding_right", 0);
+		CheckFormatOnUnitSelect("padding_bottom_units", "padding_bottom", 0);
+		CheckFormatOnUnitSelect("padding_left_units", "padding_left", 0);
+		CheckFormatOnUnitSelect("radius_top_left_units", "radius_top_left", 0);
+		CheckFormatOnUnitSelect("radius_top_right_units", "radius_top_right", 0);
+		CheckFormatOnUnitSelect("radius_bottom_right_units", "radius_bottom_right", 0);
+		CheckFormatOnUnitSelect("radius_bottom_left_units", "radius_bottom_left", 0);
+		CheckFormatOnUnitSelect("margin_top_units", "margin_top", 0);
+		CheckFormatOnUnitSelect("margin_right_units", "margin_right", 0);
+		CheckFormatOnUnitSelect("margin_bottom_units", "margin_bottom", 0);
+		CheckFormatOnUnitSelect("margin_left_units", "margin_left", 0);
+		CheckFormatOnUnitSelect("width_units", "width", 0);
+		CheckFormatOnUnitSelect("height_units", "height", 0);
+		CheckFormatOnUnitSelect("position_left_units", "position_left", 0);
+		CheckFormatOnUnitSelect("position_top_units", "position_top", 0);
+		CheckFormatOnUnitSelect("position_right_units", "position_right", 0);
+		CheckFormatOnUnitSelect("position_bottom_units", "position_bottom", 0);
+		CheckFormatOnUnitSelect("clip_top_units", "clip_top", 0);
+		CheckFormatOnUnitSelect("clip_right_units", "clip_right", 0);
+		CheckFormatOnUnitSelect("clip_bottom_units", "clip_bottom", 0);
+		CheckFormatOnUnitSelect("clip_left_units", "clip_left", 0);
+		CheckFormatOnUnitSelect("background_position_units", "background_position_x", 0);
+		CheckFormatOnUnitSelect("background_position_units", "background_position_y", 0);
+		CheckFormatOnUnitSelect("background_width_units", "background_width", 0);
+		CheckFormatOnUnitSelect("background_height_units", "background_height", 0);
+		CheckFormatOnUnitSelect("letter_spacing_units", "letter_spacing", 1);
+		CheckFormatOnUnitSelect("line_height_units", "line_height", 2);
 		
 		document.getElementById("text_table").style.backgroundColor = "#FFCCCC";
 		document.getElementById("background_table").style.backgroundColor = "#CCFFCC";
@@ -184,12 +246,12 @@ function enable_disable_controls(ShowMessage)
 		document.getElementById("font2").disabled = true;
 		document.getElementById("font3").disabled = true;
 		document.getElementById("font_size").disabled = true;
+		document.getElementById("font_size_units").disabled = true;
 		document.getElementById("text_color").disabled = true;
 		document.getElementById("align").disabled = true;
 		document.getElementById("vertical_align").disabled = true;
 		document.getElementById("display").disabled = true;
 		document.getElementById("weight").disabled = true;
-		//document.getElementById("font_stretch").disabled = true;
 		document.getElementById("letter_spacing").disabled = true;
 		document.getElementById("letter_spacing_units").disabled = true;
 		document.getElementById("italic").disabled = true;
@@ -207,10 +269,14 @@ function enable_disable_controls(ShowMessage)
 		document.getElementById("shadow_blur").disabled = true;
 		document.getElementById("line_height").disabled = true;
 		document.getElementById("line_height_units").disabled = true;
+		document.getElementById("text_indent").disabled = true;
+		document.getElementById("text_indent_units").disabled = true;
 		
 		document.getElementById("bkgd_color").disabled = true;
+		document.getElementById("bkgd_transparent").disabled = true;
 		document.getElementById("bkgd_opacity").disabled = true;
 		document.getElementById("border").disabled = true;
+		document.getElementById("border_units").disabled = true;
 		document.getElementById("border_color").disabled = true;
 		document.getElementById("border_style").disabled = true;
 		document.getElementById("outline_style").disabled = true;
@@ -223,6 +289,10 @@ function enable_disable_controls(ShowMessage)
 		document.getElementById("padding_right").disabled = true;
 		document.getElementById("padding_bottom").disabled = true;
 		document.getElementById("padding_left").disabled = true;
+		document.getElementById("padding_top_units").disabled = true;
+		document.getElementById("padding_right_units").disabled = true;
+		document.getElementById("padding_bottom_units").disabled = true;
+		document.getElementById("padding_left_units").disabled = true;
 		
 		document.getElementById("margin_top").disabled = true;
 		document.getElementById("margin_right").disabled = true;
@@ -263,6 +333,8 @@ function enable_disable_controls(ShowMessage)
 		document.getElementById("position_bottom_units").disabled = true;
 		document.getElementById("z_index").disabled = true;
 		document.getElementById("overflow").disabled = true;
+		document.getElementById("overflow_x").disabled = true;
+		document.getElementById("overflow_y").disabled = true;
 		document.getElementById("clip_top").disabled = true;
 		document.getElementById("clip_top_units").disabled = true;
 		document.getElementById("clip_right").disabled = true;
@@ -306,6 +378,8 @@ function enable_disable_controls(ShowMessage)
 		document.getElementById("background_height").disabled = true;
 		document.getElementById("background_height_units").disabled = true;
 		
+		document.getElementById("visibility").disabled = true;
+		
 		document.getElementById("text_table").style.backgroundColor = "#D9D9D9";
 		document.getElementById("background_table").style.backgroundColor = "#D9D9D9";
 		document.getElementById("border_table").style.backgroundColor = "#D9D9D9";
@@ -318,7 +392,7 @@ function enable_disable_controls(ShowMessage)
 	if (ShowMessage == 1)
 	{
 		popup_msg.popup_msg_type = 2;
-		popup_msg.status_msg = "Click 'Update' to commit changes.";
+		popup_msg.status_msg = EDIT_CSS_CLICK_UPDATE_TO_COMMIT_MSG;
 		popup_msg.popup_timeout = -1;
 		popup_msg.top_offset = 0;
 		popup_msg.left_offset = 500;
@@ -410,7 +484,7 @@ function enable_disable_background_sizes()
 
 function enable_disable_letter_spacing()
 {
-	if (document.getElementById("letter_spacing_units").value == 1)
+	if ((document.getElementById("letter_spacing_units").value > 0) && (document.getElementById("letter_spacing_units").value < 15))
 		document.getElementById("letter_spacing").disabled = false;
 	else
 		document.getElementById("letter_spacing").disabled = true;
@@ -425,24 +499,27 @@ function enable_disable_line_height()
 }
 
 //////////////////////////////////////////////////////////////////////////////////////
-function UpdateMessage(xmlhttp)
+function UpdateMessage(xmlhttp, show_preview)
 {
 	xmlhttp.onreadystatechange=function()
 	{
 		if (xmlhttp.readyState==4)
 		{
+//			alert(xmlhttp.responseText);
 			if (xmlhttp.responseText.length > 0)
-				popup_msg.status_msg = "Update complete: " + xmlhttp.responseText;
+				popup_msg.status_msg = EDIT_CSS_UPDATE_COMPLETE_MSG + ": " + xmlhttp.responseText;
 			else
-				popup_msg.status_msg = "Update complete";
+				popup_msg.status_msg = EDIT_CSS_UPDATE_COMPLETE_MSG;
 			popup_msg.popup_timeout = 2000;
+			if (show_preview !== false)
+				ShowPreview(show_preview);
 		}
 		else if (xmlhttp.readyState==1)
-			popup_msg.status_msg = "Update ready to send...";
+			popup_msg.status_msg = EDIT_CSS_UPDATE_READY_TO_SEND_MSG;
 		else if (xmlhttp.readyState==2)
-			popup_msg.status_msg = "Update sent";
+			popup_msg.status_msg = EDIT_CSS_UPDATE_SENT_MSG;
 		else if (xmlhttp.readyState==3)
-			popup_msg.status_msg = "Updating...";
+			popup_msg.status_msg = EDIT_CSS_UPDATING_MSG;
 		popup_msg.ShowPopupMsg();
 	}
 	return (xmlhttp);
@@ -454,7 +531,7 @@ function LoadBrowserResetParams()
 	var params = "";
 	
 	popup_msg.popup_msg_type = 1;
-	popup_msg.status_msg = "Starting update...";
+	popup_msg.status_msg = EDITOR_STARTING_UPDATE_MSG;
 	popup_msg.popup_timeout = -1;
 	popup_msg.top_offset = 0;
 	popup_msg.left_offset = 500;
@@ -466,7 +543,7 @@ function LoadBrowserResetParams()
 	{
 		xmlhttp.open("POST","save_css.php",true);
 		xmlhttp.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
-		xmlhttp = UpdateMessage(xmlhttp);
+		xmlhttp = UpdateMessage(xmlhttp, false);
 
 		params = "submit=Update";
 		params = params + "&quick_setup=1";
@@ -485,21 +562,52 @@ function LoadBrowserResetParams()
 		params = params + "&padding_right=0";
 		params = params + "&padding_left=0";
 		params = params + "&padding_bottom=0";
+		params = params + "&padding_top_units=0";
+		params = params + "&padding_right_units=0";
+		params = params + "&padding_left_units=0";
+		params = params + "&padding_bottom_units=0";
 		params = params + "&border=0";
+		params = params + "&border_units=0";
 		params = params + "&border_sides=15";
 		params = params + "&submit_action=Update";
 		
 		xmlhttp.send(params);
 	}
+	
+	var xmlhttp2;
+	xmlhttp2 = getXmlHttpRequestObject();
+	if (xmlhttp2.readyState == 4 || xmlhttp2.readyState == 0)
+	{
+		xmlhttp2.open("POST","save_css.php",true);
+		xmlhttp2.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
+		xmlhttp2 = UpdateMessage(xmlhttp2);
 
-	var msg = "Your CSS has been setup to reset browsers by setting all of the margins, paddings and borders for the HTML element to 0.";
+		params = "submit=Update";
+		params = params + "&quick_setup=1";
+		params = params + "&style_sheet=site";
+		params = params + "&class=body";
+		params = params + "&use_table_data=1";
+		params = params + "&margin_top=0";
+		params = params + "&margin_top_units=0";
+		params = params + "&margin_right=0";
+		params = params + "&margin_right_units=0";
+		params = params + "&margin_left=0";
+		params = params + "&margin_left_units=0";
+		params = params + "&margin_bottom=0";
+		params = params + "&margin_bottom_units=0";
+		params = params + "&submit_action=Update";
+		
+		xmlhttp2.send(params);
+	}
+
+	var msg = EDIT_CSS_RESET_BROWSER_CSS_COMPLETE_MSG;
 	mTimer2 = setTimeout(function() { DisplayFinalMsg(msg) }, 3000);
 }
 
 ////////////////////////////////////////////////////////////////////////////////////
 function LoadCenterParams()
 {
-	alert("We will now load styles with settings that will cause your website to appear centered with a fixed width.");
+	alert(EDIT_CSS_LOAD_CENTERED_PAGES_CSS_ALERT_MSG);
 	
 	var params = "";
 	
@@ -516,7 +624,7 @@ function LoadCenterParams()
 	{
 		xmlhttp.open("POST","save_css.php",true);
 		xmlhttp.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
-		xmlhttp = UpdateMessage(xmlhttp);
+		xmlhttp = UpdateMessage(xmlhttp, false);
 
 		params = "submit=Update";
 		params = params + "&quick_setup=1";
@@ -536,7 +644,7 @@ function LoadCenterParams()
 	{
 		xmlhttp2.open("POST","save_css.php",true);
 		xmlhttp2.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
-		xmlhttp2 = UpdateMessage(xmlhttp2);
+		xmlhttp2 = UpdateMessage(xmlhttp2, false);
 
 		params = "submit=Update";
 		params = params + "&quick_setup=1";
@@ -559,19 +667,19 @@ function LoadCenterParams()
 		xmlhttp2.send(params);
 	}
 		
-	var msg = "Your site has been centered.  You may want to revise the 'body' width, the 'body' background color, and the '#wrap' backgound color to your needs.";
+	var msg = EDIT_CSS_LOAD_CENTERED_PAGES_CSS_COMPLETE_MSG;
 	mTimer2 = setTimeout(function() { DisplayFinalMsg(msg) }, 5000);
 }
 
 //////////////////////////////////////////////////////////////////////////////////////
 function LoadStickyFooterParams()
 {
-	alert("We will now load styles with settings that will cause the footer of your web pages to 'stick' to the bottom of your browser window.");
+	alert(EDIT_CSS_LOAD_STICKY_FOOTERS_ALERT_MSG);
 	
 	var params = "";
 	
 	popup_msg.popup_msg_type = 1;
-	popup_msg.status_msg = "Starting update...";
+	popup_msg.status_msg = EDITOR_STARTING_UPDATE_MSG;
 	popup_msg.popup_timeout = -1;
 	popup_msg.top_offset = 0;
 	popup_msg.left_offset = 500;
@@ -583,7 +691,7 @@ function LoadStickyFooterParams()
 	{
 		xmlhttp.open("POST","save_css.php",true);
 		xmlhttp.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
-		xmlhttp = UpdateMessage(xmlhttp);
+		xmlhttp = UpdateMessage(xmlhttp, false);
 
 		params = "submit=Update";
 		params = params + "&quick_setup=1";
@@ -603,7 +711,7 @@ function LoadStickyFooterParams()
 	{
 		xmlhttp2.open("POST","save_css.php",true);
 		xmlhttp2.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
-		xmlhttp2 = UpdateMessage(xmlhttp2);
+		xmlhttp2 = UpdateMessage(xmlhttp2, false);
 
 		params = "submit=Update";
 		params = params + "&quick_setup=1";
@@ -628,7 +736,7 @@ function LoadStickyFooterParams()
 	{
 		xmlhttp3.open("POST","save_css.php",true);
 		xmlhttp3.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
-		xmlhttp3 = UpdateMessage(xmlhttp3);
+		xmlhttp3 = UpdateMessage(xmlhttp3, false);
 
 		params = "submit=Update";
 		params = params + "&quick_setup=1";
@@ -648,7 +756,7 @@ function LoadStickyFooterParams()
 	{
 		xmlhttp4.open("POST","save_css.php",true);
 		xmlhttp4.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
-		xmlhttp4 = UpdateMessage(xmlhttp4);
+		xmlhttp4 = UpdateMessage(xmlhttp4, false);
 
 		params = "submit=Update";
 		params = params + "&quick_setup=1";
@@ -673,7 +781,7 @@ function LoadStickyFooterParams()
 		xmlhttp4.send(params);
 	}
 		
-	var msg = "Your footer will now stick to the bottom of the browser window.  You may also want to revise the 'footer' height and the background color to your needs. Be sure to set the footer's margin top to the same but negative of the footer's height.";
+	var msg = EDIT_CSS_LOAD_STICKY_FOOTERS_COMPLETE_MSG;
 	mTimer2 = setTimeout(function() { DisplayFinalMsg(msg) }, 5000);
 }
 
@@ -693,13 +801,6 @@ function OpenHelpWindow()
 	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#edit_css", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
 }
 
-///////////////////////////////////////////////////////////////////////////////////////
-function SubmitForm(submit_action)
-{
-	document.getElementById('submit_action').value = submit_action;
-	document.getElementById('frm_site_styles').submit();
-}
-
 ///////////////////////////////////////////////////////////////////////////////////////
 function CheckBorderParams(element)
 {
@@ -708,10 +809,10 @@ function CheckBorderParams(element)
 		var msg = '';
 		
 		if ((!document.getElementById('border_top').checked) && (!document.getElementById('border_bottom').checked) && (!document.getElementById('border_left').checked) && (!document.getElementById('border_right').checked))
-			msg = "It appears that you are trying to setup a border, but you don't have any sides selected.  You must check at least one of the boxes labeled <b>Top</b>, <b>Bottom</b>, <b>Left</b> or <b>Right</b>.";
+			msg = EDIT_CSS_BORDER_REQUIREMENTS_MSG;
 			
 		if (document.getElementById('border_style').value == "-not selected-")
-			msg = msg + "<br/><br/>You must specify a <b>border style</b> in order for a border to display.";
+			msg = msg + EDIT_CSS_BORDER_REQUIREMENTS_STYLE_ADENDUM_MSG;
 			
 		if (msg != '')
 		{
@@ -729,10 +830,10 @@ function CheckBorderParams(element)
 
 function CheckLetterSpacing(element)
 {
-	if (((element.value != 1) && (element.value != -1)) && (document.getElementById('letter_spacing').value != -1000000) && (document.getElementById('letter_spacing').value != '-not set-') && (document.getElementById('letter_spacing').value != ''))
+	if (((element.value == 0) || (element.value > 14)) && (document.getElementById('letter_spacing').value != -1000000) && (document.getElementById('letter_spacing').value != '-not set-') && (document.getElementById('letter_spacing').value != ''))
 	{
 		popup_msg.popup_msg_type = 2;
-		popup_msg.status_msg = "You have selected <b>Normal</b>, <b>Initial</b> or <b>Inherit</b> for your letter spacing, yet you have a number set for letter spacing. Note that the number you have selected will be ignored.  If you want to set a letter spacing, choose <b>px</b> instead.";
+		popup_msg.status_msg = EDIT_CSS_LETTER_SPACING_REQUIREMENTS_MSG;
 		popup_msg.popup_timeout = -1;
 		popup_msg.top_offset = 0;
 		popup_msg.left_offset = 250;
@@ -741,18 +842,24 @@ function CheckLetterSpacing(element)
 		popup_msg.ShowPopupMsg();
 	}
 	
-	if (element.value == 1)
+	if ((element.value > 0) && (element.value < 15))
 		document.getElementById("letter_spacing").disabled = false;
 	else
 		document.getElementById("letter_spacing").disabled = true;
+		
+	if ((element.value > 0) && (element.value < 3))	{
+		letter_spacing = document.getElementById("letter_spacing").value;
+		var letter_spacing_arr = letter_spacing.split(".");
+		document.getElementById("letter_spacing").value = letter_spacing_arr[0];
+	}
 }
 
 function CheckLineHeight(element)
 {
-	if (((element.value == 0) || (element.value > 3)) && (document.getElementById('line_height').value != -1) && (document.getElementById('line_height').value != '-not set-') && (document.getElementById('line_height').value != ''))
+	if (((element.value == 0) || (element.value > 15)) && (document.getElementById('line_height').value != -1) && (document.getElementById('line_height').value != '-not set-') && (document.getElementById('line_height').value != ''))
 	{
 		popup_msg.popup_msg_type = 2;
-		popup_msg.status_msg = "You have selected <b>Normal</b> or <b>Inherit</b> for your line height, yet you have a positive number set for line height. Note that the number you have selected will be ignored.  If you want to set a line height, choose <b>Bultiplyer</b>, <b>%</b> or <b>px</b> instead.";
+		popup_msg.status_msg = EDIT_CSS_LINE_HEIGHT_REQUIREMENTS_MSG;
 		popup_msg.popup_timeout = -1;
 		popup_msg.top_offset = 0;
 		popup_msg.left_offset = 250;
@@ -761,10 +868,16 @@ function CheckLineHeight(element)
 		popup_msg.ShowPopupMsg();
 	}
 	
-	if ((element.value < 1) || (element.value > 3))
+	if ((element.value < 1) || (element.value > 15))
 		document.getElementById("line_height").disabled = true;
 	else
 		document.getElementById("line_height").disabled = false;
+		
+	if ((element.value > 1) && (element.value < 4))	{
+		line_height = document.getElementById("line_height").value;
+		var line_height_arr = line_height.split(".");
+		document.getElementById("line_height").value = line_height_arr[0];
+	}
 }
 
 ////////////////////////////////////////////////////////////////////////////
@@ -875,7 +988,7 @@ function UpdateImage(i)
 			var mImageTimer = setTimeout("CheckBkgndImage('" + image_path + "', '" + photo_img + "');", 2000);
 		}
 		else	{
-			html = "<img alt='photo' src='/manage/images/upload_photo_placeholder.jpg' style='width: 104px; height: 104px;' id='photo_img" + i + "' />";
+			html = "<img alt='photo' src='/manage/theme/" + theme + "/images/upload_photo_placeholder.jpg' style='width: 104px; height: 104px;' id='photo_img" + i + "' />";
 		}
 		
 		document.getElementById(preview_ctl).innerHTML = html;
@@ -902,7 +1015,7 @@ function ChangeSort(bAlpha)
 	var params = "";
 	
 	popup_msg.popup_msg_type = 1;
-	popup_msg.status_msg = "Sorting class list...";
+	popup_msg.status_msg = EDIT_CSS_SORTING_CLASS_LIST_MSG;
 	popup_msg.popup_timeout = -1;
 	popup_msg.top_offset = 0;
 	popup_msg.left_offset = 500;
@@ -933,21 +1046,127 @@ function UpdateMessage2(xmlhttp)
 			if (xmlhttp.responseText.length > 0)
 			{
 				document.getElementById("goto_class_div").innerHTML = xmlhttp.responseText;
-				popup_msg.status_msg = "Sort complete";
+				popup_msg.status_msg = EDIT_CSS_SORT_COMPLETE;
 			}
 			popup_msg.popup_timeout = 1000;
 		}
 		else if (xmlhttp.readyState==1)
-			popup_msg.status_msg = "Query ready to send...";
+			popup_msg.status_msg = QUERY_READY_TO_SEND;
 		else if (xmlhttp.readyState==2)
-			popup_msg.status_msg = "Query sent";
+			popup_msg.status_msg = QUERY_SENT;
 		else if (xmlhttp.readyState==3)
-			popup_msg.status_msg = "Sorting...";
+			popup_msg.status_msg = EDIT_CSS_SORTING_MSG;
 		popup_msg.ShowPopupMsg();
 	}
 	return (xmlhttp);
 }
 
+///////////////////////////////////////////////////////////////////////////////////////////////////////////
+function enable_disable_font_size()
+{
+	var units = document.getElementById("font_size_units").value;
+	var font_size = "";
+	
+	var no_length_arr = new Array("xx-small","x-small","small","medium","large","x-large","xx-large","smaller","larger","initial","inherit");
+	var integer_length_arr = new Array("px","%");
+	
+	if (no_length_arr.indexOf(units) > -1)
+		document.getElementById("font_size").disabled = true;
+	else
+		document.getElementById("font_size").disabled = false;
+		
+	if (integer_length_arr.indexOf(units) > -1)	{
+		font_size = document.getElementById("font_size").value;
+		var font_size_arr = font_size.split(".");
+		document.getElementById("font_size").value = font_size_arr[0];
+	}
+}
+
+function CheckFormatOnUnitSelect(unit_el_id, length_el_id, offset)
+{
+	var units = document.getElementById(unit_el_id).value;
+	var length = "";
+			
+	if (units < (2 + offset))	{
+		length = document.getElementById(length_el_id).value;
+		var length_arr = length.split(".");
+		document.getElementById(length_el_id).value = length_arr[0];
+	}
+}
+
+function CheckOverflowLists(selection, list)
+{
+	if ((selection != "-not selected-") && (list == "xy"))	{
+		document.getElementById("overflow_x").value = "-not selected-";
+		document.getElementById("overflow_y").value = "-not selected-";
+	}
+	else if ((selection != "-not selected-") && ((list == "x") || (list == "y")))	{
+		document.getElementById("overflow").value = "-not selected-";
+	}
+}
+
+function enable_disable_background_color()
+{
+	if (document.getElementById("bkgd_transparent").checked)	{
+		document.getElementById("bkgd_color").value = "-not set-";
+		document.getElementById("bkgd_color").disabled = true;
+		document.getElementById("bkgd_opacity").value = -1;
+		document.getElementById("bkgd_opacity").disabled = true;
+	}
+	else	{
+		document.getElementById("bkgd_color").disabled = false;
+		document.getElementById("bkgd_opacity").disabled = false;
+	}
+}
+
+function PreviewPageSelect()
+{
+	var ntop = tempY - 1600;
+	var strtop = ntop + "px";
+	document.getElementById("page_select_div").style.display = "block";
+	document.getElementById("page_select_div").style.bottom = strtop;
+}
+var preview_window;
+function Preview(page_name, do_refresh)
+{
+	document.getElementById("page_select_div").style.display = "none";
+	
+	UpdateCSS('Preview', page_name + "@@@@@" + do_refresh);
+}
+function ShowPreview(page_name_do_refresh)
+{
+	var params = page_name_do_refresh.split("@@@@@");
+	page_name = params[0];
+	do_refresh = params[1];
+	if (do_refresh != 1)	{
+		var style_sheet = document.getElementById('style_sheet').value;
+		var preview_page_string = "preview_page.php?page_name=" + page_name + "&special=3&mode=0&blog_id=0&style_sheet=" + style_sheet;
+		preview_window = window.open(preview_page_string, "Preview", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=900,width=1000");
+	}
+	else
+		preview_window.location.reload();
+}
+
+function TextFieldClick(el)
+{
+	if (el.value == _NOT_SET_)	{
+		el.value = "";
+		el.className = "";
+	}
+}
+function TextFieldChange(el)
+{
+	el.value = el.value.replace(/[a-z]/gi, '');
+}
+function TextFieldBlur(el)
+{
+	if (el.value == "")	{
+		el.value = _NOT_SET_;
+		el.className = "not_set";
+	}
+}
+
+
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////
 function ResizeWorkspace(mainWidth, mainHeight, menuWidth, headerHeight) {
 
