@@ -9,6 +9,8 @@
 var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
 var popup_msg = new PopupMsg(param_array);
 
+window.parent.document.title = document.title;
+
 function OpenHelpWindow()
 {
 	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#edit_favicon", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
@@ -20,9 +22,9 @@ function DeleteConfirm()
 	popup_msg.left_offset = 300;
 	popup_msg.popup_msg_type = 3;
 	popup_msg.popup_btn_cnt = 2;
-	popup_msg.popup_msg_cell = "Are you sure you want to delete the favicon?";
-	popup_msg.popup_button_2_span = "Yes";
-	popup_msg.popup_button_1_span = "No";
+	popup_msg.popup_msg_cell = EDIT_FAVICON_DELETE_FAVICON_CONFIRM;
+	popup_msg.popup_button_2_span = YES_WORD;
+	popup_msg.popup_button_1_span = NO_WORD;
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
 	document.getElementById("popup_button_2_span").onclick = function () { DeleteFavicon(); };
