@@ -14,6 +14,11 @@
 var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
 var popup_msg = new PopupMsg(param_array);
 
+window.parent.document.title = document.title;
+
+var browser = BrowserDetect.browser;
+var browser_version = BrowserDetect.version;
+
 function Indent(level)
 {
 	var indent = "";
@@ -37,9 +42,9 @@ function DeleteConfirm(item_text, ID, i)
 	popup_msg.left_offset = 300;
 	popup_msg.popup_msg_type = 3;
 	popup_msg.popup_btn_cnt = 2;
-	popup_msg.popup_msg_cell = "Are you sure you want to delete the <b>" + item_text + "</b> menu item?";
-	popup_msg.popup_button_2_span = "Yes";
-	popup_msg.popup_button_1_span = "No";
+	popup_msg.popup_msg_cell = EDIT_MENU_ITEMS_DELETE_ITEM_CONFIRM_1_MSG + " <b>" + item_text + "</b> " + EDIT_MENU_ITEMS_DELETE_ITEM_CONFIRM_2_MSG;
+	popup_msg.popup_button_2_span = YES_WORD;
+	popup_msg.popup_button_1_span = NO_WORD;
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
 	document.getElementById("popup_button_2_span").onclick = function () { DeleteMenuItem(ID); };
@@ -54,7 +59,7 @@ function DeleteMenuItem(IDRemove)
 	menu = document.getElementById("selectMenu").value;
 	
 	popup_msg.popup_msg_type = 1;
-	popup_msg.status_msg = "Starting delete...";
+	popup_msg.status_msg = EDIT_MENU_ITEMS_STARTING_DELETE_MSG;
 	popup_msg.popup_timeout = -1;
 	popup_msg.top_offset = 0;
 	popup_msg.left_offset = 500;
@@ -143,7 +148,7 @@ function UpdateAll()
 	var URL;
 
 	popup_msg.popup_msg_type = 1;
-	popup_msg.status_msg = "Starting update...";
+	popup_msg.status_msg = EDITOR_STARTING_UPDATE_MSG;
 	popup_msg.popup_timeout = -1;
 	popup_msg.top_offset = 0;
 	popup_msg.left_offset = 500;
@@ -191,28 +196,28 @@ function UpdateAll()
 //////////////////////////////////////////////////////////////////////////////////////
 function UpdateMessage(xmlhttp, Source)
 {
-	var query_complete_no_record = "Query complete.  No records found.";
-	var query_complete = "<b>Query complete<\/b><br/>\n";
-	var query_read_to_send = "Query ready to send...";
-	var query_sent = "Query sent";
-	var query_starting = "Locating menu items...";
+	var query_complete_no_record = QUERY_COMPLETE_NO_RECORD_FOUND;
+	var query_complete = "<b>" + QUERY_COMPLETE + "<\/b><br/>\n";
+	var query_read_to_send = QUERY_READY_TO_SEND;
+	var query_sent = QUERY_SENT;
+	var query_starting = EDIT_MENU_ITEMS_LOCATING_MENU_ITEMS_MSG;
 	if (Source == "Delete")
 	{
-		query_complete_no_record = "No records found. Could not delete menu item.";
-		query_complete = "<b>Menu item deleted<\/b><br/>\n";
-		query_starting = "Deleting menu item...";
+		query_complete_no_record = EDIT_MENU_ITEMS_COULD_NOT_DELETE_ITEM_MSG;
+		query_complete = "<b>" + EDIT_MENU_ITEMS_MENU_ITEM_DELETED_MSG + "<\/b><br/>\n";
+		query_starting = EDIT_MENU_ITEMS_DELETING_MENU_ITEM_MSG;
 	}
 	else if (Source == "Update")
 	{
-		query_complete_no_record = "No record found. Could not update menu item.";
-		query_complete = "<b>Menu item updated<\/b><br/>\n";
-		query_starting = "Updating menu item...";
+		query_complete_no_record = EDIT_MENU_ITEMS_COULD_NOT_UPDATE_ITEM_MSG;
+		query_complete = "<b>" + EDIT_MENU_ITEMS_MENU_ITEM_UPDATED_MSG + "<\/b><br/>\n";
+		query_starting = EDIT_MENU_ITEMS_UPDATING_MENU_ITEM_MSG;
 	}
 	else if (Source == "UpdateAll")
 	{
-		query_complete_no_record = "No records found. Could not update menu items.";
-		query_complete = "<b>Menu items updated<\/b><br/>\n";
-		query_starting = "Updating menu items...";
+		query_complete_no_record = EDIT_MENU_ITEMS_COULD_NOT_UPDATE_ITEMS_MSG;
+		query_complete = "<b>" + EDIT_MENU_ITEMS_MENU_ITEMS_UPDATED_MSG + "<\/b><br/>\n";
+		query_starting = EDIT_MENU_ITEMS_UPDATING_MENU_ITEMS_MSG;
 	}
 	
 	xmlhttp.onreadystatechange=function()
@@ -258,7 +263,7 @@ function AddMenuItem(i)
 	var d = 0;
 	var srch_str;
 	
-	if (navigator.appName == "Microsoft Internet Explorer")
+	if ((browser == "Explorer") && (browser_version < 9))
 		srch_str = "<TR id=row" + i;
 	else
 		srch_str = "<tr id=\"row" + i + "\"";
@@ -271,20 +276,20 @@ function AddMenuItem(i)
 	var bgclr = "#FFFF99";
 	var new_row = "<tr id=\"row" + i + "\" bgcolor=\"" + bgclr + "\">\n";
 	
-	new_row = new_row + "<td valign='top'>\n<img src='images/indent_remove.png' border=0 alt='Indent Remove' name='IndentRemove' id='IndentRemove" + i + "' onClick=\"IndentItemRemove(" + i + ");\" />\n<\/td>\n";
-	new_row = new_row + "<td valign='top'>\n<img src='images/indent.png' border=0 alt='Indent' name='Indent' id='Indent" + i + "' onClick=\"IndentItem(" + i + ");\" />\n<\/td>\n";
+	new_row = new_row + "<td valign='top'>\n<img src='theme/" + theme + "/images/indent_remove.png' border=0 alt='Indent Remove' name='IndentRemove' id='IndentRemove" + i + "' onClick=\"IndentItemRemove(" + i + ");\" style='cursor:pointer;' />\n<\/td>\n";
+	new_row = new_row + "<td valign='top'>\n<img src='theme/" + theme + "/images/indent.png' border=0 alt='Indent' name='Indent' id='Indent" + i + "' onClick=\"IndentItem(" + i + ");\" style='cursor:pointer;' />\n<\/td>\n";
 	
 	new_row = new_row + "<td valign='top'><input type='hidden' name='ID" + i + "' id='ID" + i + "' value='-1'>\n";
-	new_row = new_row + "<input type='text' name='item_text" + i + "' id='item_text" + i + "' value=''><\/td>\n";
+	new_row = new_row + "<input type='text' name='item_text" + i + "' id='item_text" + i + "' value='' onchange=\"SetElementValue('item_text" + i + "');\"><\/td>\n";
 		
 	new_row = new_row + "<td>\n";
 	new_row = new_row + "<input type='hidden' id='level" + i + "' value='' />\n";
-	new_row = new_row + "<span id='level_text" + i + "'>Top Level<\/span>\n";
+	new_row = new_row + "<span id='level_text" + i + "'>" + EDIT_MENU_ITEMS_TOP_LEVEL + "<\/span>\n";
 	new_row = new_row + "<\/td>\n";
 	
 	new_row = new_row + "<td valign='top'>\n";
-	new_row = new_row + "<select name='selectPage" + i + "' id='selectPage" + i + "' onChange='PopulatePage(" + i + ");'>\n";
-	new_row = new_row + "<option value=''>-not selected-<\/option>\n";
+	new_row = new_row + "<select name='selectPage" + i + "' id='selectPage" + i + "' onChange=\"result=PopulatePage(" + i + "); SetElementValue('URL" + i + "');\">\n";
+	new_row = new_row + "<option value=''>" + _NOT_SELECTED_ + "<\/option>\n";
 	
 	for (var k = 0; k < page_cnt; k++)
 	{
@@ -292,26 +297,26 @@ function AddMenuItem(i)
 	}
 	new_row = new_row + "<\/select>\n";
 	
-	new_row = new_row + "<input type='text' name='URL" + i + "' id='URL" + i + "' value=''><\/td>\n";
+	new_row = new_row + "<input type='text' name='URL" + i + "' id='URL" + i + "' value='' onchange=\"SetElementValue('URL" + i + "');\"><\/td>\n";
 	
 	new_row = new_row + "<td valign='top'>\n";
 	new_row = new_row + "<select name='target_select" + i + "' id='target_select" + i + "' onChange='PopulateTarget(" + i + ");'>\n";
-	new_row = new_row + "<option value='_self'>Self (normal)<\/option>\n";
-	new_row = new_row + "<option value='_blank'>New Window<\/option>\n";
-	new_row = new_row + "<option value='enter frame name'>Named Frame<\/option>\n";
+	new_row = new_row + "<option value='_self'>" + SELF_NORMAL + "<\/option>\n";
+	new_row = new_row + "<option value='_blank'>" + NEW_WINDOW + "<\/option>\n";
+	new_row = new_row + "<option value='" + ENTER_FRAME_NAME + "'>" + NAMED_FRAME + "<\/option>\n";
 	new_row = new_row + "<\/select>\n";
-	new_row = new_row + "<input type='hidden' name='target" + i + "' id='target" + i + "' value=''><\/td>\n";
+	new_row = new_row + "<input type='hidden' name='target" + i + "' id='target" + i + "' value='' onclick=\"if (this.value == '" + ENTER_FRAME_NAME + "') this.value = '';\"><\/td>\n";
 	new_row = new_row + "<td valign='top'>\n<input type='hidden' id='sort_order" + i + "' name='sort_order" + i + "' value='' />\n";
 	
-	new_row = new_row + "<img src='images/save.png' border=0 alt='Update' name='Update' onClick=\"UpdateMenuItem(-1, " + i + ");\" />\n<\/td>\n";
+	new_row = new_row + "<img src='theme/" + theme + "/images/save.png' border=0 alt='Update' name='Update' onClick=\"UpdateMenuItem(-1, " + i + ");\" style='cursor:pointer;' />\n<\/td>\n";
 	
-	new_row = new_row + "<td valign='top'>\n<img src='images/plus.png' border=0 alt='Insert Above' name='Insert' onClick=\"AddMenuItem(" + i + ");\" />\n<\/td>\n";
+	new_row = new_row + "<td valign='top'>\n<img src='theme/" + theme + "/images/plus.png' border=0 alt='Insert Above' name='Insert' onClick=\"AddMenuItem(" + i + ");\" style='cursor:pointer;' />\n<\/td>\n";
 	
-	new_row = new_row + "<td valign='top'>\n<img src='images/arrow-up.png' border=0 alt='Move Up' name='MoveUp' id='MoveUp" + i + "' onClick=\"MoveItem(" + i + ");\" />\n<\/td>\n";
+	new_row = new_row + "<td valign='top'>\n<img src='theme/" + theme + "/images/arrow-up.png' border=0 alt='Move Up' name='MoveUp' id='MoveUp" + i + "' onClick=\"MoveItem(" + i + ");\" style='cursor:pointer;' />\n<\/td>\n";
 	d = parseInt(i) + 1;
-	new_row = new_row + "<td valign='top'>\n<img src='images/arrow-down.png' border=0 alt='Move Down' name='MoveDown' id='MoveDown" + i + "' onClick=\"MoveItemDown(" + d + ");\" />\n<\/td>\n";
+	new_row = new_row + "<td valign='top'>\n<img src='theme/" + theme + "/images/arrow-down.png' border=0 alt='Move Down' name='MoveDown' id='MoveDown" + i + "' onClick=\"MoveItemDown(" + d + ");\" style='cursor:pointer;' />\n<\/td>\n";
 	
-	new_row = new_row + "<td valign='top'>\n<img src='images/delete.png' border=0 alt='Delete' name='Delete' onClick=\"DeleteConfirm('', -1, " + i + ");\" />\n<\/td>\n";
+	new_row = new_row + "<td valign='top'>\n<img src='theme/" + theme + "/images/delete.png' border=0 alt='Delete' name='Delete' onClick=\"DeleteConfirm('', -1, " + i + ");\" style='cursor:pointer;' />\n<\/td>\n";
 	
 	new_row = new_row + "<\/tr>\n";
 	var n = i - 1;
@@ -415,7 +420,7 @@ function AddMenuItem(i)
 	else
 	{
 		document.getElementById("level0").value = 0;
-		document.getElementById("level_text0").innerHTML = "Top Level";
+		document.getElementById("level_text0").innerHTML = EDIT_MENU_ITEMS_TOP_LEVEL;
 		document.getElementById("MoveUp0").style.display = "none";
 		document.getElementById("MoveUp1").style.display = "table-row";
 		document.getElementById("Indent0").style.display = "none";
@@ -432,16 +437,18 @@ function RetrieveMenuItems()
 	{
 		document.getElementById("MenuItemsTable").innerHTML ="&nbsp;\n";
 		document.getElementById("update").style.display = "none";
+		document.getElementById("select_menu_msg_div").style.display = "block";
 		return;
 	}
 	else
 	{
 		document.getElementById("update").style.display = "block";
 		document.getElementById("update").style.width = "130px";
+		document.getElementById("select_menu_msg_div").style.display = "none";
 	}
 		
 	popup_msg.popup_msg_type = 1;
-	popup_msg.status_msg = "Retrieving menu items...";
+	popup_msg.status_msg = EDIT_MENU_ITEMS_RETRIEVING_MENU_ITEMS_MSG;
 	popup_msg.popup_timeout = -1;
 	popup_msg.top_offset = 0;
 	popup_msg.left_offset = 500;
@@ -455,7 +462,7 @@ function RetrieveMenuItems()
 		xmlhttp.open("POST","populate_menu_items.php",true);
 		xmlhttp.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
 		xmlhttp = UpdateMessage(xmlhttp, "Populate");
-		params = "menu=" + document.getElementById("selectMenu").value;
+		var params = "menu=" + document.getElementById("selectMenu").value;
 		xmlhttp.send(params);
 	}
 }
@@ -471,10 +478,10 @@ function PopulateTable(rows_str)
 	var output_str = "<table width='90%' align='center'>\n";
 	output_str = output_str + "<tr bgcolor='#CCCCCC' class='header_row'>\n";
 	output_str = output_str + "<td colspan='2'>&nbsp;<\/td>\n";
-	output_str = output_str + "<td class='header_row'><b>Item Text<\/b><\/td>\n";
-	output_str = output_str + "<td class='header_row'><b>Nesting Level<\/b><\/td>\n";
-	output_str = output_str + "<td class='header_row'><b>URL<\/b><\/td>\n";
-	output_str = output_str + "<td class='header_row'><b>Target Window<\/b><\/td>\n";
+	output_str = output_str + "<td class='header_row'><b>" + EDIT_MENU_ITEMS_ITEM_TEXT + "<\/b><\/td>\n";
+	output_str = output_str + "<td class='header_row'><b>" + EDIT_MENU_ITEMS_NESTING_LEVEL + "<\/b><\/td>\n";
+	output_str = output_str + "<td class='header_row'><b>" + EDIT_MENU_ITEMS_URL + "<\/b><\/td>\n";
+	output_str = output_str + "<td class='header_row'><b>" + EDIT_MENU_ITEMS_TARGET_WINDOW + "<\/b><\/td>\n";
 	output_str = output_str + "<td>&nbsp;<\/td>\n";
 	output_str = output_str + "<td>&nbsp;<\/td>\n";
 	output_str = output_str + "<td colspan='2'>&nbsp;<\/td>\n";
@@ -497,8 +504,8 @@ function PopulateTable(rows_str)
 				
 			output_str = output_str + "<tr id=\"row" + i + "\" bgcolor=\"" + bgclr + "\">\n";
 				
-			output_str = output_str + "<td valign='top'>\n<img src='images/indent_remove.png' border=0 alt='Indent Remove' name='IndentRemove' id='IndentRemove" + i + "' onClick=\"IndentItemRemove(" + i + ");\" />\n<\/td>\n";
-			output_str = output_str + "<td valign='top'>\n<img src='images/indent.png' border=0 alt='Indent' name='Indent' id='Indent" + i + "' onClick=\"IndentItem(" + i + ");\" />\n<\/td>\n";
+			output_str = output_str + "<td valign='top'>\n<img src='theme/" + theme + "/images/indent_remove.png' border=0 alt='Indent Remove' name='IndentRemove' id='IndentRemove" + i + "' onClick=\"IndentItemRemove(" + i + ");\" style='cursor:pointer;' />\n<\/td>\n";
+			output_str = output_str + "<td valign='top'>\n<img src='theme/" + theme + "/images/indent.png' border=0 alt='Indent' name='Indent' id='Indent" + i + "' onClick=\"IndentItem(" + i + ");\" style='cursor:pointer;' />\n<\/td>\n";
 				
 			output_str = output_str + "<td valign='top'><input type='hidden' name='ID" + i + "' id='ID" + i + "' value='" + JSON_row.ID + "'>\n";
 			output_str = output_str + "<input type='text' name='item_text" + i + "' id='item_text" + i + "' value='" + Indent(JSON_row.level) + JSON_row.item_text + "'><\/td>\n";
@@ -506,24 +513,24 @@ function PopulateTable(rows_str)
 			output_str = output_str + "<td>\n";
 			output_str = output_str + "<input type='hidden' id='level" + i + "' value='" + JSON_row.level + "' />\n";
 			if ((JSON_row.level == 0) || !JSON_row.level)
-				output_str = output_str + "<span id='level_text" + i + "'>Top Level<\/span>\n";
+				output_str = output_str + "<span id='level_text" + i + "'>" + EDIT_MENU_ITEMS_TOP_LEVEL + "<\/span>\n";
 			else if (JSON_row.level == 1)
-				output_str = output_str + "<span id='level_text" + i + "'>1st Sub Level<\/span>\n";
+				output_str = output_str + "<span id='level_text" + i + "'>" + EDIT_MENU_ITEMS_1ST_SUB_LEVEL + "<\/span>\n";
 			else if (JSON_row.level == 2)
-				output_str = output_str + "<span id='level_text" + i + "'>2nd Sub Level<\/span>\n";
+				output_str = output_str + "<span id='level_text" + i + "'>" + EDIT_MENU_ITEMS_2ND_SUB_LEVEL + "<\/span>\n";
 			else if (JSON_row.level == 3)
-				output_str = output_str + "<span id='level_text" + i + "'>3rd Sub Level<\/span>\n";
+				output_str = output_str + "<span id='level_text" + i + "'>" + EDIT_MENU_ITEMS_3RD_SUB_LEVEL + "<\/span>\n";
 			else if (JSON_row.level == 4)
-				output_str = output_str + "<span id='level_text" + i + "'>4th Sub Level<\/span>\n";
+				output_str = output_str + "<span id='level_text" + i + "'>" + EDIT_MENU_ITEMS_4TH_SUB_LEVEL + "<\/span>\n";
 			else if (JSON_row.level == 5)
-				output_str = output_str + "<span id='level_text" + i + "'>5th Sub Level<\/span>\n";
+				output_str = output_str + "<span id='level_text" + i + "'>" + EDIT_MENU_ITEMS_5TH_SUB_LEVEL + "<\/span>\n";
 			output_str = output_str + "<\/td>\n";
 			
 			output_str = output_str + "<td valign='top'>\n";
 			output_str = output_str + "<select name='selectPage" + i + "' id='selectPage" + i + "' onChange='PopulatePage(" + i + ");'>\n";
 			output_str = output_str + "<option value=''>-not selected-<\/option>\n";
 			
-			for (j = 0; j < page_cnt; j++)
+			for (var j = 0; j < page_cnt; j++)
 			{
 				if (pages_full[j] == JSON_row.URL)
 					output_str = output_str + "<option value='" + pages[j] + "' selected='selected'>" + pages[j] + "<\/option>\n";
@@ -539,33 +546,33 @@ function PopulateTable(rows_str)
 			if (!JSON_row.target)
 				JSON_row.target = "_self";
 			if (JSON_row.target == "_self")
-				output_str = output_str + "<option value='_self' selected='selected'>Self (normal)<\/option>\n";
+				output_str = output_str + "<option value='_self' selected='selected'>" + SELF_NORMAL + "<\/option>\n";
 			else
-				output_str = output_str + "<option value='_self'>Self (normal)<\/option>\n";
+				output_str = output_str + "<option value='_self'>" + SELF_NORMAL + "<\/option>\n";
 			if (JSON_row.target == "_blank")
-				output_str = output_str + "<option value='_blank' selected='selected'>New Window<\/option>\n";
+				output_str = output_str + "<option value='_blank' selected='selected'>" + NEW_WINDOW + "<\/option>\n";
 			else
-				output_str = output_str + "<option value='_blank'>New Window<\/option>\n";
+				output_str = output_str + "<option value='_blank'>" + NEW_WINDOW + "<\/option>\n";
 			if ((JSON_row.target != "_blank") && (JSON_row.target != "_self"))
-				output_str = output_str + "<option value='enter frame name' selected='selected'>Named Frame<\/option>\n";
+				output_str = output_str + "<option value='" + ENTER_FRAME_NAME + "' selected='selected'>" + NAMED_FRAME + "<\/option>\n";
 			else
-				output_str = output_str + "<option value='enter frame name'>Named Frame<\/option>\n";
+				output_str = output_str + "<option value='" + ENTER_FRAME_NAME + "'>" + NAMED_FRAME + "<\/option>\n";
 			output_str = output_str + "<\/select>\n";
 			if ((JSON_row.target == "_blank") || (JSON_row.target == "_self"))
 				output_str = output_str + "<input type='hidden' name='target" + i + "' id='target" + i + "' value='" + JSON_row.target + "'><\/td>\n";
 			else
-				output_str = output_str + "<input type='text' name='target" + i + "' id='target" + i + "' value='" + JSON_row.target + "'><\/td>\n";
+				output_str = output_str + "<input type='text' name='target" + i + "' id='target" + i + "' value='" + JSON_row.target + "' onclick=\"if (this.value == '" + ENTER_FRAME_NAME + "') this.value = '';\"><\/td>\n";
 			
 			output_str = output_str + "<td valign='top'>\n<input type='hidden' id='sort_order" + i + "' name='sort_order" + i + "' value='" + JSON_row.sort_order + "' />\n";
 			
-			output_str = output_str + "<img src='images/save.png' border=0 alt='Update' name='Update' onClick=\"UpdateMenuItem(" + JSON_row.ID + ", " + i + ");\" />\n<\/td>\n";
+			output_str = output_str + "<img src='theme/" + theme + "/images/save.png' border=0 alt='Update' name='Update' onClick=\"UpdateMenuItem(" + JSON_row.ID + ", " + i + ");\" style='cursor:pointer;' />\n<\/td>\n";
 			
-			output_str = output_str + "<td valign='top'>\n<img src='images/plus.png' border=0 alt='Insert Above' name='Insert' onClick=\"AddMenuItem(" + i + ");\" />\n<\/td>\n";
+			output_str = output_str + "<td valign='top'>\n<img src='theme/" + theme + "/images/plus.png' border=0 alt='Insert Above' name='Insert' onClick=\"AddMenuItem(" + i + ");\" style='cursor:pointer;' />\n<\/td>\n";
 			
-			output_str = output_str + "<td valign='top'>\n<img src='images/arrow-up.png' border=0 alt='Move Up' name='MoveUp' id='MoveUp" + i + "' onClick=\"MoveItem(" + i + ");\" />\n<\/td>\n";
+			output_str = output_str + "<td valign='top'>\n<img src='theme/" + theme + "/images/arrow-up.png' border=0 alt='Move Up' name='MoveUp' id='MoveUp" + i + "' onClick=\"MoveItem(" + i + ");\" style='cursor:pointer;' />\n<\/td>\n";
 			
 			d = parseInt(i) + 1;
-			output_str = output_str + "<td valign='top'>\n<img src='images/arrow-down.png' border=0 alt='Move Down' name='MoveDown'  id='MoveDown" + i + "' onClick=\"MoveItemDown(" + d + ");\" />\n<\/td>\n";
+			output_str = output_str + "<td valign='top'>\n<img src='theme/" + theme + "/images/arrow-down.png' border=0 alt='Move Down' name='MoveDown'  id='MoveDown" + i + "' onClick=\"MoveItemDown(" + d + ");\" style='cursor:pointer;' />\n<\/td>\n";
 			
 			tmp = JSON_row.item_text;
 			tmp = tmp.replace("&#39;", "");
@@ -573,7 +580,7 @@ function PopulateTable(rows_str)
 			tmp = tmp.replace("&#39;", "");
 			tmp = tmp.replace("&#39;", "");
 			tmp = tmp.replace("&#39;", "");
-			output_str = output_str + "<td valign='top'>\n<img src='images/delete.png' border=0 alt='Delete' name='Delete' onClick=\"DeleteConfirm('" + tmp + "', " + JSON_row.ID + ", " + i + ");\" />\n<\/td>\n";
+			output_str = output_str + "<td valign='top'>\n<img src='theme/" + theme + "/images/delete.png' border=0 alt='Delete' name='Delete' onClick=\"DeleteConfirm('" + tmp + "', " + JSON_row.ID + ", " + i + ");\" style='cursor:pointer;' />\n<\/td>\n";
 			
 			output_str = output_str + "<\/tr>\n";
 		}
@@ -585,7 +592,7 @@ function PopulateTable(rows_str)
 		bgclr = "#dddddd";
 	output_str = output_str + "<tr id=\"row" + i + "\" bgcolor='" + bgclr + "'>\n";
 	output_str = output_str + "<td colspan='7'>&nbsp;<\/td>\n";
-	output_str = output_str + "<td valign='top'>\n<img src='images/plus.png' border=0 alt='Insert Above' name='Insert' onClick=\"AddMenuItem(" + i + ");\" />\n<\/td>\n";
+	output_str = output_str + "<td valign='top'>\n<img src='theme/" + theme + "/images/plus.png' border=0 alt='Insert Above' name='Insert' onClick=\"AddMenuItem(" + i + ");\" style='cursor:pointer;' />\n<\/td>\n";
 	output_str = output_str + "<td colspan='3'>&nbsp;<\/td>\n";
 	output_str = output_str + "<\/tr>\n";
 	output_str = output_str + "<\/table>\n";
@@ -595,7 +602,7 @@ function PopulateTable(rows_str)
 	
 	if (rows[0] != "-no data-")
 	{
-		LastMoveDown = "MoveDown" + (i - 1);
+		var LastMoveDown = "MoveDown" + (i - 1);
 		document.getElementById(LastMoveDown).style.display = "none";
 		document.getElementById("MoveUp0").style.display = "none";
 		document.getElementById("Indent0").style.display = "none";
@@ -610,9 +617,9 @@ function DisplayNotSavedMessage(btn)
 	popup_msg.left_offset = 300;
 	popup_msg.popup_msg_type = 3;
 	popup_msg.popup_btn_cnt = 2;
-	popup_msg.popup_msg_cell = "Your changes have not been saved. Do you want to save your changes before returning to the main menu?";
-	popup_msg.popup_button_2_span = "Yes";
-	popup_msg.popup_button_1_span = "No";
+	popup_msg.popup_msg_cell = EDIT_MENU_ITEMS_NOT_SAVED_CONFIRM_MSG;
+	popup_msg.popup_button_2_span = YES_WORD;
+	popup_msg.popup_button_1_span = NO_WORD;
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
 	document.getElementById("popup_button_2_span").onclick = function () { SaveBeforeMain(); };
@@ -860,17 +867,17 @@ function IndentItem(i)
 		document.getElementById(nesting_level_ctl).value = nesting_level;
 		var nesting_level_text_ctl = "level_text" + i;
 		if (nesting_level == 0)
-			document.getElementById(nesting_level_text_ctl).innerHTML = "Top Level";
+			document.getElementById(nesting_level_text_ctl).innerHTML = EDIT_MENU_ITEMS_TOP_LEVEL;
 		else if (nesting_level == 1)
-			document.getElementById(nesting_level_text_ctl).innerHTML = "1st Sub Level";
+			document.getElementById(nesting_level_text_ctl).innerHTML = EDIT_MENU_ITEMS_1ST_SUB_LEVEL;
 		else if (nesting_level == 2)
-			document.getElementById(nesting_level_text_ctl).innerHTML = "2nd Sub Level";
+			document.getElementById(nesting_level_text_ctl).innerHTML = EDIT_MENU_ITEMS_2ND_SUB_LEVEL;
 		else if (nesting_level == 3)
-			document.getElementById(nesting_level_text_ctl).innerHTML = "3rd Sub Level";
+			document.getElementById(nesting_level_text_ctl).innerHTML = EDIT_MENU_ITEMS_3RD_SUB_LEVEL;
 		else if (nesting_level == 4)
-			document.getElementById(nesting_level_text_ctl).innerHTML = "4th Sub Level";
+			document.getElementById(nesting_level_text_ctl).innerHTML = EDIT_MENU_ITEMS_4TH_SUB_LEVEL;
 		else if (nesting_level == 5)
-			document.getElementById(nesting_level_text_ctl).innerHTML = "5th Sub Level";
+			document.getElementById(nesting_level_text_ctl).innerHTML = EDIT_MENU_ITEMS_5TH_SUB_LEVEL;
 			
 	}
 }
@@ -895,17 +902,17 @@ function IndentItemRemove(i)
 		document.getElementById(nesting_level_ctl).value = nesting_level;
 		var nesting_level_text_ctl = "level_text" + i;
 		if (nesting_level == 0)
-			document.getElementById(nesting_level_text_ctl).innerHTML = "Top Level";
+			document.getElementById(nesting_level_text_ctl).innerHTML = EDIT_MENU_ITEMS_TOP_LEVEL;
 		else if (nesting_level == 1)
-			document.getElementById(nesting_level_text_ctl).innerHTML = "1st Sub Level";
+			document.getElementById(nesting_level_text_ctl).innerHTML = EDIT_MENU_ITEMS_1ST_SUB_LEVEL;
 		else if (nesting_level == 2)
-			document.getElementById(nesting_level_text_ctl).innerHTML = "2nd Sub Level";
+			document.getElementById(nesting_level_text_ctl).innerHTML = EDIT_MENU_ITEMS_2ND_SUB_LEVEL;
 		else if (nesting_level == 3)
-			document.getElementById(nesting_level_text_ctl).innerHTML = "3rd Sub Level";
+			document.getElementById(nesting_level_text_ctl).innerHTML = EDIT_MENU_ITEMS_3RD_SUB_LEVEL;
 		else if (nesting_level == 4)
-			document.getElementById(nesting_level_text_ctl).innerHTML = "4th Sub Level";
+			document.getElementById(nesting_level_text_ctl).innerHTML = EDIT_MENU_ITEMS_4TH_SUB_LEVEL;
 		else if (nesting_level == 5)
-			document.getElementById(nesting_level_text_ctl).innerHTML = "5th Sub Level";
+			document.getElementById(nesting_level_text_ctl).innerHTML = EDIT_MENU_ITEMS_5TH_SUB_LEVEL;
 
 		document.getElementById(item_text_ctl).value = Indent(nesting_level) + item_text;
 	}
@@ -920,6 +927,7 @@ function PopulatePage(i)
 	document.getElementById(URL_ctl).value = url;
 	
 	window.parent.SetWorkSavedNotSaved(false);
+	return(1);
 }
 
 function PopulateTarget(i)
@@ -937,6 +945,32 @@ function PopulateTarget(i)
 	window.parent.SetWorkSavedNotSaved(false);
 }
 
+////////////////////////////////////////////////////////////////////////////////////////////////////
+function SetElementValue(el_id)
+{
+	var html = document.getElementById("MenuItemsTable").innerHTML;
+	var val = document.getElementById(el_id).value;
+	var srch = "id=\"" + el_id;
+	var pos1 = html.indexOf(srch, 0);
+	if (pos1 == -1)	{
+		srch = "id='" + el_id;
+		pos1 = html.indexOf(srch, 0);
+	}
+	srch = "value=";
+	var pos2 = html.indexOf(srch, pos1);
+	srch = "\"";
+	var pos3 = html.indexOf(srch, pos2);
+	if (pos3 == -1)	{
+		srch = "'";
+		pos3 = html.indexOf(srch, pos2);
+	}
+	var pos4 = html.indexOf(srch, pos3 + 1);
+	var html_start = html.substr(0, pos2);
+	var html_end = html.substr(pos4 + 1);
+	html = html_start + "value='" + val + "'" + html_end;
+	document.getElementById("MenuItemsTable").innerHTML = html;
+}
+
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////
 function ResizeWorkspace(mainWidth, mainHeight, menuWidth, headerHeight) {
 
