@@ -29,6 +29,8 @@ var mTimer;
 var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
 var popup_msg = new PopupMsg(param_array);
 
+window.parent.document.title = document.title;
+
 function OpenHelpWindow()
 {
 	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#edit_page", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
@@ -75,7 +77,7 @@ function Save(action)
 	var sValue = CKEDITOR.instances['editorContainer'].getData();
 	
 	popup_msg.popup_msg_type = 1;
-	popup_msg.status_msg = "Starting update...";
+	popup_msg.status_msg = EDITOR_STARTING_UPDATE_MSG;
 	popup_msg.popup_timeout = -1;
 	popup_msg.top_offset = 0;
 	popup_msg.left_offset = 500;
@@ -93,20 +95,32 @@ function CompleteSave(data)	{
 	bwb_ckeditor.resetDirty();
 }
 
-function Preview()
+var preview_window;
+function Preview(preview_page_name, do_refresh)
 {
 	var sValue = CKEDITOR.instances['editorContainer'].getData();
 	
 	popup_msg.popup_msg_type = 1;
-	popup_msg.status_msg = "Preparing preview...";
+	popup_msg.status_msg = EDITOR_PREPARING_PREVIEW_MSG;
 	popup_msg.popup_timeout = 2000;
 	popup_msg.top_offset = 0;
 	popup_msg.left_offset = 500;
 	popup_msg.ShowPopupMsg();
-	$.post( "preview_page_init.php", { sValue: sValue }, function(data){ document.getElementById("StatusMsg").innerHTML = data; }, "text" ) ;
+	$.post( "preview_page_init.php", { sValue: sValue, page_name: page_name, disable_site_styles: disable_site_styles }, function(data){ CompletePreview(data, do_refresh); }, "text" ) ;
 	
-	var preview_page_string = "preview_page.php?page_name=" + page_name + "&special=" + special + "&mode=" + mode + "&blog_id=" + blog_id;
-	window.open(preview_page_string, "Preview", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=900,width=1000");
+	if (do_refresh != 1)	{
+		var preview_page_string = "preview_page.php?page_name=" + page_name + "&special=" + special + "&mode=" + mode + "&blog_id=" + blog_id;
+		preview_window = window.open(preview_page_string, "Preview", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=900,width=1000");
+	}
+}
+function CompletePreview(data, do_refresh)
+{
+	popup_msg.status_msg = data;
+	popup_msg.popup_timeout = 2000;
+	popup_msg.ShowPopupMsg();
+	
+	if (do_refresh == 1)
+		preview_window.location.reload();
 }
 
 function ClearContent()
@@ -124,16 +138,16 @@ function RevertConfirm(delete_mode)
 	popup_msg.left_offset = 300;
 	popup_msg.popup_msg_type = 3;
 	popup_msg.popup_btn_cnt = 2;
-	popup_msg.popup_button_2_span = "Yes";
-	popup_msg.popup_button_1_span = "No";
+	popup_msg.popup_button_2_span = YES_WORD;
+	popup_msg.popup_button_1_span = NO_WORD;
 	popup_msg.popup_timeout = -1;
 	
 	if (delete_mode == "blog")
-		popup_msg.popup_msg_cell = "Are your sure you want to revert <b>blog id " + blog_id + "</b>?";
+		popup_msg.popup_msg_cell = EDITOR_REVERT_BLOG_CONFIRM_1_MSG + " <b>" + blog_id + "</b> " + EDITOR_REVERT_BLOG_CONFIRM_2_MSG;
 	else if (delete_mode == "border")
-		popup_msg.popup_msg_cell = "Are you sure you want to revert the <b>" + page_name + "</b> area?";
+		popup_msg.popup_msg_cell = EDITOR_REVERT_AREA_CONFIRM_1_MSG + " <b>" + page_name + "</b> " + EDITOR_REVERT_AREA_CONFIRM_2_MSG;
 	else
-		popup_msg.popup_msg_cell = "Are your sure you want to revert the <b>" + page_name + "</b> page?";
+		popup_msg.popup_msg_cell = EDITOR_REVERT_PAGE_CONFIRM_1_MSG + " <b>" + page_name + "</b> " + EDITOR_REVERT_PAGE_CONFIRM_2_MSG;
 		
 	document.getElementById("popup_button_2_span").onclick = function() { Revert(); };
 	document.getElementById("popup_button_1_span").onclick = function () { HidePopupMsg(); };
@@ -142,7 +156,7 @@ function RevertConfirm(delete_mode)
 function Revert()
 {	
 	popup_msg.popup_msg_type = 1;
-	popup_msg.status_msg = "Reverting to last published version...";
+	popup_msg.status_msg = EDITOR_REVERTING_MSG;
 	popup_msg.popup_timeout = 2000;
 	popup_msg.ShowPopupMsg();
 	$.post( "revert.php", { page_name: page_name, blog_id: blog_id, special: special, mode: mode, prepend: prepend, postpend: postpend }).done(CompleteRevert) ;
@@ -164,7 +178,7 @@ function OptimizeResetImages(action)
 	var sValue = CKEDITOR.instances['editorContainer'].getData();
 	
 	popup_msg.popup_msg_type = 1;
-	popup_msg.status_msg = "Starting update...";
+	popup_msg.status_msg = EDITOR_STARTING_UPDATE_MSG;
 	popup_msg.popup_timeout = -1;
 	popup_msg.top_offset = 0;
 	popup_msg.left_offset = 500;
@@ -183,9 +197,9 @@ function DisplayNotSavedMessage(btn)
 	popup_msg.left_offset = 300;
 	popup_msg.popup_msg_type = 3;
 	popup_msg.popup_btn_cnt = 2;
-	popup_msg.popup_msg_cell = "Your page is not saved.  Do you want to save your changes?";
-	popup_msg.popup_button_2_span = "Yes";
-	popup_msg.popup_button_1_span = "No";
+	popup_msg.popup_msg_cell = EDITOR_PAGE_NOT_SAVED_MSG;
+	popup_msg.popup_button_2_span = YES_WORD;
+	popup_msg.popup_button_1_span = NO_WORD;
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
 	document.getElementById("popup_button_2_span").onclick = function () { SaveBeforeMain(); };
@@ -232,13 +246,13 @@ function ShowSaveAsMsg()
 			else if (page_name.indexOf("footer") == 0)
 				name_prefix = "footer_";
 		}
-		popup_msg.popup_prompt_cell = "Save as: " + name_prefix;
+		popup_msg.popup_prompt_cell = SAVE_AS_WORD + ": " + name_prefix;
 	}
 	else
-		popup_msg.popup_prompt_cell = "Save as: ";
+		popup_msg.popup_prompt_cell = SAVE_AS_WORD + ": ";
 		
-	popup_msg.popup_button_2_span = "Cancel";
-	popup_msg.popup_button_1_span = "OK";
+	popup_msg.popup_button_2_span = CANCEL_WORD;
+	popup_msg.popup_button_1_span = OK_WORD;
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
 	document.getElementById("popup_button_2_span").onclick = function () { HidePopupMsg(); };
@@ -251,7 +265,7 @@ function SaveAs(name_prefix)
 	var new_page_name = document.getElementById("popup_prompt_textbox").value;
 	if ((new_page_name == null) || (new_page_name == ""))
 	{
-		alert("Page name cannot be blank. Please enter a page name and try again.");
+		alert(EDITOR_PAGE_BLANK_ERR);
 		return;
 	}
 	var page_exists;
@@ -259,9 +273,9 @@ function SaveAs(name_prefix)
 		
 	if (page_exists == "1")	{
 		if (special != 1)
-			alert("Page " + new_page_name + " already exists. Please go back to the main menu to copy and rename your pages.");
+			alert(EDITOR_PAGE_ALREADY_EXISTS_1_ERR + " " + new_page_name + " " + EDITOR_PAGE_ALREADY_EXISTS_2_ERR);
 		else
-			alert("Border area " + new_page_name + " already exists. Please go back to the main menu to manage border areas.");
+			alert(EDITOR_AREA_ALREADY_EXISTS_1_ERR + " " + new_page_name + " " + EDITOR_AREA_ALREADY_EXISTS_2_ERR);
 	}
 	else
 	{
@@ -286,6 +300,10 @@ function SaveAs(name_prefix)
 		}
 		
 		Save('publish');
+		
+		var new_title = new_page_name + " - Editing | Breeze Website Builder";
+		document.title = new_title;
+		window.parent.document.title = document.title;
 	}
 	
 	HidePopupMsg();
@@ -298,23 +316,23 @@ function DeleteConfirm(delete_mode)
 	popup_msg.left_offset = 300;
 	popup_msg.popup_msg_type = 3;
 	popup_msg.popup_btn_cnt = 2;
-	popup_msg.popup_button_2_span = "Yes";
-	popup_msg.popup_button_1_span = "No";
+	popup_msg.popup_button_2_span = YES_WORD;
+	popup_msg.popup_button_1_span = NO_WORD;
 	popup_msg.popup_timeout = -1;
 	
 	if (delete_mode == "blog")
 	{
-		popup_msg.popup_msg_cell = "Are your sure you want to delete <b>blog id " + blog_id + "</b>?";
+		popup_msg.popup_msg_cell = EDITOR_DELETE_BLOG_CONFIRM_1_MSG + " <b>" + blog_id + "</b> " + EDITOR_DELETE_BLOG_CONFIRM_2_MSG;
 		document.getElementById("popup_button_2_span").onclick = function() { DeleteBlog(); };
 	}
 	else if (delete_mode == "border")
 	{
-		popup_msg.popup_msg_cell = "Are you sure you want to delete the <b>" + page_name + "</b> area?";
+		popup_msg.popup_msg_cell = EDITOR_DELETE_AREA_CONFIRM_1_MSG + " <b>" + page_name + "</b> " + EDITOR_DELETE_AREA_CONFIRM_2_MSG;
 		document.getElementById("popup_button_2_span").onclick = function() { DeleteBorderArea(); };
 	}
 	else
 	{
-		popup_msg.popup_msg_cell = "Are your sure you want to delete the <b>" + page_name + "</b> page?";
+		popup_msg.popup_msg_cell = EDITOR_DELETE_PAGE_CONFIRM_1_MSG + " <b>" + page_name + "</b> " + EDITOR_DELETE_PAGE_CONFIRM_2_MSG;
 		document.getElementById("popup_button_2_span").onclick = function() { DeletePage(); };
 	}
 	document.getElementById("popup_button_1_span").onclick = function () { HidePopupMsg(); };
@@ -338,7 +356,7 @@ function DeleteBlog()
 function DeleteBorderArea()
 {
 	HidePopupMsg();
-	var url = "delete_special.php?area_name=" + page_name + "&redirect=manage_border_area_select.php";
+	var url = "delete_border_area.php?area_name=" + page_name + "&redirect=manage_border_area_select.php";
 	window.location = url;
 }
 
