@@ -19,6 +19,8 @@
 // Added new button for editing files.
 // Revised 1/12/2015	ELL
 // Added code to hide/show new NEW SESSION button. Fixed bug with sliver of LOGOUT button showing with collapsed header.
+// Revised: 1/18/2016	ELL
+// Added ability to put custom in any button group.
 // 
 // 
 var browser = BrowserDetect.browser;
@@ -145,6 +147,7 @@ function ExpandCollapseMenus(menu_group)
 function ExpandContentFunctions()
 {	
 	var strHeight = curr_height.toString() + 'px';
+	var plugin_button;
 	if (access_level != "blogger")
 	{
 		document.getElementById("btn_edit_content").style.height = strHeight;
@@ -161,6 +164,15 @@ function ExpandContentFunctions()
 	document.getElementById("btn_preview_published_site").style.height = strHeight;
 	document.getElementById("btn_manage_edit_blog").style.height = strHeight;
 	
+	for (i = 0; i < plugin_button_cnt; i++)
+	{
+		plugin_button = plugin_buttons[i];
+		if ((plugin_button[0] == i) && (plugin_button[1] == "content_functions"))	{
+			btn_custom_str = "btn_custom_" + parseInt(i);
+			document.getElementById(btn_custom_str).style.height = strHeight;
+		}
+	}
+	
 	if (curr_height == 0)
 	{
 		if (access_level != "blogger")
@@ -178,6 +190,15 @@ function ExpandContentFunctions()
 		}
 		document.getElementById("btn_preview_published_site").style.display = inherit;
 		document.getElementById("btn_manage_edit_blog").style.display = inherit;
+		
+		for (i = 0; i < plugin_button_cnt; i++)
+		{
+			plugin_button = plugin_buttons[i];
+			if ((plugin_button[0] == i) && (plugin_button[1] == "content_functions"))	{
+				btn_custom_str = "btn_custom_" + parseInt(i);
+				document.getElementById(btn_custom_str).style.display = inherit;
+			}
+		}
 	}
 
 	curr_height++;
@@ -191,6 +212,7 @@ function ExpandContentFunctions()
 function CollapseContentFunctions()
 {
 	var strHeight = curr_height.toString() + 'px';
+	var plugin_button;
 	if (access_level != "blogger")
 	{
 		document.getElementById("btn_edit_content").style.height = strHeight;
@@ -207,6 +229,15 @@ function CollapseContentFunctions()
 	document.getElementById("btn_preview_published_site").style.height = strHeight;
 	document.getElementById("btn_manage_edit_blog").style.height = strHeight;
 	
+	for (i = 0; i < plugin_button_cnt; i++)
+	{
+		plugin_button = plugin_buttons[i];
+		if ((plugin_button[0] == i) && (plugin_button[1] == "content_functions"))	{
+			btn_custom_str = "btn_custom_" + parseInt(i);
+			document.getElementById(btn_custom_str).style.height = strHeight;
+		}
+	}
+	
 	if (curr_height <= 0)
 	{
 		document.getElementById("btn_edit_content").style.display = "none";
@@ -216,6 +247,15 @@ function CollapseContentFunctions()
 		document.getElementById("btn_preview_published_site").style.display = "none";
 		document.getElementById("btn_manage_edit_blog").style.display = "none";
 		document.getElementById("btn_edit_file").style.display = "none";
+		
+		for (i = 0; i < plugin_button_cnt; i++)
+		{
+			plugin_button = plugin_buttons[i];
+			if ((plugin_button[0] == i) && (plugin_button[1] == "content_functions"))	{
+				btn_custom_str = "btn_custom_" + parseInt(i);
+				document.getElementById(btn_custom_str).style.display = "none";
+			}
+		}
 	}
 	
 	curr_height--;
@@ -230,6 +270,7 @@ function CollapseContentFunctions()
 function ExpandMenuFunctions()
 {
 	var strHeight = curr_height2.toString() + 'px';
+	var plugin_button;
 	document.getElementById("btn_edit_menu_items").style.height = strHeight;
 	if (access_level != "user")
 	{
@@ -240,6 +281,15 @@ function ExpandMenuFunctions()
 		document.getElementById("btn_edit_js_menu_styles").style.height = strHeight;
 	}
 	
+	for (i = 0; i < plugin_button_cnt; i++)
+	{
+		plugin_button = plugin_buttons[i];
+		if ((plugin_button[0] == i) && (plugin_button[1] == "menu_functions"))	{
+			btn_custom_str = "btn_custom_" + parseInt(i);
+			document.getElementById(btn_custom_str).style.height = strHeight;
+		}
+	}
+	
 	if (curr_height2 == 0)
 	{
 		document.getElementById("btn_edit_menu_items").style.display = inherit;
@@ -251,6 +301,15 @@ function ExpandMenuFunctions()
 			document.getElementById("btn_edit_js_menu_params").style.display = inherit;
 			document.getElementById("btn_edit_js_menu_styles").style.display = inherit;
 		}
+		
+		for (i = 0; i < plugin_button_cnt; i++)
+		{
+			plugin_button = plugin_buttons[i];
+			if ((plugin_button[0] == i) && (plugin_button[1] == "menu_functions"))	{
+				btn_custom_str = "btn_custom_" + parseInt(i);
+				document.getElementById(btn_custom_str).style.display = inherit;
+			}
+		}
 	}
 	
 	curr_height2++;
@@ -264,6 +323,7 @@ function ExpandMenuFunctions()
 function CollapseMenuFunctions()
 {
 	var strHeight = curr_height2.toString() + 'px';
+	var plugin_button;
 	document.getElementById("btn_edit_menu_items").style.height = strHeight;
 	if (access_level != "user")
 	{
@@ -274,6 +334,15 @@ function CollapseMenuFunctions()
 		document.getElementById("btn_edit_js_menu_styles").style.height = strHeight;
 	}
 	
+	for (i = 0; i < plugin_button_cnt; i++)
+	{
+		plugin_button = plugin_buttons[i];
+		if ((plugin_button[0] == i) && (plugin_button[1] == "menu_functions"))	{
+			btn_custom_str = "btn_custom_" + parseInt(i);
+			document.getElementById(btn_custom_str).style.height = strHeight;
+		}
+	}
+	
 	if (curr_height2 <= 0)
 	{
 		document.getElementById("btn_edit_menu_items").style.display = "none";
@@ -282,6 +351,15 @@ function CollapseMenuFunctions()
 		document.getElementById("btn_edit_css_menu_styles").style.display = "none";
 		document.getElementById("btn_edit_js_menu_params").style.display = "none";
 		document.getElementById("btn_edit_js_menu_styles").style.display = "none";
+		
+		for (i = 0; i < plugin_button_cnt; i++)
+		{
+			plugin_button = plugin_buttons[i];
+			if ((plugin_button[0] == i) && (plugin_button[1] == "menu_functions"))	{
+				btn_custom_str = "btn_custom_" + parseInt(i);
+				document.getElementById(btn_custom_str).style.display = "none";
+			}
+		}
 	}
 	
 	curr_height2--;
@@ -296,17 +374,36 @@ function CollapseMenuFunctions()
 function ExpandStyleFunctions()
 {
 	var strHeight = curr_height3.toString() + 'px';
+	var plugin_button;
 	document.getElementById("btn_edit_styles").style.height = strHeight;
 	document.getElementById("btn_edit_head_code").style.height = strHeight;
 	document.getElementById("btn_manage_head_code").style.height = strHeight;
 	document.getElementById("btn_edit_favicon").style.height = strHeight;
 	
+	for (i = 0; i < plugin_button_cnt; i++)
+	{
+		plugin_button = plugin_buttons[i];
+		if ((plugin_button[0] == i) && (plugin_button[1] == "style_functions"))	{
+			btn_custom_str = "btn_custom_" + parseInt(i);
+			document.getElementById(btn_custom_str).style.height = strHeight;
+		}
+	}
+	
 	if (curr_height3 == 0)
 	{
 		document.getElementById("btn_edit_styles").style.display = inherit;
 		document.getElementById("btn_edit_head_code").style.display = inherit;
 		document.getElementById("btn_manage_head_code").style.display = inherit;
 		document.getElementById("btn_edit_favicon").style.display = inherit;
+		
+		for (i = 0; i < plugin_button_cnt; i++)
+		{
+			plugin_button = plugin_buttons[i];
+			if ((plugin_button[0] == i) && (plugin_button[1] == "style_functions"))	{
+				btn_custom_str = "btn_custom_" + parseInt(i);
+				document.getElementById(btn_custom_str).style.display = inherit;
+			}
+		}
 	}
 	
 	curr_height3++;
@@ -320,17 +417,36 @@ function ExpandStyleFunctions()
 function CollapseStyleFunctions()
 {
 	var strHeight = curr_height3.toString() + 'px';
+	var plugin_button;
 	document.getElementById("btn_edit_styles").style.height = strHeight;
 	document.getElementById("btn_edit_head_code").style.height = strHeight;
 	document.getElementById("btn_manage_head_code").style.height = strHeight;
 	document.getElementById("btn_edit_favicon").style.height = strHeight;
 	
+	for (i = 0; i < plugin_button_cnt; i++)
+	{
+		plugin_button = plugin_buttons[i];
+		if ((plugin_button[0] == i) && (plugin_button[1] == "style_functions"))	{
+			btn_custom_str = "btn_custom_" + parseInt(i);
+			document.getElementById(btn_custom_str).style.height = strHeight;
+		}
+	}
+	
 	if (curr_height3 <= 0)
 	{
 		document.getElementById("btn_edit_styles").style.display = "none";
 		document.getElementById("btn_edit_head_code").style.display = "none";
 		document.getElementById("btn_manage_head_code").style.display = "none";
 		document.getElementById("btn_edit_favicon").style.display = "none";
+		
+		for (i = 0; i < plugin_button_cnt; i++)
+		{
+			plugin_button = plugin_buttons[i];
+			if ((plugin_button[0] == i) && (plugin_button[1] == "style_functions"))	{
+				btn_custom_str = "btn_custom_" + parseInt(i);
+				document.getElementById(btn_custom_str).style.display = "none";
+			}
+		}
 	}
 	
 	curr_height3--;
@@ -345,6 +461,7 @@ function CollapseStyleFunctions()
 function ExpandPageFunctions()
 {
 	var strHeight = curr_height4.toString() + 'px';
+	var plugin_button;
 	document.getElementById("btn_edit_page_titles").style.height = strHeight;
 	document.getElementById("btn_edit_meta_tags").style.height = strHeight;
 	if (access_level != "user")
@@ -354,6 +471,16 @@ function ExpandPageFunctions()
 		document.getElementById("btn_restore_page").style.height = strHeight;
 		document.getElementById("btn_add_plugin_to_page").style.height = strHeight;
 		document.getElementById("btn_manage_page_access").style.height = strHeight;
+		document.getElementById("btn_manage_page_attributes").style.height = strHeight;
+	}
+	
+	for (i = 0; i < plugin_button_cnt; i++)
+	{
+		plugin_button = plugin_buttons[i];
+		if ((plugin_button[0] == i) && (plugin_button[1] == "page_functions"))	{
+			btn_custom_str = "btn_custom_" + parseInt(i);
+			document.getElementById(btn_custom_str).style.height = strHeight;
+		}
 	}
 	
 	if (curr_height4 == 0)
@@ -367,6 +494,16 @@ function ExpandPageFunctions()
 			document.getElementById("btn_restore_page").style.display = inherit;
 			document.getElementById("btn_add_plugin_to_page").style.display = inherit;
 			document.getElementById("btn_manage_page_access").style.display = inherit;
+			document.getElementById("btn_manage_page_attributes").style.display = inherit;
+		}
+		
+		for (i = 0; i < plugin_button_cnt; i++)
+		{
+			plugin_button = plugin_buttons[i];
+			if ((plugin_button[0] == i) && (plugin_button[1] == "page_functions"))	{
+				btn_custom_str = "btn_custom_" + parseInt(i);
+				document.getElementById(btn_custom_str).style.display = inherit;
+			}
 		}
 	}
 	
@@ -381,6 +518,7 @@ function ExpandPageFunctions()
 function CollapsePageFunctions()
 {
 	var strHeight = curr_height4.toString() + 'px';
+	var plugin_button;
 	document.getElementById("btn_edit_page_titles").style.height = strHeight;
 	document.getElementById("btn_edit_meta_tags").style.height = strHeight;
 	if (access_level != "user")
@@ -390,6 +528,16 @@ function CollapsePageFunctions()
 		document.getElementById("btn_restore_page").style.height = strHeight;
 		document.getElementById("btn_add_plugin_to_page").style.height = strHeight;
 		document.getElementById("btn_manage_page_access").style.height = strHeight;
+		document.getElementById("btn_manage_page_attributes").style.height = strHeight;
+	}
+	
+	for (i = 0; i < plugin_button_cnt; i++)
+	{
+		plugin_button = plugin_buttons[i];
+		if ((plugin_button[0] == i) && (plugin_button[1] == "page_functions"))	{
+			btn_custom_str = "btn_custom_" + parseInt(i);
+			document.getElementById(btn_custom_str).style.height = strHeight;
+		}
 	}
 	
 	if (curr_height4 <= 0)
@@ -401,6 +549,16 @@ function CollapsePageFunctions()
 		document.getElementById("btn_restore_page").style.display = "none";
 		document.getElementById("btn_add_plugin_to_page").style.display = "none";
 		document.getElementById("btn_manage_page_access").style.display = "none";
+		document.getElementById("btn_manage_page_attributes").style.display = "none";
+		
+		for (i = 0; i < plugin_button_cnt; i++)
+		{
+			plugin_button = plugin_buttons[i];
+			if ((plugin_button[0] == i) && (plugin_button[1] == "page_functions"))	{
+				btn_custom_str = "btn_custom_" + parseInt(i);
+				document.getElementById(btn_custom_str).style.display = "none";
+			}
+		}
 	}
 	
 	curr_height4--;
@@ -417,6 +575,7 @@ function ExpandOtherFunctions()
 	var strHeight = curr_height5.toString() + 'px';
 	var btn_custom_str;
 	var i;
+	var plugin_button;
 	if ((access_level != "blogger") && (access_level != "restricted"))
 	{
 		if (enable_wizard == 1)
@@ -427,8 +586,11 @@ function ExpandOtherFunctions()
 	
 	for (i = 0; i < plugin_button_cnt; i++)
 	{
-		btn_custom_str = "btn_custom_" + parseInt(i);
-		document.getElementById(btn_custom_str).style.height = strHeight;
+		plugin_button = plugin_buttons[i];
+		if ((plugin_button[0] == i) && ((plugin_button[1] == "other_functions") || (plugin_button[1] == "")))	{
+			btn_custom_str = "btn_custom_" + parseInt(i);
+			document.getElementById(btn_custom_str).style.height = strHeight;
+		}
 	}
 	
 	if (curr_height5 == 0)
@@ -443,8 +605,11 @@ function ExpandOtherFunctions()
 			
 		for (i = 0; i < plugin_button_cnt; i++)
 		{
-			btn_custom_str = "btn_custom_" + parseInt(i);
-			document.getElementById(btn_custom_str).style.display = inherit;
+			plugin_button = plugin_buttons[i];
+			if ((plugin_button[0] == i) && ((plugin_button[1] == "other_functions") || (plugin_button[1] == "")))	{
+				btn_custom_str = "btn_custom_" + parseInt(i);
+				document.getElementById(btn_custom_str).style.display = inherit;
+			}
 		}
 	}
 	
@@ -459,6 +624,8 @@ function ExpandOtherFunctions()
 function CollapseOtherFunctions()
 {
 	var strHeight = curr_height5.toString() + 'px';
+	var btn_custom_str;
+	var i;
 	if ((access_level != "blogger") && (access_level != "restricted"))
 	{
 		if (enable_wizard == 1)
@@ -469,8 +636,11 @@ function CollapseOtherFunctions()
 		
 	for (i = 0; i < plugin_button_cnt; i++)
 	{
-		btn_custom_str = "btn_custom_" + parseInt(i);
-		document.getElementById(btn_custom_str).style.height = strHeight;
+		plugin_button = plugin_buttons[i];
+		if ((plugin_button[0] == i) && ((plugin_button[1] == "other_functions") || (plugin_button[1] == "")))	{
+			btn_custom_str = "btn_custom_" + parseInt(i);
+			document.getElementById(btn_custom_str).style.height = strHeight;
+		}
 	}
 	
 	if (curr_height5 <= 0)
@@ -484,8 +654,11 @@ function CollapseOtherFunctions()
 		
 		for (i = 0; i < plugin_button_cnt; i++)
 		{
-			btn_custom_str = "btn_custom_" + parseInt(i);
-			document.getElementById(btn_custom_str).style.display = "none";
+			plugin_button = plugin_buttons[i];
+			if ((plugin_button[0] == i) && ((plugin_button[1] == "other_functions") || (plugin_button[1] == "")))	{
+				btn_custom_str = "btn_custom_" + parseInt(i);
+				document.getElementById(btn_custom_str).style.display = "none";
+			}
 		}
 	}
 	
@@ -502,7 +675,7 @@ function HorizontalExpandCollapseMenuClick()
 {
 	var img_src = document.getElementById("btn_horizontal_expand_collapse_menus").src;
 	
-	if (img_src.indexOf("images/icon_collapse-column.png") > -1)
+	if (img_src.indexOf("theme/" + theme + "/images/icon_collapse-column.png") > -1)
 	{
 		if (mTimerH == null)
 		{
@@ -550,7 +723,7 @@ function HorizontalExpandCollapseMenus(expand_collapse)
 		workspace_left = parseInt(workspace_left) + 2;
 		if (curr_width > menu_width_expanded)
 		{
-			document.getElementById("btn_horizontal_expand_collapse_menus").src = "images/icon_collapse-column.png";
+			document.getElementById("btn_horizontal_expand_collapse_menus").src = "theme/" + theme + "/images/icon_collapse-column.png";
 			clearInterval(mTimerH);
 			mTimerH = null;
 		}
@@ -562,7 +735,7 @@ function HorizontalExpandCollapseMenus(expand_collapse)
 		workspace_left = parseInt(workspace_left) - 2;
 		if (curr_width < menu_width_collapsed)
 		{
-			document.getElementById("btn_horizontal_expand_collapse_menus").src = "images/icon_expand-column.png";
+			document.getElementById("btn_horizontal_expand_collapse_menus").src = "theme/" + theme + "/images/icon_expand-column.png";
 			clearInterval(mTimerH);
 			mTimerH = null;
 		}
@@ -700,6 +873,7 @@ function SetBtnDown(btn)
 	document.getElementById("btn_restore_page").className =	"button_top_level";
 	document.getElementById("btn_add_plugin_to_page").className =	"button_top_level";
 	document.getElementById("btn_manage_page_access").className =	"button_top_level";
+	document.getElementById("btn_manage_page_attributes").className =	"button_top_level";
 	if ((access_level != "blogger") && (access_level != "restricted"))
 	{
 		if (enable_wizard == 1)
@@ -795,6 +969,7 @@ function SetWorkspaceLocation(module, btn)
 {
 	if (work_saved) 
 	{
+		document.title = "Breeze Website Builder";
 		workspace.location = module;
 		SetBtnDown(btn);
 	}
@@ -833,9 +1008,9 @@ function CheckSession(xmlhttp)
 				popup_msg.left_offset = 300;
 				popup_msg.popup_msg_type = 3;
 				popup_msg.popup_btn_cnt = 2;
-				popup_msg.popup_msg_cell = "Your session has time out.  Do you want to log back in?";
-				popup_msg.popup_button_2_span = "Yes";
-				popup_msg.popup_button_1_span = "No";
+				popup_msg.popup_msg_cell = MAIN_MENU_TIMEOUT_ERR;
+				popup_msg.popup_button_2_span = YES_WORD;
+				popup_msg.popup_button_1_span = NO_WORD;
 				popup_msg.popup_timeout = -1;
 				popup_msg.ShowPopupMsg();
 				document.getElementById("popup_button_2_span").onclick = function () { window.location='index.php'; };
@@ -868,7 +1043,7 @@ function CallResizeWorkspace()
 		mainHeight = document.body.clientHeight;
 	}
 
-	if ((document.getElementById("btn_horizontal_expand_collapse_menus").src).indexOf("images/icon_collapse-column.png") > -1)
+	if ((document.getElementById("btn_horizontal_expand_collapse_menus").src).indexOf("theme/" + theme + "/images/icon_collapse-column.png") > -1)
 		menuWidth = 300;
 	else
 		menuWidth = 90;
