@@ -11,6 +11,9 @@
 // Added Show Login Links Always checkboxes.
 // Revised: 11/6/2014	ELL
 // Overhauled individual user management areas at bottom as AJAX functions.
+// Revised: 3/23/2016	ELL
+// Added error checking when saving restirect page access.
+// Added info links.
 // 
 // 
 //
@@ -22,9 +25,13 @@ var total_pages = 0;
 var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
 var popup_msg = new PopupMsg(param_array);
 
-function OpenHelpWindow()
+window.parent.document.title = document.title;
+
+var no_plefix = 1;
+
+function OpenHelpWindow(topic)
 {
-	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#manage_page_access", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
+	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#" + topic, "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
 }
 
 
@@ -35,9 +42,9 @@ function DeleteUserConfirm()
 	popup_msg.popup_msg_type = 3;
 	popup_msg.popup_btn_cnt = 2;
 	popup_msg.msg_width = 450;
-	popup_msg.popup_msg_cell = "Are you sure you want to delete the user <b>" + document.getElementById("selectUserNameDelete").value + "</b>?";
-	popup_msg.popup_button_2_span = "Yes";
-	popup_msg.popup_button_1_span = "No";
+	popup_msg.popup_msg_cell = MANAGE_PAGE_ACCESS_DELETE_USER_CONFIRM_1_MSG + " <b>" + document.getElementById("selectUserNameDelete").value + "</b>" + MANAGE_PAGE_ACCESS_DELETE_USER_CONFIRM_2_MSG;
+	popup_msg.popup_button_2_span = YES_WORD;
+	popup_msg.popup_button_1_span = NO_WORD;
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
 	document.getElementById("popup_button_2_span").onclick = function () { DeleteUser(); };
@@ -48,7 +55,7 @@ function DeleteUser()
 	var user_name = document.getElementById("selectUserNameDelete").value;
 	var table = document.getElementById("table_delete_user").value;
 	
-	$.post( "delete_user.php", { user_name: user_name, table: table } ).done(CompleteDeleteUser) ;
+	$.post( "delete_user.php", { user_name: user_name, table: table, no_prefix: 1 } ).done(CompleteDeleteUser) ;
 }
 function CompleteDeleteUser(data)
 {
@@ -56,7 +63,7 @@ function CompleteDeleteUser(data)
 	popup_msg.left_offset = 320;
 	popup_msg.popup_msg_type = 2;
 	popup_msg.popup_timeout = 2000;
-	popup_msg.status_msg = "User <b>" + data + "</b> has been deleted";
+	popup_msg.status_msg = MANAGE_PAGE_ACCESS_USER_DELETED_1_MSG + " <b>" + data + "</b> " + MANAGE_PAGE_ACCESS_USER_DELETED_2_MSG;
 	popup_msg.ShowPopupMsg();
 	
 	var user_table = document.getElementById("table_delete_user").value;
@@ -109,9 +116,9 @@ function DeleteAccessLevelConfirm()
 	popup_msg.popup_msg_type = 3;
 	popup_msg.popup_btn_cnt = 2;
 	popup_msg.msg_width = 450;
-	popup_msg.popup_msg_cell = "Are you sure you want to delete the access level <b>" + document.getElementById("access_level_remove").value + "</b>?";
-	popup_msg.popup_button_2_span = "Yes";
-	popup_msg.popup_button_1_span = "No";
+	popup_msg.popup_msg_cell = MANAGE_PAGE_ACCESS_DELETE_ACCESS_LEVEL_CONFIRM_1_MSG + " <b>" + document.getElementById("access_level_remove").value + "</b>" + MANAGE_PAGE_ACCESS_DELETE_ACCESS_LEVEL_CONFIRM_2_MSG;
+	popup_msg.popup_button_2_span = YES_WORD;
+	popup_msg.popup_button_1_span = NO_WORD;
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
 	document.getElementById("popup_button_2_span").onclick = function () { AddRemoveAccessLevel('remove'); };
@@ -127,14 +134,36 @@ function UpdatePageRestriction(page_name, i)
 	var access_level_ctl = "access_level" + i;
 	var login_page_ctl = "login_page" + i;
 	var show_login_links_ctl = "show_login_links" + i;
-
-	popup_msg.popup_msg_type = 1;
-	popup_msg.status_msg = "Starting update...";
+	
 	popup_msg.popup_timeout = -1;
 	popup_msg.top_offset = 0;
 	popup_msg.left_offset = 500;
+	
+	if ((document.getElementById(login_required_ctl).checked === true) && ((document.getElementById(user_table_ctl).value == _NOT_SELECTED_) || (document.getElementById(user_table_ctl).value == "")))	{
+		popup_msg.popup_msg_type = 2;
+		popup_msg.status_msg = MANAGE_PAGE_ACCESS_NO_TABLE_SELECTED_ERR;
+		popup_msg.ShowPopupMsg();
+		return -1;
+	}
+		
+	if ((document.getElementById(login_required_ctl).checked === true) && ((document.getElementById(login_page_ctl).value == _NOT_SELECTED_) || (document.getElementById(login_page_ctl).value == "")))	{
+		popup_msg.popup_msg_type = 2;
+		popup_msg.status_msg = MANAGE_PAGE_ACCESS_NO_LOGIN_PAGE_SELECTED_ERR;
+		popup_msg.ShowPopupMsg();
+		return -1;
+	}
+	
+	popup_msg.popup_msg_type = 1;
+	popup_msg.status_msg = EDITOR_STARTING_UPDATE_MSG;
 	popup_msg.ShowPopupMsg();
 	
+	var table_viability = 0;
+	for (var j = 0; j < tables.length; j++)
+	{
+		if (tables[j][0] == document.getElementById(user_table_ctl).value)
+			table_viability = tables[j][1];
+	}
+	
 	var xmlhttp;
 	xmlhttp = getXmlHttpRequestObject();
 
@@ -153,6 +182,10 @@ function UpdatePageRestriction(page_name, i)
 		if (document.getElementById(login_page_ctl).value != "")
 			params = params + "&login_page=" + document.getElementById(login_page_ctl).value;
 		params = params + "&show_login_links=" + document.getElementById(show_login_links_ctl).value;
+		if (table_viability < 10)
+			params = params + "&add_missing_fields=1";
+		else
+			params = params + "&add_missing_fields=0";
 //		alert(params);
 		xmlhttp.send(params);
 	}
@@ -162,46 +195,46 @@ function UpdatePageRestriction(page_name, i)
 //////////////////////////////////////////////////////////////////////////////////////
 function UpdateMessage(xmlhttp, Source)
 {
-	var query_complete_no_record = "Query complete.  No records found.";
-	var query_complete = "<b>Query complete<\/b><br/>\n";
-	var query_read_to_send = "Query ready to send...";
-	var query_sent = "Query sent";
-	var query_starting = "Locating page restrictions...";
+	var query_complete_no_record = QUERY_COMPLETE_NO_RECORD_FOUND;
+	var query_complete = "<b>" + QUERY_COMPLETE + "<\/b><br/>\n";
+	var query_read_to_send = QUERY_READY_TO_SEND;
+	var query_sent = QUERY_SENT;
+	var query_starting = MANAGE_PAGE_ACCESS_LOCATING_PAGE_RESTRICTIONS_MSG;
 	
 	if (Source == "Update")
 	{
-		query_complete_no_record = "No record found. Could not update page restrictions.";
-		query_complete = "<b>Page restrictions updated<\/b><br/>\n";
-		query_starting = "Updating page restrictions...";
+		query_complete_no_record = MANAGE_PAGE_ACCESS_COULD_NOT_UPDATE_PAGE_RESTRICTIONS_MSG;
+		query_complete = "<b>" + MANAGE_PAGE_ACCESS_PAGE_RESTRICTIONS_UPDATED_MSG + "<\/b><br/>\n";
+		query_starting = MANAGE_PAGE_ACCESS_UPDATING_PAGE_RESTRICTIONS_MSG;
 	}
 	else if (Source == "UpdateUserStatus")
 	{
-		query_complete_no_record = "No record found. Could not update user status.";
-		query_complete = "<b>User status updated<\/b><br/>\n";
-		query_starting = "Updating user status...";
+		query_complete_no_record = MANAGE_PAGE_ACCESS_COULD_NOT_UPDATE_USER_STATUS_MSG;
+		query_complete = "<b>" + MANAGE_PAGE_ACCESS_USER_STATUS_UPDATED_MSG + "<\/b><br/>\n";
+		query_starting = MANAGE_PAGE_ACCESS_UPDATING_USER_STATUS_MSG;
 	}
 	else if (Source == "AddFields")
 	{
-		query_complete_no_record = "Could not modify table.";
-		query_complete = "<b>Fields added to table<\/b><br/>\n";
-		query_starting = "Adding fields to table...";
+		query_complete_no_record = MANAGE_PAGE_ACCESS_COULD_NOT_MODIFY_TABLE_MSG;
+		query_complete = "<b>" + MANAGE_PAGE_ACCESS_FIELDS_ADDED_TO_TABLE_MSG + "<\/b><br/>\n";
+		query_starting = MANAGE_PAGE_ACCESS_ADDING_FIELDS_TO_TABLE_MSG;
 	}
 	else if (Source == "AssignWelcomeMessage")
 	{
-		query_complete_no_record = "Could not modify table.";
-		query_complete = "<b>Welcome message page added to table<\/b><br/>\n";
-		query_starting = "Adding welcome message page to table...";
+		query_complete_no_record = MANAGE_PAGE_ACCESS_COULD_NOT_MODIFY_TABLE_MSG;
+		query_complete = "<b>" + MANAGE_PAGE_ACCESS_WELCOME_MESSAGE_PAGE_ADDED_TO_TABLE_MSG + "<\/b><br/>\n";
+		query_starting = MANAGE_PAGE_ACCESS_ADDING_WELCOME_MESSAGE_PAGE_TO_TABLE_MSG;
 	}
 	else if (Source == "AddRemoveAccessLevel")
 	{
-		query_complete_no_record = "Could not add or delete access level.";
-		query_complete = "<b>Access level records modified<\/b><br/>\n";
-		query_starting = "Changing access levels...";
+		query_complete_no_record = MANAGE_PAGE_ACCESS_COULD_NOT_ADD_DELETE_ACCESS_LEVEL_MSG;
+		query_complete = "<b>" + MANAGE_PAGE_ACCESS_ACESS_LEVEL_RECORDS_MODIFIED_MSG + "<\/b><br/>\n";
+		query_starting = MANAGE_PAGE_ACCESS_CHANGING_ACCESS_LEVELS_MSG;
 	}
 	else if (Source == "PopulateAccessLevels")
-		query_starting = "Locating access levels...";
+		query_starting = MANAGE_PAGE_ACCESS_LOCATING_ACCESS_LEVELS_MSG;
 	else if (Source == "PopulateUsers")
-		query_starting = "Locating users...";
+		query_starting = MANAGE_PAGE_ACCESS_LOCATING_USERS_MSG;
 
 	xmlhttp.onreadystatechange=function()
 	{
@@ -221,7 +254,7 @@ function UpdateMessage(xmlhttp, Source)
 				else if (Source == "PopulateAccessLevels")
 					PopulateAccessLevels(rows_str);
 				else if (Source == "AddFields")
-					alert("Make sure the form you are using for users has fields with the names 'email', 'UserID' and 'Password'. If the table you selected was created using the account-creation form plugin, then these fields already exist in this table.");
+					alert(MANAGE_PAGE_ACCESS_REQUIRED_FIELDS_MSG);
 				else if (Source == "AddRemoveAccessLevel")
 					RetrieveAccessLevels(1);
 				else if (Source == "PopulateUsers")
@@ -249,7 +282,7 @@ function UpdateMessage(xmlhttp, Source)
 function RetrievePages()
 {		
 	popup_msg.popup_msg_type = 1;
-	popup_msg.status_msg = "Retrieving page restrictions...";
+	popup_msg.status_msg = MANAGE_PAGE_ACCESS_RETRIEVING_PAGE_RESTRICTIONS_MSG;
 	popup_msg.popup_timeout = -1;
 	popup_msg.top_offset = 0;
 	popup_msg.left_offset = 500;
@@ -260,10 +293,11 @@ function RetrievePages()
 
 	if (xmlhttp.readyState == 4 || xmlhttp.readyState == 0)
 	{
-		xmlhttp.open("POST","populate_page_restrictions.php",true);
+		xmlhttp.open("POST","get_rows.php",true);
 		xmlhttp.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
 		xmlhttp = UpdateMessage(xmlhttp, "Populate");
-		xmlhttp.send();
+		params = "table=page_data&order_by=page_name";
+		xmlhttp.send(params);
 	}
 }
 
@@ -273,16 +307,18 @@ function PopulatePageTable(rows_str)
 	var rows = new Array();
 
 	var output_str = "<table width='100%' border='0' class='layout_box_table'>\n";
-	output_str = output_str + "<tr><td colspan='5' class='sub_title'>Restrict Page Access</td></tr>\n";
+	output_str = output_str + "<tr><td colspan='5' class='sub_title'>" + MANAGE_PAGE_ACCESS_RESTRICT_PAGE_ACCESS + "</td></tr>\n";
 	output_str = output_str + "<tr bgcolor='#CCCCCC' class='header_row'>\n";
-	output_str = output_str + "<td class='header_row'><b>Page<\/b><\/td>\n";
-	output_str = output_str + "<td class='header_row'><b>Require Login<\/b><\/td>\n";
-	output_str = output_str + "<td class='header_row'><b>User Table<\/b><\/td>\n";
-	output_str = output_str + "<td class='header_row'><b>Access Level<\/b><\/td>\n";
-	output_str = output_str + "<td class='header_row'><b>Login Page<\/b><\/td>\n";
-	output_str = output_str + "<td class='header_row'><b>Show Login<br />Links Always<\/b><\/td>\n";
+	output_str = output_str + "<td class='header_row'><b>" + PAGE_1ST_CAP_WORD + "<\/b><\/td>\n";
+	output_str = output_str + "<td class='header_row'><b>" + MANAGE_PAGE_ACCESS_REQUIRE_LOGIN + "<\/b><\/td>\n";
+	output_str = output_str + "<td class='header_row'><b>" + USER_TABLE_WORD + "<\/b> <div class='help_button_sm info_btn' id='help_button_selector' onClick=\"OpenHelpWindow('user_table');\">&nbsp;</div><\/td>\n";
+	output_str = output_str + "<td class='header_row'><b>" + ACCESS_LEVEL_WORD + "<\/b><\/td>\n";
+	output_str = output_str + "<td class='header_row'><b>" + MANAGE_PAGE_ACCESS_LOGIN_PAGE + "<\/b> <div class='help_button_sm info_btn' id='help_button_selector' onClick=\"OpenHelpWindow('login_page');\">&nbsp;</div><\/td>\n";
+	output_str = output_str + "<td class='header_row'><b>" + MANAGE_PAGE_ACCESS_SHOW_LOGIN_LINKS_ALWAYS + "<\/b><\/td>\n";
 	output_str = output_str + "<td>&nbsp;<\/td>\n";
 	output_str = output_str + "<\/tr>\n";
+	
+	var class_str = "";
 
 	rows = rows_str.split("@@@@@");
 	if (rows[0] == "-no data-")	// If no pages yet (first time).
@@ -312,20 +348,23 @@ function PopulatePageTable(rows_str)
 
 			output_str = output_str + "<td valign='top'>\n";
 			output_str = output_str + "<select name='user_table" + i + "' id='user_table" + i + "'>\n";
-			output_str = output_str + "<option value=''>-not selected-<\/option>\n";
+			output_str = output_str + "<option value=''>" + _NOT_SELECTED_ + "<\/option>\n";
 			for (j = 0; j < table_cnt; j++)
 			{
-				if (tables[j] == JSON_row.user_table)
-					output_str = output_str + "<option value='" + tables[j] + "' selected='selected'>" + tables[j] + "<\/option>\n";
+				class_str = "";
+				if (tables[j][1] < 10)
+					class_str = " class='missing _fields' style='color: #FF0000;'";
+				if (tables[j][0] == JSON_row.user_table)
+					output_str = output_str + "<option value='" + tables[j][0] + "' selected='selected'" + class_str + ">" + tables[j][0] + "<\/option>\n";
 				else
-					output_str = output_str + "<option value='" + tables[j] + "'>" + tables[j] + "<\/option>\n";
+					output_str = output_str + "<option value='" + tables[j][0] + "'" + class_str + ">" + tables[j][0] + "<\/option>\n";
 			}
 			output_str = output_str + "<\/select>\n";
 			output_str = output_str + "<\/td>\n";
 
 			output_str = output_str + "<td valign='top'>\n";
 			output_str = output_str + "<select name='access_level" + i + "' id='access_level" + i + "'>\n";
-			output_str = output_str + "<option value=''>-not selected-<\/option>\n";
+			output_str = output_str + "<option value=''>" + _NOT_SELECTED_ + "<\/option>\n";
 			for (j = 0; j < access_level_cnt; j++)
 			{
 				if (access_levels[j] == JSON_row.AccessLevel)
@@ -338,6 +377,7 @@ function PopulatePageTable(rows_str)
 			
 			output_str = output_str + "<td valign='top'>\n";
 			output_str = output_str + "<select name='login_page" + i + "' id='login_page" + i + "'>\n";
+			output_str = output_str + "<option value=''>" + _NOT_SELECTED_ + "<\/option>\n";
 			for (j = 0; j < login_page_cnt; j++)
 			{
 				if (login_pages[j] == JSON_row.login_page)
@@ -350,19 +390,19 @@ function PopulatePageTable(rows_str)
 			
 			output_str = output_str + "<td>\n";
 			output_str = output_str + "<select name='show_login_links" + i + "' id='show_login_links" + i + "'>\n";
-			output_str = output_str + "<option value='0'>-not selected-<\/option>\n";
+			output_str = output_str + "<option value='0'>" + _NOT_SELECTED_ + "<\/option>\n";
 			if (JSON_row.show_login_links == 1)
-				output_str = output_str + "<option value='1' selected='selected'>Top<\/option>\n";
+				output_str = output_str + "<option value='1' selected='selected'>" + TOP_1ST_CAP_WORD + "<\/option>\n";
 			else
-				output_str = output_str + "<option value='1'>Top<\/option>\n";
+				output_str = output_str + "<option value='1'>" + TOP_1ST_CAP_WORD + "<\/option>\n";
 			if (JSON_row.show_login_links == 2)
-				output_str = output_str + "<option value='2' selected='selected'>Header<\/option>\n";
+				output_str = output_str + "<option value='2' selected='selected'>" + HEADER_1ST_CAP_WORD + "<\/option>\n";
 			else
-				output_str = output_str + "<option value='2'>Header<\/option>\n";
+				output_str = output_str + "<option value='2'>" + HEADER_1ST_CAP_WORD + "<\/option>\n";
 			output_str = output_str + "<\/select>\n";
 			output_str = output_str + "<\/td>\n";
 			
-			output_str = output_str + "<td valign='top'>\n<img src='images/save.png' border=0 alt='Update' name='Update' onClick=\"UpdatePageRestriction('" + JSON_row.page_name + "', " + i + ");\" />\n<\/td>\n";
+			output_str = output_str + "<td valign='top'>\n<img src='theme/" + theme + "/images/save.png' border=0 alt='Update' name='Update' onClick=\"UpdatePageRestriction('" + JSON_row.page_name + "', " + i + ");\" style='cursor:pointer;' />\n<\/td>\n";
 			
 			output_str = output_str + "<\/tr>\n";
 
@@ -380,7 +420,7 @@ function RetrieveAccessLevels(update_page_table)
 	update_page_table_mode = update_page_table;
 	
 	popup_msg.popup_msg_type = 1;
-	popup_msg.status_msg = "Retrieving access levels...";
+	popup_msg.status_msg = MANAGE_PAGE_ACCESS_RETRIEVING_ACCESS_LEVELS_MSG;
 	popup_msg.popup_timeout = -1;
 	popup_msg.top_offset = 0;
 	popup_msg.left_offset = 500;
@@ -391,10 +431,11 @@ function RetrieveAccessLevels(update_page_table)
 
 	if (xmlhttp.readyState == 4 || xmlhttp.readyState == 0)
 	{
-		xmlhttp.open("POST","populate_access_levels.php",true);
+		xmlhttp.open("POST","get_rows.php",true);
 		xmlhttp.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
 		xmlhttp = UpdateMessage(xmlhttp, "PopulateAccessLevels");
-		xmlhttp.send();
+		params = "table=access_levels";
+		xmlhttp.send(params);
 	}
 }
 
@@ -406,9 +447,9 @@ function PopulateAccessLevels(rows_str)
 	var output_str = "<select name='access_level_remove' id='access_level_remove'>\n";
 	var output_str2 = "<select name='selectAccessLevel' id='selectAccessLevelNewUser'>\n";
 	var output_str3 = "<select name='selectAccessLevel' id='selectAccessLevelEdit'>\n";
-	output_str = output_str + "<option>-not selected-</option>\n";
-	output_str2 = output_str2 + "<option>-not selected-</option>\n";
-	output_str3 = output_str3 + "<option>-not selected-</option>\n";
+	output_str = output_str + "<option>" + _NOT_SELECTED_ + "</option>\n";
+	output_str2 = output_str2 + "<option>" + _NOT_SELECTED_ + "</option>\n";
+	output_str3 = output_str3 + "<option>" + _NOT_SELECTED_ + "</option>\n";
 
 	rows = rows_str.split("@@@@@");
 	if (rows[0] == "-no data-")	// If no pages yet (first time).
@@ -426,7 +467,7 @@ function PopulateAccessLevels(rows_str)
 	output_str = output_str + "<\/select>\n";
 	output_str2 = output_str2 + "<\/select>\n";
 	output_str3 = output_str3 + "<\/select>\n";
-	
+
 	document.getElementById("AccessLevelRemoveDiv").innerHTML = output_str;
 	document.getElementById("AccessLevelAddUserDiv").innerHTML = output_str2;
 	document.getElementById("AccessLevelEditUserDiv").innerHTML = output_str3;
@@ -453,7 +494,7 @@ function PopulateAccessLevels(rows_str)
 function RetrieveUserLists(user_table, start)
 {	
 	popup_msg.popup_msg_type = 1;
-	popup_msg.status_msg = "Retrieving users...";
+	popup_msg.status_msg = MANAGE_PAGE_ACCESS_RETRIEVING_USERS_MSG;
 	popup_msg.popup_timeout = -1;
 	popup_msg.top_offset = 0;
 	popup_msg.left_offset = 500;
@@ -491,14 +532,14 @@ function PopulateUserLists(rows_str)
 
 	var output_str = "<select name='selectUserName' id='selectUserNameExistingUser'>\n";
 	var output_str2 = "<select name='selectUserName' id='selectUserNameDelete'>\n";
-	var output_str3 = "<select name='selectUserName' id='selectUserNameEdit'>\n";
+	var output_str3 = "<select name='selectUserName' id='selectUserNameEdit' onChange='GetUser(this.value);'>\n";
 	var output_str4 =  "<table width='100%' border='0' cellspacing='0' cellpadding='0'>\n";
-	output_str = output_str + "<option>-not selected-</option>\n";
-	output_str2 = output_str2 + "<option>-not selected-</option>\n";
-	output_str3 = output_str3 + "<option>-not selected-</option>\n";
+	output_str = output_str + "<option>" + _NOT_SELECTED_ + "</option>\n";
+	output_str2 = output_str2 + "<option>" + _NOT_SELECTED_ + "</option>\n";
+	output_str3 = output_str3 + "<option>" + _NOT_SELECTED_ + "</option>\n";
 	output_str4 = output_str4 + "<tr bgcolor='#CCCCCC' class='header_row'>\n";
-	output_str4 = output_str4 + "<td class='header_row'><b>User<\/b><\/td>\n";
-	output_str4 = output_str4 + "<td class='header_row'><b>Active<\/b><\/td>\n";
+	output_str4 = output_str4 + "<td class='header_row'><b>" + USER_WORD + "<\/b><\/td>\n";
+	output_str4 = output_str4 + "<td class='header_row'><b>" + ACTIVE_WORD + "<\/b><\/td>\n";
 	output_str4 = output_str4 + "<td>&nbsp;<\/td>\n";
 	output_str4 = output_str4 + "</tr>\n";
 
@@ -540,7 +581,7 @@ function PopulateUserLists(rows_str)
 					output_str4 = output_str4 + " checked='checked'";
 				output_str4 = output_str4 + " />\n</td>\n";
 				
-				output_str4 = output_str4 + "<td valign='top'>\n<img src='images/save.png' border=0 alt='Update' name='Update' onClick=\"UpdateUserStatus('" + JSON_row.UserID + "', " + i + ");\" />\n<\/td>\n";
+				output_str4 = output_str4 + "<td valign='top'>\n<img src='theme/" + theme + "/images/save.png' border=0 alt='Update' name='Update' onClick=\"UpdateUserStatus('" + JSON_row.UserID + "', " + i + ");\" style='cursor:pointer;' />\n<\/td>\n";
 
 			}
 			if (JSON_row.welcome_message_page)
@@ -571,7 +612,7 @@ function UpdateUserStatus(UserID, i)
 	var active_ctl = "active" + i;
 
 	popup_msg.popup_msg_type = 1;
-	popup_msg.status_msg = "Starting update...";
+	popup_msg.status_msg = EDITOR_STARTING_UPDATE_MSG;
 	popup_msg.popup_timeout = -1;
 	popup_msg.top_offset = 0;
 	popup_msg.left_offset = 500;
@@ -598,7 +639,7 @@ function UpdateUserStatus(UserID, i)
 function AddFieldsToTable()
 {		
 	popup_msg.popup_msg_type = 1;
-	popup_msg.status_msg = "Adding login fields to table...";
+	popup_msg.status_msg = MANAGE_PAGE_ACCESS_ADDING_LOGIN_FIELDS_TO_TABLE_MSG;
 	popup_msg.popup_timeout = -1;
 	popup_msg.top_offset = 0;
 	popup_msg.left_offset = 500;
@@ -622,7 +663,7 @@ function AddFieldsToTable()
 function AssignWelcomeMessagePageToTable()
 {		
 	popup_msg.popup_msg_type = 1;
-	popup_msg.status_msg = "Assigning welcome message page to table...";
+	popup_msg.status_msg = MANAGE_PAGE_ACCESS_ASSIGNING_WELCOME_MESSAGE_PAGE_TO_TABLE_MSG;
 	popup_msg.popup_timeout = -1;
 	popup_msg.top_offset = 0;
 	popup_msg.left_offset = 500;
@@ -649,12 +690,12 @@ function AddRemoveAccessLevel(action)
 {		
 	if (action == "add")
 	{
-		popup_msg.status_msg = "Adding access level...";
+		popup_msg.status_msg = MANAGE_PAGE_ACCESS_ADDING_ACCESS_LEVEL_MSG;
 	}
 	else
 	{
 		HidePopupMsg();
-		popup_msg.status_msg = "Removing access level...";
+		popup_msg.status_msg = MANAGE_PAGE_ACCESS_REMOVING_ACCESS_LEVEL_MSG;
 	}
 	popup_msg.popup_msg_type = 1;
 	popup_msg.popup_timeout = -1;
@@ -767,32 +808,32 @@ function ShowHidePageBtns()
 
 	if (page < 1)
 	{
-		document.getElementById("first_top").src = "./images/First_disabled.gif";
-		document.getElementById("prev_top").src = "./images/Previous_disabled.gif";
-		document.getElementById("first_bot").src = "./images/First_disabled.gif";
-		document.getElementById("prev_bot").src = "./images/Previous_disabled.gif";
+		document.getElementById("first_top").src = "./theme/" + theme + "/images/First_disabled.gif";
+		document.getElementById("prev_top").src = "./theme/" + theme + "/images/Previous_disabled.gif";
+		document.getElementById("first_bot").src = "./theme/" + theme + "/images/First_disabled.gif";
+		document.getElementById("prev_bot").src = "./theme/" + theme + "/images/Previous_disabled.gif";
 	}
 	else
 	{
-		document.getElementById("first_top").src = "./images/First.gif";
-		document.getElementById("prev_top").src = "./images/Previous.gif";
-		document.getElementById("first_bot").src = "./images/First.gif";
-		document.getElementById("prev_bot").src = "./images/Previous.gif";
+		document.getElementById("first_top").src = "./theme/" + theme + "/images/First.gif";
+		document.getElementById("prev_top").src = "./theme/" + theme + "/images/Previous.gif";
+		document.getElementById("first_bot").src = "./theme/" + theme + "/images/First.gif";
+		document.getElementById("prev_bot").src = "./theme/" + theme + "/images/Previous.gif";
 	}
 	
 	if (page == total_pages)
 	{
-		document.getElementById("next_top").src = "./images/Next_disabled.gif";
-		document.getElementById("last_top").src = "./images/Last_disabled.gif";
-		document.getElementById("next_bot").src = "./images/Next_disabled.gif";
-		document.getElementById("last_bot").src = "./images/Last_disabled.gif";
+		document.getElementById("next_top").src = "./theme/" + theme + "/images/Next_disabled.gif";
+		document.getElementById("last_top").src = "./theme/" + theme + "/images/Last_disabled.gif";
+		document.getElementById("next_bot").src = "./theme/" + theme + "/images/Next_disabled.gif";
+		document.getElementById("last_bot").src = "./theme/" + theme + "/images/Last_disabled.gif";
 	}
 	else
 	{
-		document.getElementById("next_top").src = "./images/Next.gif";
-		document.getElementById("last_top").src = "./images/Last.gif";
-		document.getElementById("next_bot").src = "./images/Next.gif";
-		document.getElementById("last_bot").src = "./images/Last.gif";
+		document.getElementById("next_top").src = "./theme/" + theme + "/images/Next.gif";
+		document.getElementById("last_top").src = "./theme/" + theme + "/images/Last.gif";
+		document.getElementById("next_bot").src = "./theme/" + theme + "/images/Next.gif";
+		document.getElementById("last_bot").src = "./theme/" + theme + "/images/Last.gif";
 	}
 }
 
@@ -808,12 +849,12 @@ function AddUser()
 	var table = document.getElementById('table_new_user').value;
 	var website_user = 1;
 
-	$.post( "add_user.php", { user_name: user_name, password: password, AccessLevel: AccessLevel, email: email, first_name: first_name, last_name: last_name, table: table, website_user: website_user } ).done(CompleteAddUser) ;
+	$.post( "add_user.php", { user_name: user_name, password: password, AccessLevel: AccessLevel, email: email, first_name: first_name, last_name: last_name, table: table, website_user: website_user, no_prefix: 1 } ).done(CompleteAddUser) ;
 }
 function CompleteAddUser(data)
 {
 	if (data == "-no data-")
-		popup_msg.status_msg = "An error has occured.  The new user was not added.";
+		popup_msg.status_msg = MANAGE_PAGE_ACCESS_NEW_USER_NOT_ADDED_ERR;
 	else
 	{
 		var field_pairs = data.split("@@@@@");
@@ -825,11 +866,11 @@ function CompleteAddUser(data)
 			fields[pair[0]] = pair[1];
 		}
 	
-		popup_msg.status_msg = "New user <b>" + fields['user_name'] + "</b> has been created with password <b>" + fields['password'] + "</b> and an access level of <b>" + fields['AccessLevel'] + "</b>";
+		popup_msg.status_msg = MANAGE_PAGE_ACCESS_NEW_USER_CREATED_1_MSG + " <b>" + fields['user_name'] + "</b> " + MANAGE_PAGE_ACCESS_NEW_USER_CREATED_2_MSG + " <b>" + fields['password'] + "</b> " + MANAGE_PAGE_ACCESS_NEW_USER_CREATED_3_MSG + " <b>" + fields['AccessLevel'] + "</b>";
 		if ((fields['first_name'] != "") || (fields['last_name'] != ""))
-			popup_msg.status_msg = popup_msg.status_msg + " for <b>" + fields['first_name'] + " " + fields['last_name'] + "</b>";
+			popup_msg.status_msg = popup_msg.status_msg + " " + MANAGE_PAGE_ACCESS_NEW_USER_CREATED_4_MSG + " <b>" + fields['first_name'] + " " + fields['last_name'] + "</b>";
 		if (fields['email'] != "")
-			popup_msg.status_msg = popup_msg.status_msg + " with email <b>" + fields['email'] + "</b>";
+			popup_msg.status_msg = popup_msg.status_msg + " " + MANAGE_PAGE_ACCESS_NEW_USER_CREATED_5_MSG + " <b>" + fields['email'] + "</b>";
 	}
 		
 	popup_msg.top_offset = 100;
@@ -858,7 +899,7 @@ function ChangePassword()
 	var table = document.getElementById('table_existing_user').value;
 	var website_user = 1;
 	
-	$.post( "change_password.php", { user_name: user_name, password: password, table: table, website_user: website_user } ).done(CompleteChangePassword) ;
+	$.post( "change_password.php", { user_name: user_name, password: password, table: table, website_user: website_user, no_prefix: 1 } ).done(CompleteChangePassword) ;
 }
 function CompleteChangePassword(data)
 {
@@ -875,7 +916,7 @@ function CompleteChangePassword(data)
 	popup_msg.left_offset = 320;
 	popup_msg.popup_msg_type = 2;
 	popup_msg.popup_timeout = -1;
-	popup_msg.status_msg = "The password for user <b>" + fields['user_name'] + "</b> has been change to <b>" + fields['password'] + "</b>";
+	popup_msg.status_msg = MANAGE_PAGE_ACCESS_PASSWORD_CHANGED_1_MSG + " <b>" + fields['user_name'] + "</b> " + MANAGE_PAGE_ACCESS_PASSWORD_CHANGED_2_MSG + " <b>" + fields['password'] + "</b>";
 	popup_msg.ShowPopupMsg();
 }
 
@@ -889,7 +930,7 @@ function ModifyUser()
 	var table = document.getElementById('table_edit').value;
 	var website_user = 1;
 	
-	$.post( "modify_user.php", { user_name: user_name, AccessLevel: AccessLevel, email: email, first_name: first_name, last_name: last_name, table: table, website_user: website_user } ).done(CompleteModifyUser) ;
+	$.post( "modify_user.php", { user_name: user_name, AccessLevel: AccessLevel, email: email, first_name: first_name, last_name: last_name, table: table, website_user: website_user, no_prefix: 1 } ).done(CompleteModifyUser) ;
 }
 function CompleteModifyUser(data)
 {
@@ -906,23 +947,23 @@ function CompleteModifyUser(data)
 	popup_msg.left_offset = 320;
 	popup_msg.popup_msg_type = 2;
 	popup_msg.popup_timeout = 5000;
-	popup_msg.status_msg = "User <b>" + fields['user_name'] + "</b> has been modified with an access level of <b>" + fields['AccessLevel'] + "</b>";
+	popup_msg.status_msg = MANAGE_PAGE_ACCESS_USER_CHANGED_1_MSG + " <b>" + fields['user_name'] + "</b> " + MANAGE_PAGE_ACCESS_USER_CHANGED_2_MSG + " <b>" + fields['AccessLevel'] + "</b>";
 	if ((fields['first_name'] != "") || (fields['last_name'] != ""))
-		popup_msg.status_msg = popup_msg.status_msg + ", a name of <b>" + fields['first_name'] + " " + fields['last_name'] + "</b>";
+		popup_msg.status_msg = popup_msg.status_msg + MANAGE_PAGE_ACCESS_USER_CHANGED_3_MSG + " <b>" + fields['first_name'] + " " + fields['last_name'] + "</b>";
 	if (fields['email'] != "")
-		popup_msg.status_msg = popup_msg.status_msg + " and an email of <b>" + fields['email'] + "</b>";
+		popup_msg.status_msg = popup_msg.status_msg + " " + MANAGE_PAGE_ACCESS_USER_CHANGED_4_MSG + " <b>" + fields['email'] + "</b>";
 	popup_msg.ShowPopupMsg();
 }
 
 function GetUser(user_name)
 {
 	var table = document.getElementById('table_edit').value;
-	$.post( "get_user.php", { user_name: user_name, table: table } ).done(PopulateUser) ;
+	$.post( "get_rows.php", { table: table, where: "`UserID` = '" + user_name + "'", no_prefix: 1 } ).done(PopulateUser) ;
 }
 function PopulateUser(data)
 {
 	if (data == "-no data-")
-		alert("Error: No data found for that user");
+		alert(MANAGE_PAGE_ACCESS_NO_DATA_FOUND_FOR_USER_ERR);
 	else
 	{
 		var JSON_row = JSON.parse(data);
