@@ -7,6 +7,8 @@
 var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
 var popup_msg = new PopupMsg(param_array);
 
+window.parent.document.title = document.title;
+
 function OpenHelpWindow()
 {
 	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#restore_page_select", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
@@ -20,9 +22,9 @@ function DeleteConfirm(page_name, ID)
 	popup_msg.popup_msg_type = 3;
 	popup_msg.popup_btn_cnt = 2;
 	popup_msg.msg_width = 450;
-	popup_msg.popup_msg_cell = "Are you sure you want to <b>delete</b> the <b>" + page_name + "</b> page from the backup history?";
-	popup_msg.popup_button_2_span = "Yes";
-	popup_msg.popup_button_1_span = "No";
+	popup_msg.popup_msg_cell = RESTORE_PAGE_DELETE_BACKUP_CONFIRM_1_MSG + " <b>" + page_name + "</b> " + RESTORE_PAGE_DELETE_BACKUP_CONFIRM_2_MSG;
+	popup_msg.popup_button_2_span = YES_WORD;
+	popup_msg.popup_button_1_span = NO_WORD;
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
 	document.getElementById("popup_button_2_span").onclick = function () { DeletePageFromHistory(page_name, ID); };
@@ -44,9 +46,9 @@ function RestoreConfirm(page_name, ID)
 	popup_msg.popup_msg_type = 3;
 	popup_msg.popup_btn_cnt = 2;
 	popup_msg.msg_width = 450;
-	popup_msg.popup_msg_cell = "Are you sure you want to <b>restore</b> the <b>" + page_name + "</b> page?";
-	popup_msg.popup_button_2_span = "Yes";
-	popup_msg.popup_button_1_span = "No";
+	popup_msg.popup_msg_cell = RESTORE_PAGE_RESTORE_PAGE_CONFIRM_1_MSG + " <b>" + page_name + "</b> " + RESTORE_PAGE_RESTORE_PAGE_CONFIRM_2_MSG;
+	popup_msg.popup_button_2_span = YES_WORD;
+	popup_msg.popup_button_1_span = NO_WORD;
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
 	document.getElementById("popup_button_2_span").onclick = function () { RestorePage(page_name, ID); };
@@ -71,7 +73,7 @@ function SelectPage(page_name)
 function DisplayArchivedContent(ID)
 {
 	popup_msg.popup_msg_type = 1;
-	popup_msg.status_msg = "Preparing preview...";
+	popup_msg.status_msg = EDITOR_PREPARING_PREVIEW_MSG;
 	popup_msg.popup_timeout = 2000;
 	popup_msg.top_offset = 0;
 	popup_msg.left_offset = 500;
