@@ -26,23 +26,29 @@
 	include ("check_session.php");
 	
 ?>
+<!DOCTYPE html>
 <html>
 <head>
-<title>Breeze Website Builder</title>
+<title>Change Site Options | Breeze Website Builder</title>
 <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
-<link rel="stylesheet" href="manager.css" type="text/css">
+<link rel="stylesheet" href="theme/<?php echo $theme; ?>/manager.css" type="text/css">
 <link rel="shortcut icon" href="images/favicon.ico" type="image/x-icon">
 
 <style type="text/css">
 #save_options_btn	{	width:110px;	}
 </style>
 
-<script type="text/javascript" src="js/jquery-1.11.1.min.js"></script>
+<script type="text/javascript" src="js/jquery.min.js"></script>
 <script language="javascript" type="text/javascript" src="js/browser_detect.js"></script>
 <script language="javascript" type="text/javascript" src="js/mouse_position.js"></script>
 <script language="javascript" type="text/javascript" src="js/popup_msg.js"></script>
 <script language="javascript" type="text/javascript" src="js/options.js"></script>
 <script>
+<?php
+	echo "	var MANAGE_SITE_OPTIONS_OPTIONS_SAVED_MSG = \"" . MANAGE_SITE_OPTIONS_OPTIONS_SAVED_MSG . "\";\n";
+	echo "	var MANAGE_SITE_OPTIONS_ERROR_SAVING_OPTIONS_ERR = \"" . MANAGE_SITE_OPTIONS_ERROR_SAVING_OPTIONS_ERR . "\";\n";
+?>
+
 	var option_image = 
 	{
 <?php
@@ -84,11 +90,11 @@
 <div align="center">
 
 	<table width="80%" border="0"><tr><td>
-	<div class="button_heading_sub_level_1"><div class="button_heading_text_sub_level_1">Change Site Options</div><div class="button_heading_help" onClick="OpenHelpWindow();">&nbsp;</div></div>
+	<div class="button_heading_sub_level_1"><div class="button_heading_text_sub_level_1"><?php echo MANAGE_SITE_OPTIONS_HEADING; ?></div><div class="button_heading_help" onClick="OpenHelpWindow();">&nbsp;</div></div>
     </td></tr></table>
     
 	<table width="80%" class="layout_box_table">
-	<tr bgcolor='#CCCCCC'><td class="sub_title">Option</td><td class="sub_title">Value</td><td>&nbsp;</td></tr>
+	<tr bgcolor='#CCCCCC'><td class="sub_title"><?php echo OPTION_WORD; ?></td><td class="sub_title"><?php echo VALUE_WORD; ?></td><td>&nbsp;</td></tr>
 <?php
 	
 	//First, create image style list for images in dropdown.
@@ -114,10 +120,17 @@
 		//Get record from options table with all possible options.
 		$option_name = $row["option_name"];
 		$option_string = $row["option_string"];
+		$option_string_define = $row["option_string_define"];
 		$option_value = $row["option_value"];
 		$data_type = $row["data_type"];
 		if (($option_name == "RunWizardLocal") && (!file_exists("../wizard")))
 			continue;
+			
+		if (isset($option_string_define) && ($option_string_define != ""))
+		{
+			if (defined($option_string_define) && (constant($option_string_define) != ""))
+				$option_string = constant($option_string_define);
+		}
 		
 		//If this is the 1st time to see this option, write table row and put option string in first cell and dropdown list in 2nd.
 		if ($option_name != $last_option_name)
@@ -196,7 +209,7 @@
 ?>
 	<tr><td colspan="3">&nbsp;</td></tr>
 	<tr><td align="center" colspan="3">
-        <div class='button_console_save' id="save_options_btn" onClick="SaveOptions();"><span class='button_console_text_w_icon'>Submit</span></div>
+        <div class='button_console_save' id="save_options_btn" onClick="SaveOptions();"><span class='button_console_text_w_icon'><?php echo SUBMIT_WORD; ?></span></div>
   	</td>
 	</tr>
   </table>
