@@ -14,8 +14,8 @@
 	$style_sheet = $_POST['style_sheet'];
 	$class_table = $style_sheet . "_classes";
 	
-	$replace = array(".", "#", " ", ",");
-	$search = array("PERIOD", "POUND", "SPACE", "COMMA");
+	$replace = array(".", "#", " ", ",", ">", "&gt;", "+", "~");
+	$search = array("PERIOD", "POUND", "SPACE", "COMMA", "GREATERTHAN", "GREATERTHAN", "PLUS", "TILDA");
 	$class = str_replace($search, $replace, $class);
 	
 	$query = "SELECT `description` FROM `" . BWB_TABLE_PREFIX . $class_table . "` WHERE `class`='" . $class . "'";
