@@ -15,8 +15,8 @@
 	$css_table = $_GET['css_table'];
 	$class = $_GET['class'];
 	$_SESSION['last_class_edited'] = $class;
-	$search = array("PERIOD", "POUND", "SPACE", "COMMA");
-	$replace = array(".", "#", " ", ",");
+	$search = array("PERIOD", "POUND", "SPACE", "COMMA", "GREATERTHAN", "GREATERTHAN", "PLUS", "TILDA");
+	$replace = array(".", "#", " ", ",", ">", "&gt;", "+", "~");
 	$class = str_replace($search, $replace, $class);
 	
 	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . $css_table . "` WHERE `class`='" . $class . "'";
