@@ -18,5 +18,8 @@
 	$query = "UPDATE " . BWB_TABLE_PREFIX . "head SET head_name='" . $head_name . "' WHERE head_name='" . $head_old_name . "'";
 	$cnt = $bwb_dbh->exec($query);
 	
-	header("Location: manage_head.php");
+	$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_draft SET page_name='" . $head_name . "' WHERE page_name='" . $head_old_name . "'";
+	$cnt2 = $bwb_dbh->exec($query);
+	
+	echo $cnt . "@@@@@" . $area_old_name  . "@@@@@" . $name_prefix . $name_suffix;
 ?>
\ No newline at end of file
