@@ -30,6 +30,18 @@
 // Removed obsolete image Upload as this in now done with "AJAX" image uploader.
 // Revised: 1/12/2015	ELL
 // Replaced deprecated font-stretch with letter-spacing.
+// Revised: 2/14/2015	ELL
+// Added visibility.
+// Added full compliment of font-size units.
+// Added full compliment of length units to border.
+// Added full compliment of length units to all paddings.
+// Revised: 5/15/2015	ELL
+// Added background transparancy.
+// Added overflow-x and overflow-y.
+// Revised: 9/21/2015	ELL
+// Added text-indent attribute.
+// Revised: 1/19/2016	ELL
+// Elimination of forwarding to CSS preview page. (New preview design.)
 //
 //
 	include ("check_session.php");
@@ -40,180 +52,56 @@
 	$css_file = $style_sheet . ".css";
 	$show_class_editor = $_REQUEST['show_class_editor'];
 	
-	include ("build_sql_string.php");
+	include ("lib/build_sql_string.php");
+	include("lib/build_css_string.php");
+	include ("lib/copy_table.php");
 
 	$submit_action = $_REQUEST['submit_action'];
 	if ($submit_action == "Update")
 	{
 		$site_css_table = $css_table;
-		if ($style_sheet == "site_mobile")
-			$custom_site_css_table = "custom_site_mobile_css";
-		else
-			$custom_site_css_table = "custom_site_css";
 	}
 	elseif ($submit_action == "Preview")
 	{
 		$site_css_table = "site_css_preview";
-		$custom_site_css_table = "custom_site_css_preview";
 		
 		//Start by deleting all old data in table.
 		$query = "TRUNCATE TABLE " . BWB_TABLE_PREFIX . "site_css_preview";
 		$cnt = $bwb_dbh->exec($query);
 		
 		//Get data from live table and move to preview table.
-		$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . $css_table. "`";
-		$result = $bwb_dbh->query($query);
-		while ($row = $result->fetch(PDO::FETCH_ASSOC))
-		{
-			$class = $row["class"];
-			$sub_class_of = $row["sub_class_of"];
-			$use_table_data = $row["use_table_data"];
-			$font = $row["font"];
-			$font2 = $row["font2"];
-			$font3 = $row["font3"];
-			$font_size = $row["font_size"];
-			$text_color = $row["text_color"];
-			$padding_top = $row["padding_top"];
-			$padding_right = $row["padding_right"];
-			$padding_bottom = $row["padding_bottom"];
-			$padding_left = $row["padding_left"];
-			$weight = $row["weight"];
-			$italic = $row["italic"];
-			$underline = $row["underline"];
-			$overline = $row["overline"];
-			$blink = $row["blink"];
-			$linethrough = $row["linethrough"];
-			//$font_stretch = $row["font_stretch"];
-			$letter_spacing = $row["letter_spacing"];
-			$letter_spacing_units = $row["letter_spacing_units"];
-			$oblique = $row["oblique"];
-			$small_caps = $row["small_caps"];
-			$no_text_decoration = $row["no_text_decoration"];
-			$shadow = $row["shadow"];
-			$shadow_color = $row["shadow_color"];
-			$shadow_x_offset = $row["shadow_x_offset"];
-			$shadow_y_offset = $row["shadow_y_offset"];
-			$shadow_blur = $row["shadow_blur"];
-			$line_height = $row["line_height"];
-			$line_height_units = $row["line_height_units"];
-			
-			$align = $row["align"];
-			$vertical_align = $row["vertical_align"];
-			$display = $row["display"];
-			
-			$bkgd_color = $row["bkgd_color"];
-			$bkgd_opacity = $row["bkgd_opacity"];
-			$border = $row["border"];
-			$border_color = $row["border_color"];
-			$border_style = $row["border_style"];
-			$outline_style = $row["outline_style"];
-			$border_collapse = $row["border_collapse"];
-			$border_sides = $row["border_sides"];
-			
-			$margin_top = $row["margin_top"];
-			$margin_right = $row["margin_right"];
-			$margin_left = $row["margin_left"];
-			$margin_bottom = $row["margin_bottom"];
-			$margin_top_units = $row["margin_top_units"];
-			$margin_top_auto = $row["margin_top_auto"];
-			$margin_right_units = $row["margin_right_units"];
-			$margin_right_auto = $row["margin_right_auto"];
-			$margin_left_units = $row["margin_left_units"];
-			$margin_left_auto = $row["margin_left_auto"];
-			$margin_bottom_units = $row["margin_bottom_units"];
-			$margin_bottom_auto = $row["margin_bottom_auto"];
-			$width = $row["width"];
-			$width_units = $row["width_units"];
-			$width_prefix = $row["width_prefix"];
-			$height = $row["height"];
-			$height_units = $row["height_units"];
-			$height_prefix = $row["height_prefix"];
-			
-			$background_image = $row["background_image"];
-			$background_attachment = $row["background_attachment"];
-			$background_repeat = $row["background_repeat"];
-			$background_position = $row["background_position"];
-			$background_position_x = $row["background_position_x"];
-			$background_position_y = $row["background_position_y"];
-			$background_position_units = $row["background_position_units"];
-			
-			$position = $row["position"];
-			$position_left = $row["position_left"];
-			$position_left_units = $row["position_left_units"];
-			$position_top = $row["position_top"];
-			$position_top_units = $row["position_top_units"];
-			$position_right = $row["position_right"];
-			$position_right_units = $row["position_right_units"];
-			$position_bottom = $row["position_bottom"];
-			$position_bottom_units = $row["position_bottom_units"];
-			$z_index = $row["z_index"];
-			$overflow = $row["overflow"];
-			$clip_top = $row["clip_top"];
-			$clip_top_units = $row["clip_top_units"];
-			$clip_right = $row["clip_right"];
-			$clip_right_units = $row["clip_right_units"];
-			$clip_bottom = $row["clip_bottom"];
-			$clip_bottom_units = $row["clip_bottom_units"];
-			$clip_left = $row["clip_left"];
-			$clip_left_units = $row["clip_left_units"];
-			$float = $row["float"];
-			$white_space = $row["white_space"];
-			
-			$list_style_type = $row["list_style_type"];
-			$list_style_position = $row["list_style_position"];
-			$list_style_image = $row["list_style_image"];
-			
-			$table_layout = $row["table_layout"];
-			$clear = $row["clear"];
-			
-			$radius_top_left = $row["radius_top_left"];
-			$radius_top_left_units = $row["radius_top_left_units"];
-			$radius_top_right = $row["radius_top_right"];
-			$radius_top_right_units = $row["radius_top_right_units"];
-			$radius_bottom_right = $row["radius_bottom_right"];
-			$radius_bottom_right_units = $row["radius_bottom_right_units"];
-			$radius_bottom_left = $row["radius_bottom_left"];
-			$radius_bottom_left_units = $row["radius_bottom_left_units"];
-			
-			$box_shadow_horizontal = $row["box_shadow_horizontal"];
-			$box_shadow_vertical = $row["box_shadow_vertical"];
-			$box_shadow_blur = $row["box_shadow_blur"];
-			$box_shadow_spread = $row["box_shadow_spread"];
-			$box_shadow_color = $row["box_shadow_color"];
-			$box_shadow_inset = $row["box_shadow_inset"];
-			
-			$cursor = $row["cursor"];
-			
-			$background_size = $row["background_size"];
-			$background_width = $row["background_width"];
-			$background_width_units = $row["background_width_units"];
-			$background_height = $row["background_height"];
-			$background_height_units = $row["background_height_units"];
-
-			//Insert new data into table.
-		$insert_key = "class='" . $class . "', ";
+		copy_table(BWB_TABLE_PREFIX . $css_table, BWB_TABLE_PREFIX . $site_css_table, $bwb_dbh, $bwb_database);
 		
-		$query2 = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, $use_table_data, $font, $font2, $font3, $font_size, $text_color, $padding_top, $padding_right, $padding_bottom, $padding_left, $weight, $italic,
-		$underline, $overline, $blink, $linethrough, $letter_spacing, $letter_spacing_units, $oblique, $small_caps, $no_text_decoration, $shadow, $shadow_color, $shadow_x_offset,
-		$shadow_y_offset, $shadow_blur, $line_height, $line_height_units, $align, $vertical_align, $bkgd_color, $bkgd_opacity, $border, $border_color,
-		$border_style, $outline_style, $border_collapse, $border_sides, $margin_top, $margin_top_units, $margin_top_auto, $margin_right, $margin_right_units,
-		$margin_right_auto, $margin_left, $margin_left_units, $margin_left_auto, $margin_bottom, $margin_bottom_units, $margin_bottom_auto,
-		$display, $width, $width_units, $width_prefix, $height, $height_units, $height_prefix,
-		$position, $position_left, $position_left_units, $position_top, $position_top_units,
-		$position_right, $position_right_units, $position_bottom, $position_bottom_units, $z_index, $overflow,
-		$clip_top, $clip_top_units, $clip_right, $clip_right_units, $clip_bottom, $clip_bottom_units, $clip_left, $clip_left_units,
-		$background_image, $background_attachment, $background_repeat, $background_position, $background_position_x, $background_position_y,
-		$background_position_units, $list_style_type, $list_style_position, $list_style_image, $float, $white_space, $table_layout, $clear, 
-		$box_shadow_horizontal, $box_shadow_vertical, $box_shadow_blur, $box_shadow_spread, $box_shadow_color, $box_shadow_inset, $radius_top_left,
-		$radius_top_left_units, $radius_top_right, $radius_top_right_units, $radius_bottom_right, $radius_bottom_right_units, $radius_bottom_left, $radius_bottom_left_units, $cursor, $background_size, $background_width, $background_width_units, $background_height, $background_height_units);
-		 
-		 	$cnt = $bwb_dbh->exec($query2);
-		} // end while
+		if ((strpos($css_table, "site_css") !== false) || (strpos(css_table, "site_mobile_css") !== false))
+		{
+			//Get custom site CSS.
+			//Start by deleting all old data in table.
+			$query = "TRUNCATE TABLE " . BWB_TABLE_PREFIX . "custom_site_css_preview";
+			$cnt = $bwb_dbh->exec($query);
+			
+			if (strpos(css_table, "site_mobile_css") === false)
+				$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "custom_site_css";
+			else
+				$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "custom_site_mobile_css";
+				
+			$result = $bwb_dbh->query($query);
+			if ($result->rowCount() > 0)	{
+				$row = $result->fetch(PDO::FETCH_ASSOC);
+				$custom_css = $row["custom_css"];
+			}
+			else
+				$custom_css = "";
+			
+			//Insert new data into table.
+			$today = date("Y-m-d H:i:s");
+			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "custom_site_css_preview (custom_css, revised) VALUES ('" . $custom_css . "', '" . $today . "')";
+			$cnt = $bwb_dbh->exec($query);
+		}
 	}
 
 	$class = $_REQUEST['class'];
-	$search = array("PERIOD", "POUND", "SPACE", "COMMA");
-	$replace = array(".", "#", " ", ",");
+	$search = array("PERIOD", "POUND", "SPACE", "COMMA", "GREATERTHAN", "GREATERTHAN", "PLUS", "TILDA");
+	$replace = array(".", "#", " ", ",", ">", "&gt;", "+", "~");
 	$class = str_replace($search, $replace, $class);
 			
 	if ($_POST["use_table_data"]) $use_table_data = $_POST["use_table_data"];
@@ -224,10 +112,13 @@
 	else $font2 = "-not selected-";
 	if ($_POST["font3"]) $font3 = $_POST["font3"];
 	else $font3 = "-not selected-";
-	if ($_POST["font_size"]) $font_size = $_POST["font_size"];
+	if (is_numeric($_POST["font_size"])) $font_size = $_POST["font_size"];
 	else $font_size = -1;
+	if ($_POST["font_size_units"]) $font_size_units = $_POST["font_size_units"];
+	else $font_size_units = "px";
 	if ($_POST["text_color"]) $text_color = $_POST["text_color"];
 	else $text_color = "-not set-";
+	
 	if (is_numeric($_POST["padding_top"])) $padding_top = $_POST["padding_top"];
 	else $padding_top = -1;
 	if (is_numeric($_POST["padding_right"])) $padding_right = $_POST["padding_right"];
@@ -236,6 +127,15 @@
 	else $padding_bottom = -1;
 	if (is_numeric($_POST["padding_left"])) $padding_left = $_POST["padding_left"];
 	else $padding_left = -1;
+	if (is_numeric($_POST["padding_top_units"])) $padding_top_units = $_POST["padding_top_units"];
+	else $padding_top_units = 0;
+	if (is_numeric($_POST["padding_right_units"])) $padding_right_units = $_POST["padding_right_units"];
+	else $padding_right_units = 0;
+	if (is_numeric($_POST["padding_bottom_units"])) $padding_bottom_units = $_POST["padding_bottom_units"];
+	else $padding_bottom_units = 0;
+	if (is_numeric($_POST["padding_left_units"])) $padding_left_units = $_POST["padding_left_units"];
+	else $padding_left_units = 0;
+	
 	if ($_POST["weight"]) $weight = $_POST["weight"];
 	else $weight = "-not selected-";
 	if ($_POST["italic"]) $italic = $_POST["italic"];
@@ -248,8 +148,6 @@
 	else $blink = 0;
 	if ($_POST["linethrough"]) $linethrough = $_POST["linethrough"];
 	else $linethrough = 0;
-//	if ($_POST["font_stretch"]) $font_stretch = $_POST["font_stretch"];
-//	else $font_stretch = "-not selected-";
 	if (is_numeric($_POST["letter_spacing"])) $letter_spacing = $_POST["letter_spacing"];
 	else $letter_spacing = -1000000;
 	if (is_numeric($_POST["letter_spacing_units"])) $letter_spacing_units = $_POST["letter_spacing_units"];
@@ -264,16 +162,20 @@
 	else $shadow = 0;
 	if ($_POST["shadow_color"]) $shadow_color = $_POST["shadow_color"];
 	else $shadow_color = "-not set-";
-	if ($_POST["shadow_x_offset"]) $shadow_x_offset = $_POST["shadow_x_offset"];
+	if (is_numeric($_POST["shadow_x_offset"])) $shadow_x_offset = $_POST["shadow_x_offset"];
 	else $shadow_x_offset = 0;
-	if ($_POST["shadow_y_offset"]) $shadow_y_offset = $_POST["shadow_y_offset"];
+	if (is_numeric($_POST["shadow_y_offset"])) $shadow_y_offset = $_POST["shadow_y_offset"];
 	else $shadow_y_offset = 0;
-	if ($_POST["shadow_blur"]) $shadow_blur = $_POST["shadow_blur"];
+	if (is_numeric($_POST["shadow_blur"])) $shadow_blur = $_POST["shadow_blur"];
 	else $shadow_blur = 0;
 	if (is_numeric($_POST["line_height"])) $line_height = $_POST["line_height"];
 	else $line_height = -1;
 	if (is_numeric($_POST["line_height_units"])) $line_height_units = $_POST["line_height_units"];
 	else $line_height_units = -1;
+	if (is_numeric($_POST["text_indent"])) $text_indent = $_POST["text_indent"];
+	else $text_indent = -1000000;
+	if (is_numeric($_POST["text_indent_units"])) $text_indent_units = $_POST["text_indent_units"];
+	else $text_indent_units = -1;
 	
 	if ($_POST["align"]) $align = $_POST["align"];
 	else $align = "-not selected-";
@@ -281,10 +183,14 @@
 	else $vertical_align = "-not selected-";
 	if ($_POST["bkgd_color"]) $bkgd_color = $_POST["bkgd_color"];
 	else $bkgd_color = "-not set-";
+	if ($_POST["bkgd_transparent"]) $bkgd_transparent = $_POST["bkgd_transparent"];
+	else $bkgd_transparent = 0;
 	if (is_numeric($_POST["bkgd_opacity"])) $bkgd_opacity = $_POST["bkgd_opacity"];
 	else $bkgd_opacity = -1;
 	if (is_numeric($_POST["border"])) $border = $_POST["border"];
 	else $border = -1;
+	if (is_numeric($_POST["border_units"])) $border_units = $_POST["border_units"];
+	else $border_units = 0;
 	if ($_POST["border_color"]) $border_color = $_POST["border_color"];
 	else $border_color = "-not set-";
 	if ($_POST["border_style"]) $border_style = $_POST["border_style"];
@@ -318,9 +224,9 @@
 	else $background_repeat = "-not selected-";
 	if ($_POST["background_position"]) $background_position = $_POST["background_position"];
 	else $background_position = "-not selected-";
-	if ($_POST["background_position_x"]) $background_position_x = $_POST["background_position_x"];
+	if (is_numeric($_POST["background_position_x"])) $background_position_x = $_POST["background_position_x"];
 	else $background_position_x = 0;
-	if ($_POST["background_position_y"]) $background_position_y = $_POST["background_position_y"];
+	if (is_numeric($_POST["background_position_y"])) $background_position_y = $_POST["background_position_y"];
 	else $background_position_y = 0;
 	if ($_POST["background_position_units"]) $background_position_units = $_POST["background_position_units"];
 	else $background_position_units = 0;
@@ -372,6 +278,10 @@
 	else $z_index = -1000000;
 	if ($_POST["overflow"]) $overflow = $_POST["overflow"];
 	else $overflow = "-not selected-";
+	if ($_POST["overflow_x"]) $overflow_x = $_POST["overflow_x"];
+	else $overflow_x = "-not selected-";
+	if ($_POST["overflow_y"]) $overflow_y = $_POST["overflow_y"];
+	else $overflow_y = "-not selected-";
 	if (is_numeric($_POST["clip_top"])) $clip_top = $_POST["clip_top"];
 	else $clip_top = -1;
 	if (is_numeric($_POST["clip_top_units"])) $clip_top_units = $_POST["clip_top_units"];
@@ -405,30 +315,30 @@
 	if ($_POST["clear"]) $clear = $_POST["clear"];
 	else $clear = "-not selected-";
 
-	if ($_POST["radius_top_left"]) $radius_top_left = $_POST["radius_top_left"];
+	if (is_numeric($_POST["radius_top_left"])) $radius_top_left = $_POST["radius_top_left"];
 	else $radius_top_left = 0;
 	if ($_POST["radius_top_left_units"]) $radius_top_left_units = $_POST["radius_top_left_units"];
 	else $radius_top_left_units = 0;
-	if ($_POST["radius_top_right"]) $radius_top_right = $_POST["radius_top_right"];
+	if (is_numeric($_POST["radius_top_right"])) $radius_top_right = $_POST["radius_top_right"];
 	else $radius_top_right = 0;
 	if ($_POST["radius_top_right_units"]) $radius_top_right_units = $_POST["radius_top_right_units"];
 	else $radius_top_right_units = 0;
-	if ($_POST["radius_bottom_right"]) $radius_bottom_right = $_POST["radius_bottom_right"];
+	if (is_numeric($_POST["radius_bottom_right"])) $radius_bottom_right = $_POST["radius_bottom_right"];
 	else $radius_bottom_right = 0;
 	if ($_POST["radius_bottom_right_units"]) $radius_bottom_right_units = $_POST["radius_bottom_right_units"];
 	else $radius_bottom_right_units = 0;
-	if ($_POST["radius_bottom_left"]) $radius_bottom_left = $_POST["radius_bottom_left"];
+	if (is_numeric($_POST["radius_bottom_left"])) $radius_bottom_left = $_POST["radius_bottom_left"];
 	else $radius_bottom_left = 0;
 	if ($_POST["radius_bottom_left_units"]) $radius_bottom_left_units = $_POST["radius_bottom_left_units"];
 	else $radius_bottom_left_units = 0;
 	
-	if ($_POST["box_shadow_horizontal"]) $box_shadow_horizontal = $_POST["box_shadow_horizontal"];
+	if (is_numeric($_POST["box_shadow_horizontal"])) $box_shadow_horizontal = $_POST["box_shadow_horizontal"];
 	else $box_shadow_horizontal = -1000000;
-	if ($_POST["box_shadow_vertical"]) $box_shadow_vertical = $_POST["box_shadow_vertical"];
+	if (is_numeric($_POST["box_shadow_vertical"])) $box_shadow_vertical = $_POST["box_shadow_vertical"];
 	else $box_shadow_vertical = -1000000;
-	if ($_POST["box_shadow_blur"]) $box_shadow_blur = $_POST["box_shadow_blur"];
+	if (is_numeric($_POST["box_shadow_blur"])) $box_shadow_blur = $_POST["box_shadow_blur"];
 	else $box_shadow_blur = -1;
-	if ($_POST["box_shadow_spread"]) $box_shadow_spread = $_POST["box_shadow_spread"];
+	if (is_numeric($_POST["box_shadow_spread"])) $box_shadow_spread = $_POST["box_shadow_spread"];
 	else $box_shadow_spread = -1000000;
 	if ($_POST["box_shadow_color"]) $box_shadow_color = $_POST["box_shadow_color"];
 	else $box_shadow_color = "-not set-";
@@ -440,22 +350,25 @@
 	
 	if ($_POST["background_size"]) $background_size = $_POST["background_size"];
 	else $background_size = "-not selected-";
-	if ($_POST["background_width"]) $background_width = $_POST["background_width"];
+	if (is_numeric($_POST["background_width"])) $background_width = $_POST["background_width"];
 	else $background_width = -1;
 	if ($_POST["background_width_units"]) $background_width_units = $_POST["background_width_units"];
 	else $background_width_units = 0;
-	if ($_POST["background_height"]) $background_height = $_POST["background_height"];
+	if (is_numeric($_POST["background_height"])) $background_height = $_POST["background_height"];
 	else $background_height = -1;
 	if ($_POST["background_height_units"]) $background_height_units = $_POST["background_height_units"];
 	else $background_height_units = 0;
 	
+	if ($_POST["visibility"]) $visibility = $_POST["visibility"];
+	else $visibility = "-not selected-";
+	
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '" . $class . "'";
 	$result = $bwb_dbh->query($query);
 	$row_count = $result->rowCount();
 	
 	if (($_POST['quick_setup'] == 1) && ($row_count > 0))
 	{
-		$fields = array("align", "vertical_align", "bkgd_color", "position", "position_bottom", "position_bottom_units", "position_top", "position_top_units", "position_right", "position_right_units", "position_left", "position_left_units", "width", "width_units", "width_prefix", "height", "height_units", "height_prefix", "margin_left","margin_left_units", "margin_left_auto", "margin_right", "margin_right_units", "margin_right_auto", "margin_top", "margin_top_units", "margin_top_auto", "margin_bottom", "margin_bottom_units", "margin_bottom_auto", "overflow", "display", "clear", "background_size", "background_width", "background_width_units", "background_height", "background_height_units", "border", "border_sides", "padding_top", "padding_right", "padding_bottom", "padding_left");
+		$fields = array("align", "vertical_align", "bkgd_color", "position", "position_bottom", "position_bottom_units", "position_top", "position_top_units", "position_right", "position_right_units", "position_left", "position_left_units", "width", "width_units", "width_prefix", "height", "height_units", "height_prefix", "margin_left","margin_left_units", "margin_left_auto", "margin_right", "margin_right_units", "margin_right_auto", "margin_top", "margin_top_units", "margin_top_auto", "margin_bottom", "margin_bottom_units", "margin_bottom_auto", "overflow", "display", "clear", "background_size", "background_width", "background_width_units", "background_height", "background_height_units", "border", "border_units", "border_sides", "padding_top", "padding_right", "padding_bottom", "padding_left", "padding_top_units", "padding_right_units", "padding_bottom_units", "padding_left_units");
 		
 		$query = "UPDATE `" . BWB_TABLE_PREFIX . $site_css_table . "` SET `use_table_data`=1, ";
 		$delim = "";
@@ -473,39 +386,43 @@
 	{
 		//Update class record.
 		$condition = "`class` = '" . $class . "'";
-		
-		$query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "UPDATE", $condition, "", $use_table_data, $font, $font2, $font3, $font_size, $text_color, $padding_top, $padding_right, $padding_bottom, $padding_left, $weight, $italic,
+
+		$query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "UPDATE", $condition, "", $use_table_data, $font, $font2, $font3, $font_size, $font_size_units, $text_color,
+		$padding_top, $padding_right, $padding_bottom, $padding_left, $padding_top_units, $padding_right_units, $padding_bottom_units, $padding_left_units, $weight, $italic,
 		$underline, $overline, $blink, $linethrough, $letter_spacing, $letter_spacing_units, $oblique, $small_caps, $no_text_decoration, $shadow, $shadow_color, $shadow_x_offset,
-		$shadow_y_offset, $shadow_blur, $line_height, $line_height_units, $align, $vertical_align, $bkgd_color, $bkgd_opacity, $border, $border_color,
+		$shadow_y_offset, $shadow_blur, $line_height, $line_height_units, $align, $vertical_align, $text_indent, text_indent_units,
+		$bkgd_color, $bkgd_transparent, $bkgd_opacity, $border, $border_units, $border_color,
 		$border_style, $outline_style, $border_collapse, $border_sides, $margin_top, $margin_top_units, $margin_top_auto, $margin_right, $margin_right_units,
 		$margin_right_auto, $margin_left, $margin_left_units, $margin_left_auto, $margin_bottom, $margin_bottom_units, $margin_bottom_auto,
 		$display, $width, $width_units, $width_prefix, $height, $height_units, $height_prefix,
 		$position, $position_left, $position_left_units, $position_top, $position_top_units,
-		$position_right, $position_right_units, $position_bottom, $position_bottom_units, $z_index, $overflow,
+		$position_right, $position_right_units, $position_bottom, $position_bottom_units, $z_index, $overflow, $overflow_x, $overflow_y,
 		$clip_top, $clip_top_units, $clip_right, $clip_right_units, $clip_bottom, $clip_bottom_units, $clip_left, $clip_left_units,
 		$background_image, $background_attachment, $background_repeat, $background_position, $background_position_x, $background_position_y,
 		$background_position_units, $list_style_type, $list_style_position, $list_style_image, $float, $white_space, $table_layout, $clear,
 		$box_shadow_horizontal, $box_shadow_vertical, $box_shadow_blur, $box_shadow_spread, $box_shadow_color, $box_shadow_inset, $radius_top_left,
-		$radius_top_left_units, $radius_top_right, $radius_top_right_units, $radius_bottom_right, $radius_bottom_right_units, $radius_bottom_left, $radius_bottom_left_units, $cursor, $background_size, $background_width, $background_width_units, $background_height, $background_height_units);
+		$radius_top_left_units, $radius_top_right, $radius_top_right_units, $radius_bottom_right, $radius_bottom_right_units, $radius_bottom_left, $radius_bottom_left_units, $cursor, $background_size, $background_width, $background_width_units, $background_height, $background_height_units, $visibility);
 	}
 	else
 	{
 		//Insert new data into table.
 		$insert_key = "class='" . $class . "', ";
-		
-		 $query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, $use_table_data, $font, $font2, $font3, $font_size, $text_color, $padding_top, $padding_right, $padding_bottom, $padding_left, $weight, $italic,
+
+		$query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, $use_table_data, $font, $font2, $font3, $font_size, $font_size_units, $text_color,
+		$padding_top, $padding_right, $padding_bottom, $padding_left, $padding_top_units, $padding_right_units, $padding_bottom_units, $padding_left_units, $weight, $italic,
 		$underline, $overline, $blink, $linethrough, $letter_spacing, $letter_spacing_units, $oblique, $small_caps, $no_text_decoration, $shadow, $shadow_color, $shadow_x_offset,
-		$shadow_y_offset, $shadow_blur, $line_height, $line_height_units, $align, $vertical_align, $bkgd_color, $bkgd_opacity, $border, $border_color,
+		$shadow_y_offset, $shadow_blur, $line_height, $line_height_units, $align, $vertical_align, $text_indent, text_indent_units,
+		$bkgd_color, $bkgd_transparent, $bkgd_opacity, $border, $border_units, $border_color,
 		$border_style, $outline_style, $border_collapse, $border_sides, $margin_top, $margin_top_units, $margin_top_auto, $margin_right, $margin_right_units,
 		$margin_right_auto, $margin_left, $margin_left_units, $margin_left_auto, $margin_bottom, $margin_bottom_units, $margin_bottom_auto,
 		$display, $width, $width_units, $width_prefix, $height, $height_units, $height_prefix, 
 		$position, $position_left, $position_left_units, $position_top, $position_top_units,
-		$position_right, $position_right_units, $position_bottom, $position_bottom_units, $z_index, $overflow,
+		$position_right, $position_right_units, $position_bottom, $position_bottom_units, $z_index, $overflow, $overflow_x, $overflow_y,
 		$clip_top, $clip_top_units, $clip_right, $clip_right_units, $clip_bottom, $clip_bottom_units, $clip_left, $clip_left_units,
 		$background_image, $background_attachment, $background_repeat, $background_position, $background_position_x, $background_position_y,
 		$background_position_units, $list_style_type, $list_style_position, $list_style_image, $float, $white_space, $table_layout, $clear,
 		$box_shadow_horizontal, $box_shadow_vertical, $box_shadow_blur, $box_shadow_spread, $box_shadow_color, $box_shadow_inset, $radius_top_left,
-		$radius_top_left_units, $radius_top_right, $radius_top_right_units, $radius_bottom_right, $radius_bottom_right_units, $radius_bottom_left, $radius_bottom_left_units, $cursor, $background_size, $background_width, $background_width_units, $background_height, $background_height_units);
+		$radius_top_left_units, $radius_top_right, $radius_top_right_units, $radius_bottom_right, $radius_bottom_right_units, $radius_bottom_left, $radius_bottom_left_units, $cursor, $background_size, $background_width, $background_width_units, $background_height, $background_height_units, $visibility);
 	}
 //	echo $query;
 	$cnt = $bwb_dbh->exec($query);
@@ -513,8 +430,8 @@
 
 	/////////////////////////////////////////////
 	// Build string for site.css file /////
-	
-	include("build_css_string.php");
+
+	$css_string = BuildCSSString(BWB_TABLE_PREFIX . $site_css_table, BWB_TABLE_PREFIX . $class_table, $bwb_dbh, BWB_BASE_DIR, BWB_IMAGE_DIR, BWB_TABLE_PREFIX . "fonts");
 			
 
 	////////////////////////////////////////////////////////
@@ -535,12 +452,12 @@
 	{
 		$bkup_file_name = $file_name . time();
 		if (!rename($file_name, $bkup_file_name))
-			echo "Could not rename $file_name to $bkup_file_name.<br>";
+			echo EDIT_CSS_COULD_NOT_RENAME_1_ERR . " $file_name " . EDIT_CSS_COULD_NOT_RENAME_2_ERR . " $bkup_file_name.<br>";
 		@chmod($bkup_file_name, 0644);
 	}
 	
 	// Create file.
-	$fh = fopen($file_name, 'x') or die("Can't create $file_name: $php_errormsg");
+	$fh = fopen($file_name, 'x') or die(EDIT_CSS_CANT_CREATE_ERR . " $file_name: $php_errormsg");
 	$result = (fputs($fh, $css_string));
 	fclose($fh) or die($php_errormsg);
 	@chmod($file_name, 0644);
@@ -558,20 +475,14 @@
 		{
 			$bkup_file_name = $file_name . time();
 			if (!rename($file_name, $bkup_file_name))
-				echo "Could not rename $file_name to $bkup_file_name.<br>";
+				echo EDIT_CSS_COULD_NOT_RENAME_1_ERR . " $file_name " . EDIT_CSS_COULD_NOT_RENAME_2_ERR . " $bkup_file_name.<br>";
 			@chmod($bkup_file_name, 0644);
 		}
 		
 		// Create file.
-		$fh = fopen($file_name, 'x') or die("Can't create $file_name: $php_errormsg");
+		$fh = fopen($file_name, 'x') or die(EDIT_CSS_CANT_CREATE_ERR . " $file_name: $php_errormsg");
 		$result = (fputs($fh, $jason_string));
 		fclose($fh) or die($php_errormsg);
 		@chmod($file_name, 0644);
-	}
-	
-	//////////////////////////////////////////////////////////
-	// Goto Preview. /////////////////////
-	if ($submit_action == "Preview")
-		header("Location: preview_css.php?style_sheet=$style_sheet&goto_class=$class");	
-		
+	}	
 ?>
