@@ -20,13 +20,20 @@
 // Fixed bug with opacity being left at 0 if menu freshly cerated.
 // Revised: 12/16/2013	ELL
 // Added ability to specify bottom and right offsets as well as manually editing positioning.
+// Revised: 1/15/2015	ELL
+// Added full complement of units to all pertinent attributes.
+// Revised: 3/28/2016	ELL
+// Fixed bug with horizontal fixed width not saving width.
+// Fixed bug with menu top and left not saving with insert new record.
 // 
 //
 //
 	include ("check_session.php");
+	include("lib/build_css_string.php");
 		
 	$menu = $_REQUEST['menu'];
-	$suffix = substr($menu, 4);
+	$tmp = str_replace("_mobile", "", $menu);
+	$suffix = substr($tmp, 4);
 	$site_css_table = $menu . "_css";
 	$class_table = $menu . "_classes";
 	$css_file = $menu . ".css";
@@ -44,6 +51,16 @@
 	else $menu_bottom = -1000000;
 	if (is_numeric($_POST["menu_right"])) $menu_right = $_POST["menu_right"];
 	else $menu_right = -1000000;
+	
+	if (is_numeric($_POST["menu_top_units"])) $menu_top_units = $_POST["menu_top_units"];
+	else $menu_top_units = 0;
+	if (is_numeric($_POST["menu_left_units"])) $menu_left_units = $_POST["menu_left_units"];
+	else $menu_left_units = 0;
+	if (is_numeric($_POST["menu_bottom_units"])) $menu_bottom_units = $_POST["menu_bottom_units"];
+	else $menu_bottom_units = 0;
+	if (is_numeric($_POST["menu_right_units"])) $menu_right_units = $_POST["menu_right_units"];
+	else $menu_right_units = 0;
+	
 	if (is_numeric($_POST["menu_width"])) $menu_width = $_POST["menu_width"];
 	else $menu_width = 100;
 	if (is_numeric($_POST["menu_width_units"])) $menu_width_units = $_POST["menu_width_units"];
@@ -66,10 +83,24 @@
 	else $top_level_padding_bottom = 2;
 	if (is_numeric($_POST["top_level_padding_left"])) $top_level_padding_left = $_POST["top_level_padding_left"];
 	else $top_level_padding_left = 8;
+	
+	if (is_numeric($_POST["top_level_padding_top_units"])) $top_level_padding_top_units = $_POST["top_level_padding_top_units"];
+	else $top_level_padding_top_units = 0;
+	if (is_numeric($_POST["top_level_padding_right_units"])) $top_level_padding_right_units = $_POST["top_level_padding_right_units"];
+	else $top_level_padding_right_units = 0;
+	if (is_numeric($_POST["top_level_padding_bottom_units"])) $top_level_padding_bottom_units = $_POST["top_level_padding_bottom_units"];
+	else $top_level_padding_bottom_units = 0;
+	if (is_numeric($_POST["top_level_padding_left_units"])) $top_level_padding_left_units = $_POST["top_level_padding_left_units"];
+	else $top_level_padding_left_units = 0;
+	
 	if (is_numeric($_POST["sub_level_offset_top"])) $sub_level_offset_top = $_POST["sub_level_offset_top"];
 	else $sub_level_offset_top = 0;
+	if (is_numeric($_POST["sub_level_offset_top_units"])) $sub_level_offset_top_units = $_POST["sub_level_offset_top_units"];
+	else $sub_level_offset_top_units = 0;
 	if (is_numeric($_POST["sub_level_offset_left"])) $sub_level_offset_left = $_POST["sub_level_offset_left"];
 	else $sub_level_offset_left = 140;
+	if (is_numeric($_POST["sub_level_offset_left_units"])) $sub_level_offset_left_units = $_POST["sub_level_offset_left_units"];
+	else $sub_level_offset_left_units = 0;
 	if (is_numeric($_POST["sub_level_item_width"])) $sub_level_item_width = $_POST["sub_level_item_width"];
 	else $sub_level_item_width = 140;
 	if (is_numeric($_POST["sub_level_item_width_units"])) $sub_level_item_width_units = $_POST["sub_level_item_width_units"];
@@ -86,6 +117,16 @@
 	else $sub_level_padding_bottom = 2;
 	if (is_numeric($_POST["sub_level_padding_left"])) $sub_level_padding_left = $_POST["sub_level_padding_left"];
 	else $sub_level_padding_left = 10;
+	
+	if (is_numeric($_POST["sub_level_padding_top_units"])) $sub_level_padding_top_units = $_POST["sub_level_padding_top_units"];
+	else $sub_level_padding_top_units = 0;
+	if (is_numeric($_POST["sub_level_padding_right_units"])) $sub_level_padding_right_units = $_POST["sub_level_padding_right_units"];
+	else $sub_level_padding_right_units = 0;
+	if (is_numeric($_POST["sub_level_padding_bottom_units"])) $sub_level_padding_bottom_units = $_POST["sub_level_padding_bottom_units"];
+	else $sub_level_padding_bottom_units = 0;
+	if (is_numeric($_POST["sub_level_padding_left_units"])) $sub_level_padding_left_units = $_POST["sub_level_padding_left_units"];
+	else $sub_level_padding_left_units = 0;
+	
 	if (isset($_POST["sub_level_text_align"])) $sub_level_text_align = $_POST["sub_level_text_align"];
 	else $sub_level_text_align = "-not selected-";
 	if (isset($_POST["proportional_width_top"])) $proportional_width_top = $_POST["proportional_width_top"];
@@ -124,7 +165,7 @@
 			. " display='inline', list_style_type='none', border=-2, bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
-	
+
 	//////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = 'ul.nav" . $suffix . "'";
 	$result = $bwb_dbh->query($query);
@@ -132,7 +173,7 @@
 	if ($row_count > 0)
 	{
 		//Update class record.
-		if ($orientation == "horizontal_variable_width")
+		if ($orientation != "vertical")
 			$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, display='table', width=". $menu_width . ", width_units="
 			. $menu_width_units . ", table_layout='fixed', align='" . $top_level_text_align . "', bkgd_opacity=-1 WHERE class='ul.nav" . $suffix . "'";
 		else
@@ -142,7 +183,7 @@
 	else
 	{
 		//Insert new data into table.
-		if ($orientation == "horizontal_variable_width")
+		if ($orientation != "vertical")
 			$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='ul.nav" . $suffix . "', use_table_data=1, display='table', width=" 
 			. $menu_width . ", width_units=" . $menu_width_units . ", align='" . $top_level_text_align . "', table_layout='fixed', bkgd_opacity=-1";
 		else
@@ -158,16 +199,20 @@
 	{
 		//Update class record.
 		if ($orientation == "vertical")
-			$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, padding_top=" . $top_level_padding_top 
-			. ", padding_right=" . $top_level_padding_right
-			. ", padding_bottom=" . $top_level_padding_bottom . ", padding_left=" . $top_level_padding_left
+			$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, padding_top=" . $top_level_padding_top
+			. ", padding_top_units=" . $top_level_padding_top_units 
+			. ", padding_right=" . $top_level_padding_right . ", padding_right_units=" . $top_level_padding_right_units
+			. ", padding_bottom=" . $top_level_padding_bottom . ", padding_bottom_units=" . $top_level_padding_bottom_units
+			. ", padding_left=" . $top_level_padding_left . ", padding_left_units=" . $top_level_padding_left_units
 			. ", width=" . $top_level_item_width . ", width_units=" . $top_level_item_width_units
 			. ", line_height=" . $top_level_item_height . ", line_height_units=" . $top_level_item_height_units
 			. ", position='relative', display='-not selected-', bkgd_opacity=-1 WHERE class='ul.nav" . $suffix . ">li'";
 		else
 			$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, padding_top=" . $top_level_padding_top 
-			. ", padding_right=" . $top_level_padding_right
-			. ", padding_bottom=" . $top_level_padding_bottom . ", padding_left=" . $top_level_padding_left
+			. ", padding_top_units=" . $top_level_padding_top_units 
+			. ", padding_right=" . $top_level_padding_right . ", padding_right_units=" . $top_level_padding_right_units
+			. ", padding_bottom=" . $top_level_padding_bottom . ", padding_bottom_units=" . $top_level_padding_bottom_units
+			. ", padding_left=" . $top_level_padding_left . ", padding_left_units=" . $top_level_padding_left_units
 			. ", width=" . $top_level_item_width . ", width_units=" . $top_level_item_width_units
 			. ", line_height=" . $top_level_item_height . ", line_height_units=" . $top_level_item_height_units
 			. ", position='relative', display='table-cell', bkgd_opacity=-1 WHERE class='ul.nav" . $suffix . ">li'";
@@ -177,21 +222,25 @@
 		//Insert new data into table.
 		if ($orientation == "vertical")
 			$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='ul.nav" . $suffix . ">li', use_table_data=1, padding_top=" 
-			. $top_level_padding_top . ", padding_right=" . $top_level_padding_right
-			. ", padding_bottom=" . $top_level_padding_bottom . ", padding_left=" . $top_level_padding_left
+			. $top_level_padding_top. ", padding_top_units=" . $top_level_padding_top_units
+			. ", padding_right=" . $top_level_padding_right . ", padding_right_units=" . $top_level_padding_right_units
+			. ", padding_bottom=" . $top_level_padding_bottom . ", padding_bottom_units=" . $top_level_padding_bottom_units
+			. ", padding_left=" . $top_level_padding_left . ", padding_left_units=" . $top_level_padding_left_units
 			. ", width=" . $top_level_item_width . ", width_units=" . $top_level_item_width_units
 			. ", line_height=" . $top_level_item_height . ", line_height_units=" . $top_level_item_height_units
 			. ", position='relative', display='-not selected-', z_index=5, bkgd_opacity=-1";
 		else
 			$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='ul.nav" . $suffix . ">li', use_table_data=1, padding_top=" 
-			. $top_level_padding_top . ", padding_right=" . $top_level_padding_right
-			. ", padding_bottom=" . $top_level_padding_bottom . ", padding_left=" . $top_level_padding_left
+			. $top_level_padding_top. ", padding_top_units=" . $top_level_padding_top_units
+			. ", padding_right=" . $top_level_padding_right . ", padding_right_units=" . $top_level_padding_right_units
+			. ", padding_bottom=" . $top_level_padding_bottom . ", padding_bottom_units=" . $top_level_padding_bottom_units
+			. ", padding_left=" . $top_level_padding_left . ", padding_left_units=" . $top_level_padding_left_units
 			. ", width=" . $top_level_item_width . ", width_units=" . $top_level_item_width_units
 			. ", line_height=" . $top_level_item_height . ", line_height_units=" . $top_level_item_height_units
 			. ", position='relative', display='table-cell', z_index=5, bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
-	
+
 	//////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = 'ul.nav" . $suffix . " li>ul'";
 	$result = $bwb_dbh->query($query);
@@ -204,14 +253,17 @@
 	if ($row_count > 0)
 	{
 		//Update class record.
-		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, margin_top=" . $sub_level_offset_top . ", margin_left=" . $sub_level_offset_left
+		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, margin_top=" . $sub_level_offset_top . ", margin_top_units=" . $sub_level_offset_top_units 
+		. ", margin_left=" . $sub_level_offset_left . ", margin_left_units=" . $sub_level_offset_left_units
 		. ", " . $position_display_str . ", width=" . $sub_level_item_width . ", width_units=" . $sub_level_item_width_units
 		. ", line_height=" . $sub_level_item_height . ",   	line_height_units=" . $sub_level_item_height_units . ", bkgd_opacity=-1 WHERE class='ul.nav" . $suffix . " li>ul'";
 	}
 	else
 	{
 		//Insert new data into table.
-		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='ul.nav" . $suffix . " li>ul', use_table_data=1, margin_top=" . $sub_level_offset_top . ", margin_left=" . $sub_level_offset_left
+		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='ul.nav" . $suffix . " li>ul', use_table_data=1, margin_top=" . $sub_level_offset_top 
+		. ", margin_top_units=" . $sub_level_offset_top_units 
+		. ", margin_left=" . $sub_level_offset_left . ", margin_left_units=" . $sub_level_offset_left_units
 		. ", " . $position_display_str . ", width=" . $sub_level_item_width . ", width_units=" . $sub_level_item_width_units
 		. ", line_height=" . $sub_level_item_height . ",   	line_height_units=" . $sub_level_item_height_units . ", bkgd_opacity=-1";
 	}
@@ -232,7 +284,7 @@
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='ul.nav" . $suffix . " li:hover>ul', use_table_data=1, display='block', bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
-	
+
 	//////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.nav" . $suffix . " ul li a'";
 	$result = $bwb_dbh->query($query);
@@ -240,16 +292,21 @@
 	if ($row_count > 0)
 	{
 		//Update class record.
-		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, padding_top=" . $sub_level_padding_top . ", padding_right="
-		. $sub_level_padding_right . ", padding_bottom=" . $sub_level_padding_bottom . ", padding_left=" . $sub_level_padding_left
+		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, padding_top="
+		. $sub_level_padding_top . ", padding_top_units=" . $sub_level_padding_top_units
+		. ", padding_right=" . $sub_level_padding_right . ", padding_right_units=" . $sub_level_padding_right_units
+		. ", padding_bottom=" . $sub_level_padding_bottom . ", padding_bottom_units=" . $sub_level_padding_bottom_units
+		. ", padding_left=" . $sub_level_padding_left . ", padding_left_units=" . $sub_level_padding_left_units
 		. ", display='block', bkgd_opacity=-1 WHERE class='.nav" . $suffix . " ul li a'";
 	}
 	else
 	{
 		//Insert new data into table.
-		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.nav" . $suffix . " ul li a', use_table_data=1, padding_top=" . $sub_level_padding_top
-		. ", padding_right="
-		. $sub_level_padding_right . ", padding_bottom=" . $sub_level_padding_bottom . ", padding_left=" . $sub_level_padding_left
+		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.nav" . $suffix . " ul li a', use_table_data=1, padding_top="
+		. $sub_level_padding_top . ", padding_top_units=" . $sub_level_padding_top_units
+		. ", padding_right=" . $sub_level_padding_right . ", padding_right_units=" . $sub_level_padding_right_units
+		. ", padding_bottom=" . $sub_level_padding_bottom . ", padding_bottom_units=" . $sub_level_padding_bottom_units
+		. ", padding_left=" . $sub_level_padding_left . ", padding_left_units=" . $sub_level_padding_left_units
 		. ", display='block', bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
@@ -262,21 +319,21 @@
 	{
 		//Update class record.
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, position='" . $position
-		. "', position_top=" . $menu_top . ", position_top_units=0, position_left=" . $menu_left
-		. ", position_left_units=0, position_bottom='" . $menu_bottom . "', position_bottom_units=0, position_right='" 
-		. $menu_right . "', position_right_units=0, display='block', bkgd_opacity=-1 WHERE class='.menu_div" . $suffix . "'";
+		. "', position_top=" . $menu_top . ", position_top_units=" . $menu_top_units . ", position_left=" . $menu_left
+		. ", position_left_units=" . $menu_left_units . ", position_bottom='" . $menu_bottom . "', position_bottom_units=" . $menu_bottom_units . ", position_right='" 
+		. $menu_right . "', position_right_units="  . $menu_right_units . ", display='block', bkgd_opacity=-1 WHERE class='.menu_div" . $suffix . "'";
 	}
 	else
 	{
 		//Insert new data into table.
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.menu_div" . $suffix 
 		. "', use_table_data=1, position='" . $position . "',"
-		. " position_top=" . $menu_top . ", position_top_units=0, position_left=" . $menu_left
-		. ", position_left_units=0, position_bottom='" . $menu_bottom . "', position_bottom_units=0, position_right='" 
-		. $menu_right . "', display='block', bkgd_opacity=-1";
+		. " position_top=" . $menu_top . ", position_top_units=" . $menu_top_units . ", position_left=" . $menu_left
+		. ", position_left_units=" . $menu_left_units . ", position_bottom='" . $menu_bottom . "', position_bottom_units=" . $menu_bottom_units . ", position_right='" 
+		. $menu_right . "', position_right_units="  . $menu_right_units . ", display='block', bkgd_opacity=-1";
 	}
 	$cnt = $bwb_dbh->exec($query);
-	
+
 	//////////////////////////////////////////////////////////////////////////////////////////
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.sub_level_1_a" . $suffix . "'";
 	$result = $bwb_dbh->query($query);
@@ -317,7 +374,7 @@
 
 	/////////////////////////////////////////////
 	// Build string for site.css file /////
-	include("build_css_string.php");
+	$css_string = BuildCSSString(BWB_TABLE_PREFIX . $site_css_table, BWB_TABLE_PREFIX . $class_table, $bwb_dbh, BWB_BASE_DIR, BWB_IMAGE_DIR, BWB_TABLE_PREFIX . "fonts");
 			
 
 	////////////////////////////////////////////////////////
@@ -335,16 +392,15 @@
 	{
 		$bkup_file_name = $file_name . time();
 		if (!rename($file_name, $bkup_file_name))
-			echo "Could not rename $file_name to $bkup_file_name.<br>";
+			echo ADD_PLUGIN_TO_PAGE_COULD_NOT_RENAME_MSG . " $file_name " . TO_WORD ." $bkup_file_name.<br>";
 		@chmod($bkup_file_name, 0644);
 	}
 	
 	// Create file.
-	$fh = fopen($file_name, 'x') or die("Can't create $file_name: $php_errormsg");
+	$fh = fopen($file_name, 'x') or die(UPLOAD_TEMPLATE_CANT_CREATE_ERR . " $file_name: $php_errormsg");
 	$result = (fputs($fh, $css_string));
 	fclose($fh) or die($php_errormsg);
 	@chmod($file_name, 0644);
 	
-	header("Location: edit_css_menu_params.php?menu=$menu");	
-		
+	echo 1;
 ?>
