@@ -15,16 +15,16 @@
 	$style_sheet = $_POST['style_sheet'];
 	$class_table = $style_sheet . "_classes";
 	
-	$replace = array(".", "#", " ", ",");
-	$search = array("PERIOD", "POUND", "SPACE", "COMMA");
+	$replace = array(".", "#", " ", ",", ">", "&gt;", "+", "~");
+	$search = array("PERIOD", "POUND", "SPACE", "COMMA", "GREATERTHAN", "GREATERTHAN", "PLUS", "TILDA");
 	$class = str_replace($search, $replace, $class);
 	
 	$query = "UPDATE `" . BWB_TABLE_PREFIX . $class_table . "` SET `description`='" . $description. "' WHERE `class`='" . $class . "'";
 	$cnt = $bwb_dbh->exec($query);
 	
-	if (!$result)
+	if ($cnt < 0)
 		echo "-no data-";
 	else
-		echo "1";
+		echo $cnt;
 
 ?>
\ No newline at end of file
