@@ -6,6 +6,8 @@
 // Created: 1/6/2010	ELL
 // Revised: 2/10/2012	ELL
 // Added table prefix handling.
+// Revised: 3/23/2015	ELL
+// Added updating of mobile menu description.
 // 
 // 
 	include ("check_session.php");
@@ -15,7 +17,10 @@
 
 	if (($menu_name != "") && isset($menu_name))
 	{	
-		$query = "UPDATE `" . BWB_TABLE_PREFIX . "menus` SET `description` = '$description' WHERE `menu_name` = '$menu_name'";
+		$query = "UPDATE `" . BWB_TABLE_PREFIX . "menus` SET `description` = '" . $description . "' WHERE `menu_name` = '" . $menu_name . "'";
+		$cnt = $bwb_dbh->exec($query);
+		
+		$query = "UPDATE `" . BWB_TABLE_PREFIX . "menus` SET `description` = '" . $description . " Mobile' WHERE `menu_name` = '" . $menu_name . "_mobile'";
 		$cnt = $bwb_dbh->exec($query);
 	}
 	
