@@ -4,20 +4,28 @@
 // Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
 // For licensing, see license.txt.
 // Created: 4/9/2013
+// Revised: 4/12/2016	ELL
+// Added Update Breeze Mode no allow multiple plugins to be installed on one login.
 //
 	
 	include ("check_session.php");
 	
 	$password = $_REQUEST['password'];
 	
+	if (isset($_SESSION['install_plugin_mode']))	// Check for expiration.
+	{
+		if (intval($_SESSION['install_plugin_mode']) < time())
+			unset($_SESSION['install_plugin_mode']);
+	}
+	
 ?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml">
+<!DOCTYPE html>
+<html>
 <head>
 <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
 <title>Breeze Website Builder</title>
 
-<link rel="stylesheet" href="manager.css" type="text/css">
+<link rel="stylesheet" href="theme/<?php echo $theme; ?>/manager.css" type="text/css">
 <link rel="shortcut icon" href="images/favicon.ico" type="image/x-icon">
 
 <style type="text/css">
@@ -63,18 +71,18 @@ function checkForEnter(e) {
 
 </head>
 
-<body <?php if (!$password) { ?>onLoad="document.getElementById('password_input').focus();"<?php } ?>>
+<body <?php if ((!$password) && (!isset($_SESSION['install_plugin_mode']))) { ?>onLoad="document.getElementById('password_input').focus();"<?php } ?>>
 <?php
-	if (!$password)
+	if ((!$password) && (!isset($_SESSION['install_plugin_mode'])))
 	{
 ?>
         <form action="upload_plugin.php" method="post" enctype="multipart/form-data" name="formLogin" id="formLogin">
-        <p class="title" align="center">Please enter the password for the "admin" user account:</p>
+        <p class="title" align="center"><?php echo INSTALL_PLUGIN_PLEASE_ENTER_PASSWORD_FOR_ADMIN; ?>:</p>
         <p align="center"><input name="password_input" id="password_input" type="password" onKeyDown="checkForEnter(event);" /></p>
         <input type="hidden" name="password" id="password" />
         <p align="center">
         <table align="center" border="0"><tr><td>
-        <div class='button_console' id="upload_plugin_login_btn" onClick="SubmitLogin();"><span class='button_console_text'>Login</span></div>
+        <div class='button_console' id="upload_plugin_login_btn" onClick="SubmitLogin();"><span class='button_console_text'><?php echo LOGIN_LOGIN_BTN; ?></span></div>
         </td></tr></table>
         </p>
         </form>
@@ -132,29 +140,29 @@ function checkForEnter(e) {
 		
 		$decrypt_text = str_replace(BWB_SALT, '', $decrypt_text);
 		$password_lookup = hash('sha256', $decrypt_text);
-		if ($password_lookup == $password)
+		if (($password_lookup == $password) || (isset($_SESSION['install_plugin_mode'])))
 		{
 ?>
 
 <table width="80%" align="center" border="0"><tr><td>
-<div class="button_heading_sub_level_1" id="install_plugin_heading"><div class="button_heading_text_sub_level_1">Install Plugin</div><div class="help_button" id="help_button" onclick="OpenHelpWindow();">&nbsp;</div></div>
+<div class="button_heading_sub_level_1" id="install_plugin_heading"><div class="button_heading_text_sub_level_1"><?php echo INSTALL_PLUGIN_HEADING; ?></div><div class="help_button" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div></div>
 </td></tr></table>
 
 <form name="frmUploadPlugin" id="frmUploadPlugin" action="install_plugin.php" method="post" enctype="multipart/form-data">
 <table width="80%" align="center">
-	<tr><td align="center"><h3>Select the plugin you want to install from your computer:</h3></td></tr>
+	<tr><td align="center"><h3><?php echo INSTALL_PLUGIN_SELECT_PLUGIN_FROM_YOUR_COMPUTER; ?>:</h3></td></tr>
 	<tr><td align="center"><input name="plugin_file" id="plugin_file" type="file" /></td></tr>
     <tr><td align="center">
-    <div class='button_console' id="install_plugin_btn" onClick="document.getElementById('uploading_gif').style.display = 'inline'; document.getElementById('frmUploadPlugin').submit();"><span class='button_console_text'>Install</span></div>
+    <div class='button_console' id="install_plugin_btn" onClick="document.getElementById('uploading_gif').style.display = 'inline'; document.getElementById('frmUploadPlugin').submit();"><span class='button_console_text'><?php echo INSTALL_WORD; ?></span></div>
     </td></tr>
-    <tr><td align="center"><img src="images/uploading.gif" alt="Uploading..." id="uploading_gif" style="display:none; margin-top:50px;" /></td></tr>
+    <tr><td align="center"><img src="theme/<?php echo $theme; ?>/images/uploading.gif" alt="<?php echo UPLOAD_TEMPLATE_UPLOADING; ?>" id="uploading_gif" style="display:none; margin-top:50px;" /></td></tr>
 </table>
 </form>
 
 <?php
 		}
 		else
-			echo "Your password has not been confirmed.   Click <a href='upload_plugin.php'> here </a> to re-enter your password.";
+			echo LOGIN_PASSWORD_NOT_CONFIRMED_1_MSG . " " . CLICK_WORD . " <a href='upload_plugin.php'> " . HERE_WORD . " </a> " . LOGIN_PASSWORD_NOT_CONFIRMED_2_MSG;
 	}
 ?>
 
