@@ -7,12 +7,9 @@
 //	Revised: 2/10/2012	ELL
 //  Added table prefix handling.
 	
-	define('VERSION', "5.4.55");
-	define('VER_DATE',  "12 feb 2015 01:00:00");	// Release date of this version.
-	define('LAST_VER_DATE',  "2 feb 2015 01:00:00");	// Release date of last version.
-	
-	include ("../connect/db_connect.php");
-	include ("../connect/config.php");
+	define('VERSION', "6.1.20");
+	define('VER_DATE',  "12 apr 2016 01:00:00");	// Release date of this version.
+	define('LAST_VER_DATE',  "6 apr 2016 01:00:00");	// Release date of last version.
 	
 	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "version`";
 	$result = $bwb_dbh->query($query);
@@ -20,7 +17,7 @@
 	$version = $row["version"];
 	
 	if (VERSION == $version)
-		echo "Version $version";
+		echo VERSION_WORD . " " . $version;
 	else
 	{
 		echo "<script language='JavaScript'  type='text/javascript'>\n";
@@ -39,9 +36,9 @@
 		
 		echo "</script>\n";
 		echo "<span style='color:#F00;'>\n";
-		echo "<br>Your database-revision-patch level does not match your program-files-revision level.  Please contact your system administrator.<br>\n";
-		echo "Program Files Revision Level: " . VERSION . "<br>\n";
-		echo "Database Patch Level: $version<br>\n";
+		echo "<br>" . VERSION_DB_PROGRAM_FILE_MISMATCH_MSG . "<br>\n";
+		echo VERSION_PROGRAM_FILES_VERSION_MSG . ": " . VERSION . "<br>\n";
+		echo VERSION_DB_VERSION_MSG . ": $version<br>\n";
 		echo "</span>\n";
 	}
 ?>
\ No newline at end of file
